@@ -111,23 +111,8 @@ void SimulationWidget::dataUpdated(const QString& sourceName, const Plasma::Data
 
 void SimulationWidget::openAccountTab(QString accountName)
 {
-    // Create a dom document, containing relevant parameters
-    QDomDocument params("SKGML");
-
-    // Get default parameters from the current Skrooge document
-    params.setContent(doc->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-    QDomElement root = params.documentElement();
-    if (root.isNull()) {
-        root = params.createElement("parameters");
-        params.appendChild(root);
-    }
-
-    // Add an attribute account with the account name
-    root.setAttribute("account", accountName);
-
     // And finally, open a new tab for this account
-    SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, params.toString());
-
+    SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/?account=" % SKGServices::encodeForUrl(accountName));
 }
 
 #include "simulationwidget.moc"
