@@ -38,7 +38,7 @@ K_PLUGIN_FACTORY(SKGDashboardPluginFactory, registerPlugin<SKGDashboardPlugin>()
  */
 K_EXPORT_PLUGIN(SKGDashboardPluginFactory("skg_dashboard", "skg_dashboard"))
 
-SKGDashboardPlugin::SKGDashboardPlugin(QObject* iParent, const QVariantList& iArg) : SKGInterfacePlugin(iParent)
+SKGDashboardPlugin::SKGDashboardPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& iArg) : SKGInterfacePlugin(iParent)
 {
     Q_UNUSED(iArg);
     SKGTRACEIN(10, "SKGDashboardPlugin::SKGDashboardPlugin");
