@@ -32,13 +32,13 @@ class SKGMainPanel;
 class SKGDashboardPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGDashboardPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGDashboardPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -98,7 +98,7 @@ public:
 private Q_SLOTS:
 
 private:
-    Q_DISABLE_COPY(SKGDashboardPlugin);
+    Q_DISABLE_COPY(SKGDashboardPlugin)
 
     SKGDocument* m_currentDocument;
 
