@@ -53,7 +53,7 @@ K_PLUGIN_FACTORY(SKGFilePluginFactory, registerPlugin<SKGFilePlugin>();)
  */
 K_EXPORT_PLUGIN(SKGFilePluginFactory("skg_file", "skg_file"))
 
-SKGFilePlugin::SKGFilePlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGFilePlugin::SKGFilePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGFilePlugin::SKGFilePlugin");
 
@@ -84,31 +84,29 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     setXMLFile("../skg_file/skg_file.rc");
 
     //Menu
-    KAction* opennew = KStandardAction::openNew(this, SLOT(actionNew()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_new", opennew);
+    KAction* opennew = KStandardAction::openNew(this, SLOT(onNew()), actionCollection());
+    registerGlobalAction("file_new", opennew);
 
-    KAction* open = KStandardAction::open(this, SLOT(actionOpen()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_open", open);
+    KAction* open = KStandardAction::open(this, SLOT(onOpen()), actionCollection());
+    registerGlobalAction("file_open", open);
 
-    m_saveAction = KStandardAction::save(this, SLOT(actionSave()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_save", m_saveAction);
+    m_saveAction = KStandardAction::save(this, SLOT(onSave()), actionCollection());
+    registerGlobalAction("file_save", m_saveAction);
 
-    m_saveAsAction = KStandardAction::saveAs(this, SLOT(actionSaveAs()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_save_as", m_saveAsAction);
+    m_saveAsAction = KStandardAction::saveAs(this, SLOT(onSaveAs()), actionCollection());
+    registerGlobalAction("file_save_as", m_saveAsAction);
 
     m_passwordAction = new KAction(KIcon("document-encrypt"),  i18nc("Action allowing the user to change his document password", "Change password..."), this);
-    connect(m_passwordAction, SIGNAL(triggered(bool)), this, SLOT(actionChangePassword()));
-    actionCollection()->addAction(QLatin1String("file_change_password"), m_passwordAction);
+    connect(m_passwordAction, SIGNAL(triggered(bool)), this, SLOT(onChangePassword()));
     m_passwordAction->setShortcut(Qt::CTRL + Qt::Key_K);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("file_change_password", m_passwordAction);
+    registerGlobalAction("file_change_password", m_passwordAction);
 
     //Recent file
-    m_recentFiles = KStandardAction::openRecent(this, SLOT(actionOpen(KUrl)), actionCollection());
+    m_recentFiles = KStandardAction::openRecent(this, SLOT(onOpen(KUrl)), actionCollection());
     if (m_recentFiles) m_recentFiles->loadEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
 
     //Get last argument
-    connect(this, SIGNAL(loadFile(KUrl)), this, SLOT(actionOpen(KUrl)), Qt::QueuedConnection);
+    connect(this, SIGNAL(loadFile(KUrl)), this, SLOT(onOpen(KUrl)), Qt::QueuedConnection);
 
     int nbArg = iArgument.count();
     int openMode = 1; //0=no open, 1=open last opened if settings set, 2=new document
@@ -139,7 +137,7 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
         }
 
         if (openMode == 2) {
-            actionNew();
+            onNew();
         }
     }
 
@@ -255,10 +253,10 @@ int SKGFilePlugin::getOrder() const
     return 1;
 }
 
-void SKGFilePlugin::actionNew()
+void SKGFilePlugin::onNew()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::actionNew", err);
+    SKGTRACEINRC(10, "SKGFilePlugin::onNew", err);
     if (SKGMainPanel::getMainPanel() && m_currentDocument && SKGMainPanel::getMainPanel()->queryFileClose()) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
@@ -279,12 +277,12 @@ void SKGFilePlugin::actionNew()
     }
 }
 
-void SKGFilePlugin::actionSave()
+void SKGFilePlugin::onSave()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::actionSave", err);
+    SKGTRACEINRC(10, "SKGFilePlugin::onSave", err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
-        if (m_currentDocument->getCurrentFileName().isEmpty()) actionSaveAs();
+        if (m_currentDocument->getCurrentFileName().isEmpty()) onSaveAs();
         else {
             QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
             err = m_currentDocument->save();
@@ -303,10 +301,10 @@ void SKGFilePlugin::actionSave()
     }
 }
 
-void SKGFilePlugin::actionSaveAs()
+void SKGFilePlugin::onSaveAs()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::actionSaveAs", err);
+    SKGTRACEINRC(10, "SKGFilePlugin::onSaveAs", err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///" % m_currentDocument->objectName(),
                            "*." % m_currentDocument->getFileExtension() % '|' % i18nc("Associated with the file extension : for example, .csv --> CSV document", "%1 document", KCmdLineArgs::aboutData()->programName()) ,
@@ -340,10 +338,10 @@ void SKGFilePlugin::actionSaveAs()
     }
 }
 
-void SKGFilePlugin::actionOpen(const KUrl& iUrl)
+void SKGFilePlugin::onOpen(const KUrl& iUrl)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::actionOpen", err);
+    SKGTRACEINRC(10, "SKGFilePlugin::onOpen", err);
     if (SKGMainPanel::getMainPanel() && m_currentDocument && SKGMainPanel::getMainPanel()->queryFileClose()) {
         bool useKWallet = skgfile_settings::storeInKdeWallet();
         QString pwd;
@@ -384,7 +382,7 @@ void SKGFilePlugin::actionOpen(const KUrl& iUrl)
 
                     //Get password
                     if (useKWallet) {
-                        SKGTRACEINRC(10, "SKGFilePlugin::actionOpen-get kwallet passport", err);
+                        SKGTRACEINRC(10, "SKGFilePlugin::onOpen-get kwallet passport", err);
                         //Use KWallet
                         QString walletName = KWallet::Wallet::walletList().value(SKGServices::stringToInt(skgfile_settings::selectedWallet()));
                         if (walletName.isEmpty()) walletName = "kdewallet";
@@ -469,7 +467,7 @@ void SKGFilePlugin::actionOpen(const KUrl& iUrl)
                     }
                 }
             } else {
-                this->actionNew();
+                this->onNew();
                 err.addError(ERR_FAIL, i18nc("Error message: Could not open a file",  "Failed to open '%1'.", fileName));
             }
 
@@ -479,10 +477,10 @@ void SKGFilePlugin::actionOpen(const KUrl& iUrl)
     }
 }
 
-void SKGFilePlugin::actionChangePassword()
+void SKGFilePlugin::onChangePassword()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::actionChangePassword", err);
+    SKGTRACEINRC(10, "SKGFilePlugin::onChangePassword", err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QPointer<KNewPasswordDialog> dlg = new KNewPasswordDialog(SKGMainPanel::getMainPanel());
         dlg->setPrompt(i18n("Take care, if you lose your <b>password</b> then it will be <u><b>impossible</b></u> to open your document."));
@@ -502,18 +500,20 @@ void SKGFilePlugin::actionChangePassword()
     }
 }
 
-SKGAdviceList SKGFilePlugin::advice() const
+SKGAdviceList SKGFilePlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGFilePlugin::advice");
     SKGAdviceList output;
 
     //Backup
-    SKGAdvice ad;
-    ad.setUUID("skgfileplugin_notvalidated");
-    ad.setPriority(2);
-    ad.setShortMessage(i18nc("Advice to the user that he should backup his document", "Backup your document"));
-    ad.setLongMessage(i18nc("Explain the user that he should backup his document", "Don't forget to backup your document on an other device."));
-    output.push_back(ad);
+    if (!iIgnoredAdvice.contains("skgfileplugin_notvalidated")) {
+        SKGAdvice ad;
+        ad.setUUID("skgfileplugin_notvalidated");
+        ad.setPriority(2);
+        ad.setShortMessage(i18nc("Advice to the user that he should backup his document", "Backup your document"));
+        ad.setLongMessage(i18nc("Explain the user that he should backup his document", "Don't forget to backup your document on an other device."));
+        output.push_back(ad);
+    }
 
     return output;
 }
