@@ -37,13 +37,13 @@ class SKGMainPanel;
 class SKGFilePlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGFilePlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGFilePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -123,7 +123,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
 Q_SIGNALS:
     /**
@@ -133,13 +133,13 @@ Q_SIGNALS:
     void loadFile(const KUrl& iFile);
 
 private Q_SLOTS:
-    void actionOpen(const KUrl& iUrl = KUrl());
-    void actionSave();
-    void actionSaveAs();
-    void actionNew();
-    void actionChangePassword();
+    void onOpen(const KUrl& iUrl = KUrl());
+    void onSave();
+    void onSaveAs();
+    void onNew();
+    void onChangePassword();
 private:
-    Q_DISABLE_COPY(SKGFilePlugin);
+    Q_DISABLE_COPY(SKGFilePlugin)
 
     KAction* m_saveAction;
     KAction* m_saveAsAction;
