@@ -26,6 +26,15 @@
 
 #include "grantlee/util.h"
 
+#include <cmath>
+#ifdef Q_OS_WIN
+#define isnan(a) _isnan(a)
+#define isinf(a) !_finite(a)
+#else
+using std::isnan;
+using std::isinf;
+#endif
+
 QVariant SKGDocumentTableFilter::doFilter(const QVariant& input, const QVariant& argument, bool autoescape) const
 {
     Q_UNUSED(autoescape);
@@ -75,8 +84,8 @@ QVariant SKGPercentFilter::doFilter(const QVariant& input, const QVariant& argum
     SKGDocument* doc = NULL;
     if (mainPanel) doc = mainPanel->getDocument();
     if (doc) {
-
-        return QVariant(doc->formatPercentage(SKGServices::stringToDouble(Grantlee::getSafeString(input))));
+        QString s = Grantlee::getSafeString(input);
+        return QVariant(doc->formatPercentage(SKGServices::stringToDouble(s)));
     }
     return QVariant();
 }
@@ -181,7 +190,7 @@ QVariant SKGUrlEncodeFilter::doFilter(const QVariant& input, const QVariant& arg
 {
     Q_UNUSED(autoescape);
     Q_UNUSED(argument);
-    return QVariant(KUrl::encode_string(Grantlee::getSafeString(input)));
+    return QVariant(SKGServices::encodeForUrl(Grantlee::getSafeString(input)));
 }
 
 bool SKGUrlEncodeFilter::isSafe() const
