@@ -30,7 +30,7 @@
 class SKGGrantleeFilters : public QObject, public Grantlee::TagLibraryInterface
 {
     Q_OBJECT
-    Q_INTERFACES(Grantlee::TagLibraryInterface);
+    Q_INTERFACES(Grantlee::TagLibraryInterface)
 
 public:
     /**
