@@ -32,13 +32,13 @@ class QWebView;
 class SKGMonthlyPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGMonthlyPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGMonthlyPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -99,7 +99,7 @@ private Q_SLOTS:
     void refreshMainPage();
 
 private:
-    Q_DISABLE_COPY(SKGMonthlyPlugin);
+    Q_DISABLE_COPY(SKGMonthlyPlugin)
 
     SKGDocument* m_currentBankDocument;
     QWebView* m_mainPage;
