@@ -42,7 +42,7 @@ K_PLUGIN_FACTORY(SKGPropertiesPluginFactory, registerPlugin<SKGPropertiesPlugin>
  */
 K_EXPORT_PLUGIN(SKGPropertiesPluginFactory("skg_properties", "skg_properties"))
 
-SKGPropertiesPlugin::SKGPropertiesPlugin(QObject* iParent, const QVariantList& /*iArg*/) :
+SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent), m_dockWidget(NULL), m_dockContent(NULL)
 {
     SKGTRACEIN(10, "SKGPropertiesPlugin::SKGPropertiesPlugin");
@@ -78,28 +78,31 @@ bool SKGPropertiesPlugin::setupActions(SKGDocument* iDocument, const QStringList
             m_dockWidget->setWidget(m_dockContent);
 
             // add action to control hide / display of Bookmarks
-            m_dockWidget->toggleViewAction()->setShortcut(Qt::SHIFT + Qt::Key_F12);
-            actionCollection()->addAction("view_properties", m_dockWidget->toggleViewAction());
+            QAction* toggle = m_dockWidget->toggleViewAction();
+            KAction* panelAction = actionCollection()->addAction("view_properties");
+            registerGlobalAction("view_properties", panelAction);
+            panelAction->setCheckable(true);
+            panelAction->setChecked(toggle->isChecked());
+            panelAction->setText(toggle->text());
+            panelAction->setShortcut(Qt::SHIFT + Qt::Key_F12);
+            connect(panelAction, SIGNAL(triggered()), toggle, SLOT(trigger()));
+            connect(toggle, SIGNAL(toggled(bool)), panelAction, SLOT(setChecked(bool)));
         }
     }
 
     //Menu
     m_addPropertyAction = new KToolBarPopupAction(KIcon("feed-subscribe"), i18nc("Allows user to add a user defined property on an object", "Add property"), this);
-    actionCollection()->addAction(QLatin1String("add_property"), m_addPropertyAction);
     m_addPropertyMenu = static_cast<KMenu*>(m_addPropertyAction->menu());
     connect(m_addPropertyMenu , SIGNAL(aboutToShow()), this, SLOT(onShowAddPropertyMenu()));
-
     m_addPropertyAction->setStickyMenu(false);
     m_addPropertyAction->setDelayed(false);
-
-    //redoAction=KStandardAction::redo(this, SLOT(actionRedo()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("add-property", m_addPropertyAction);
+    registerGlobalAction("add_property", m_addPropertyAction);
     return true;
 }
 
-void SKGPropertiesPlugin::actionAddProperty()
+void SKGPropertiesPlugin::onAddProperty()
 {
-    SKGTRACEIN(10, "SKGPropertiesPluginDockWidget::actionAddProperty");
+    SKGTRACEIN(10, "SKGPropertiesPluginDockWidget::onAddProperty");
     SKGError err;
     //Scope for the transaction
     QAction* act = qobject_cast<QAction*>(sender());
@@ -146,7 +149,7 @@ void SKGPropertiesPlugin::onShowAddPropertyMenu()
                 QAction* act = m_addPropertyMenu->addAction(KIcon("feed-subscribe"), i18nc("Add a property (attribute=value)", "%1=%2", listTmp.at(i).at(0), listTmp.at(i).at(1)));
                 if (act) {
                     act->setData(listTmp.at(i));
-                    connect(act, SIGNAL(triggered()), this, SLOT(actionAddProperty()));
+                    connect(act, SIGNAL(triggered()), this, SLOT(onAddProperty()));
                 }
             }
         }
