@@ -63,7 +63,7 @@ private Q_SLOTS:
     void cleanEditor();
 
 private:
-    Q_DISABLE_COPY(SKGPropertiesPluginDockWidget);
+    Q_DISABLE_COPY(SKGPropertiesPluginDockWidget)
 
     Ui::skgpropertiesdockplugin_base ui;
 
