@@ -369,18 +369,22 @@ SKGError SKGImportPluginCsv::importFile()
                     SKGAccountObject defAccount;
                     QMap<int, SKGOperationObject> mapGroup;
                     QMap<int, SKGOperationObject> mapOperation;
+                    bool noUnitColumn = (getCSVMapping().indexOf("unit") == -1);
+                    bool noAccountColumn = (getCSVMapping().indexOf("account") == -1);
+                    bool emptyAccount = false;
+
                     for (int i = 0; !err && i < nb; ++i) {
                         QString currentCategory;
                         SKGOperationObject currentOperation(m_importer->getDocument());
                         SKGSubOperationObject currentSubOperation(m_importer->getDocument());
 
                         //Valuate mandatory attribute with default value
-                        if (getCSVMapping().indexOf("unit") == -1) {
-                            err = m_importer->getDefaultUnit(defUnit);
-                            if (!err) err = currentOperation.setUnit(defUnit);
-                        }
-                        if (!err && getCSVMapping().indexOf("account") == -1) {
+                        if (noUnitColumn && i == 0) err = m_importer->getDefaultUnit(defUnit);
+                        if (!err) err = currentOperation.setUnit(defUnit);
+
+                        if (!err && noAccountColumn) {
                             err = m_importer->getDefaultAccount(defAccount);
+                            if (i == 0) emptyAccount = (defAccount.getNbOperation() == 0);
                             if (!err) err = currentOperation.setParentAccount(defAccount);
                         }
 
@@ -412,6 +416,13 @@ SKGError SKGImportPluginCsv::importFile()
                                 } else if (col == "number") {
                                     if (!val.isEmpty()) err = currentOperation.setNumber(SKGServices::stringToInt(val));
                                 } else if (col == "mode") {
+                                    if (val == "1") val = i18nc("An operation mode", "Transfer");
+                                    else if (val == "2") val = i18nc("An operation mode", "Direct debit");
+                                    else if (val == "3") val = i18nc("An operation mode", "Check");
+                                    else if (val == "6") val = i18nc("An operation mode", "Withdrawal");
+                                    else if (val == "7") val = i18nc("An operation mode", "Card");
+                                    else if (val == "9") val = i18nc("An operation mode", "Subscription");
+                                    else if (val == "0") val = "";
                                     err = currentOperation.setMode(val);
                                 } else if (col == "payee") {
                                     SKGPayeeObject payeeObj;
@@ -573,6 +584,23 @@ SKGError SKGImportPluginCsv::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
+
+                    if (!err) {
+                        QString balance = m_parameters["balance"];
+                        if (!balance.isEmpty()) {
+                            if (emptyAccount) {
+                                //Current amount
+                                double currentAmount = defAccount.getAmount(QDate::currentDate());
+
+                                //Update account
+                                if (!err) err = defAccount.setInitialBalance(SKGServices::stringToDouble(balance) - currentAmount, defUnit);
+                                if (!err) err = defAccount.save();
+                                if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", defAccount.getName()));
+
+                            } else m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", defAccount.getName()));
+                        }
+                    }
+
                     if (!err) err = m_importer->getDocument()->endTransaction(true);
                     else  m_importer->getDocument()->endTransaction(false);
 
