@@ -29,7 +29,7 @@
 class SKGImportPluginCsv : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -90,7 +90,7 @@ public:
     virtual SKGError importCSVUnit();
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginCsv);
+    Q_DISABLE_COPY(SKGImportPluginCsv)
 
     /**
      * Set the CSV mapping.
