@@ -31,7 +31,7 @@
 class SKGImportPluginGnc : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -66,7 +66,7 @@ public:
 
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginGnc);
+    Q_DISABLE_COPY(SKGImportPluginGnc)
 
     typedef struct {
         QDomElement subOp;
