@@ -389,7 +389,7 @@ SKGError SKGImportPluginGsb::importFile()
                         SKGObjectBase::SKGListSKGObjectBase subObjs2;
                         if (!err) err = opObj2.getSubOperations(subObjs2);
                         if (!err && subObjs2.count()) {
-                            SKGSubOperationObject subObj2 = subObjs2.at(0);
+                            SKGSubOperationObject subObj2(subObjs2.at(0));
                             err = subObj2.setQuantity(-subObj.getQuantity());
                             err = subObj2.save();
                         }
