@@ -713,7 +713,7 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) {
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export banks"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGBankObject obj = objects.at(i);
+                        SKGBankObject obj(objects.at(i));
                         QDomElement institution = doc.createElement("INSTITUTION");
                         institutions.appendChild(institution);
 
@@ -761,7 +761,7 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) {
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export payees"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGPayeeObject payeeObject = listPayees.at(i);
+                        SKGPayeeObject payeeObject(listPayees.at(i));
                         QDomElement payee = doc.createElement("PAYEE");
                         payees.appendChild(payee);
 
@@ -911,7 +911,7 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) {
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export accounts"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGAccountObject obj = objects.at(i);
+                        SKGAccountObject obj(objects.at(i));
                         QDomElement account = doc.createElement("ACCOUNT");
                         accounts.appendChild(account);
 
@@ -972,7 +972,7 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) {
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export categories"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGCategoryObject obj = objects.at(i);
+                        SKGCategoryObject obj(objects.at(i));
                         QDomElement account = doc.createElement("ACCOUNT");
                         accounts.appendChild(account);
 
@@ -1034,7 +1034,8 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) {
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export operations"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        err = exportOperation(objects.at(i), doc, transactions);
+                        SKGOperationObject op(objects.at(i));
+                        err = exportOperation(op, doc, transactions);
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
@@ -1062,7 +1063,7 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) {
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export scheduled operations"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGRecurrentOperationObject obj = objects.at(i);
+                        SKGRecurrentOperationObject obj(objects.at(i));
                         SKGOperationObject op;
                         err = obj.getParentOperation(op);
                         if (!err) {
@@ -1134,7 +1135,7 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) {
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export budgets"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGBudgetObject obj = objects.at(i);
+                        SKGBudgetObject obj(objects.at(i));
                         SKGCategoryObject cat;
                         obj.getCategory(cat);
                         QString catId = cat.getUniqueID();
@@ -1191,7 +1192,7 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) {
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export units"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGUnitObject obj = objects.at(i);
+                        SKGUnitObject obj(objects.at(i));
                         QDomElement security = doc.createElement("SECURITY");
                         securities.appendChild(security);
 
@@ -1263,7 +1264,7 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) {
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export units"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGUnitObject obj = objects.at(i);
+                        SKGUnitObject obj(objects.at(i));
                         QDomElement pricepair = doc.createElement("PRICEPAIR");
                         prices.appendChild(pricepair);
 
@@ -1280,7 +1281,7 @@ SKGError SKGImportPluginKmy::exportFile()
                             QDomElement price = doc.createElement("PRICE");
                             pricepair.appendChild(price);
 
-                            SKGUnitValueObject unitval = unitValues.at(j);
+                            SKGUnitValueObject unitval(unitValues.at(j));
                             price.setAttribute("price", SKGImportPluginKmy::kmyValue(unitval.getQuantity()));
                             price.setAttribute("source", "Utilisateur");
                             price.setAttribute("date", SKGServices::dateToSqlString(QDateTime(unitval.getDate())));
@@ -1401,7 +1402,7 @@ SKGError SKGImportPluginKmy::exportOperation(const SKGOperationObject& iOperatio
                 QDomElement split = iDoc.createElement("SPLIT");
                 splits.appendChild(split);
 
-                SKGSubOperationObject subop = subops.at(j);
+                SKGSubOperationObject subop(subops.at(j));
                 SKGCategoryObject cat;
                 subop.getCategory(cat);
                 split.setAttribute("payee", payeeId);
