@@ -333,7 +333,7 @@ SKGError SKGImportPluginMmb::importFile()
                                 SKGObjectBase::SKGListSKGObjectBase subops;
                                 if (!err) err = op.getSubOperations(subops);
                                 if (!err && subops.count()) {
-                                    SKGSubOperationObject subop2 = subops.at(0);
+                                    SKGSubOperationObject subop2(subops.at(0));
                                     err = subop2.setQuantity(-subop2.getQuantity());
                                     if (!err) err = subop2.save();
                                 }
