@@ -111,7 +111,7 @@ SKGError SKGImportPluginOfx::importFile()
                     //Update account
                     if (!err) err = act.setInitialBalance(data.ledger_balance - currentAmount, unit);
                     if (!err) err = act.save();
-                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set with OFX file content", act.getName()));
+                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", act.getName()));
                 }
             }
         } catch (...) {
