@@ -369,7 +369,7 @@ SKGError SKGImportPluginQif::importFile()
                             SKGObjectBase::SKGListSKGObjectBase subops;
                             payement.getSubOperations(subops);
                             if (subops.count()) {
-                                SKGSubOperationObject subpayement = subops.at(0);
+                                SKGSubOperationObject subpayement(subops.at(0));
                                 err = subpayement.setQuantity(subpayement.getQuantity() + quantity);
                                 if (!err) err = subpayement.save();
                             }
@@ -677,7 +677,7 @@ SKGError SKGImportPluginQif::importFile()
                                         m_importer->getDocument()->getObjects("v_operation_display", wc, obs);
                                         if (obs.count()) {
                                             //We have to merge them and we do not need to create the transfer
-                                            SKGOperationObject firstOne = obs.at(0);
+                                            SKGOperationObject firstOne(obs.at(0));
                                             err = opOrigin.setStatus(SKGOperationObject::NONE);  //To be sure we can delete it
                                             if (!err) err = opOrigin.save();
                                             if (!err) err = firstOne.mergeAttribute(opOrigin);
@@ -799,7 +799,7 @@ SKGError SKGImportPluginQif::exportFile()
                 stream << "!Type:Cat\n";
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export categories"), nbcat);
                 for (int i = 0; !err && i < nbcat; ++i) {
-                    SKGCategoryObject cat = categories.at(i);
+                    SKGCategoryObject cat(categories.at(i));
                     QString catName = cat.getFullName();
                     if (!catName.isEmpty()) {
                         stream << "N" << catName.replace(OBJECTSEPARATOR, ":") << endl;
@@ -828,7 +828,7 @@ SKGError SKGImportPluginQif::exportFile()
             if (!err) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export operations"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGOperationObject operation = operations.at(i);
+                    SKGOperationObject operation(operations.at(i));
 
                     //Get account name
                     QString accountName = operation.getAttribute("t_ACCOUNT");
@@ -944,7 +944,7 @@ SKGError SKGImportPluginQif::exportFile()
                         int nb = suboperations.size();
                         QString category;
                         if (nb == 1) {
-                            SKGSubOperationObject suboperation = suboperations.at(0);
+                            SKGSubOperationObject suboperation(suboperations.at(0));
                             //Dump quantity
                             if (unitExported) {
                                 stream << 'Q' << SKGServices::doubleToString(qAbs(suboperation.getQuantity())) << endl;
@@ -971,7 +971,7 @@ SKGError SKGImportPluginQif::exportFile()
                         if (nb > 1) {
                             //Split operation
                             for (int i = 0; i < nb; ++i) {
-                                SKGSubOperationObject suboperation = suboperations.at(i);
+                                SKGSubOperationObject suboperation(suboperations.at(i));
                                 SKGCategoryObject cat;
                                 suboperation.getCategory(cat);
 
@@ -1002,7 +1002,7 @@ SKGError SKGImportPluginQif::exportFile()
                 stream << "!Type:Prices\n";
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export units"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGUnitValueObject unitVal = unitvalues.at(i);
+                    SKGUnitValueObject unitVal(unitvalues.at(i));
                     SKGUnitObject unit;
                     err = unitVal.getUnit(unit);
                     if (!err) {
