@@ -29,7 +29,7 @@
 class SKGImportPluginQif : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -78,7 +78,7 @@ public:
 
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginQif);
+    Q_DISABLE_COPY(SKGImportPluginQif)
 };
 
 #endif // SKGIMPORTPLUGINQIF_H
