@@ -84,8 +84,8 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = listUnits.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGUnitObject unitOrigin = listUnits.at(i);
-                    SKGUnitObject unit = unitOrigin.cloneInto(m_importer->getDocument());
+                    SKGUnitObject unitOrigin(listUnits.at(i));
+                    SKGUnitObject unit(unitOrigin.cloneInto(m_importer->getDocument()));
                     if (unit.load().isFailed()) {
                         //This unit does not exist yet
                         if (!err) {
@@ -97,7 +97,7 @@ SKGError SKGImportPluginSkg::importFile()
                             SKGUnitObject parentUnitOrigin;
                             unitOrigin.getUnit(parentUnitOrigin);
 
-                            SKGUnitObject parentUnit = mapOriginNew[parentUnitOrigin.getUniqueID()];
+                            SKGUnitObject parentUnit(mapOriginNew[parentUnitOrigin.getUniqueID()]);
                             if (parentUnit != unit) err = unit.setUnit(parentUnit);
                         }
                         if (!err) err = unit.save(false);    //Save only
@@ -112,7 +112,7 @@ SKGError SKGImportPluginSkg::importFile()
                     if (!err) err = unitOrigin.getUnitValues(listUnitsValues);
                     int nb2 = listUnitsValues.count();
                     for (int j = 0; !err && j < nb2; ++j) {
-                        SKGUnitValueObject unitValueOrigin = listUnitsValues.at(j);
+                        SKGUnitValueObject unitValueOrigin(listUnitsValues.at(j));
 
                         SKGUnitValueObject  unitval;
                         err = unit.addUnitValue(unitval);
@@ -140,8 +140,8 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = listBanks.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks and accounts"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGBankObject bankOrigin = listBanks.at(i);
-                    SKGBankObject bank = bankOrigin.cloneInto(m_importer->getDocument());
+                    SKGBankObject bankOrigin(listBanks.at(i));
+                    SKGBankObject bank(bankOrigin.cloneInto(m_importer->getDocument()));
                     if (bank.load().isFailed()) {
                         //This bank does not exist yet
                         if (!err) err = bank.save(false);    //Save only
@@ -155,8 +155,8 @@ SKGError SKGImportPluginSkg::importFile()
                     if (!err) err = bankOrigin.getAccounts(listAccounts);
                     int nb2 = listAccounts.count();
                     for (int j = 0; !err && j < nb2; ++j) {
-                        SKGAccountObject accountOrigin = listAccounts.at(j);
-                        SKGAccountObject account = accountOrigin.cloneInto(m_importer->getDocument());
+                        SKGAccountObject accountOrigin(listAccounts.at(j));
+                        SKGAccountObject account(accountOrigin.cloneInto(m_importer->getDocument()));
                         if (account.load().isFailed()) {
                             //This account does not exist yet
                             if (!err) err = account.setBank(bank);
@@ -186,7 +186,7 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = listCategories.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGCategoryObject catOrigin = listCategories.at(i);
+                    SKGCategoryObject catOrigin(listCategories.at(i));
 
                     SKGCategoryObject cat;
                     err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), catOrigin.getFullName(), cat);
@@ -210,8 +210,8 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = listRefund.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import trackers"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGTrackerObject tracOrigin = listRefund.at(i);
-                    SKGTrackerObject trac = tracOrigin.cloneInto(m_importer->getDocument());
+                    SKGTrackerObject tracOrigin(listRefund.at(i));
+                    SKGTrackerObject trac(tracOrigin.cloneInto(m_importer->getDocument()));
                     err = trac.save();
                     //Duplicate properties
                     if (!err) err = copyParameters(tracOrigin, trac);
@@ -233,8 +233,8 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = listRules.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import rules"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGRuleObject rulOrigin = listRules.at(i);
-                    SKGRuleObject rul = rulOrigin.cloneInto(m_importer->getDocument());
+                    SKGRuleObject rulOrigin(listRules.at(i));
+                    SKGRuleObject rul(rulOrigin.cloneInto(m_importer->getDocument()));
                     err = rul.save(false);  //Save only
                     //Duplicate properties
                     if (!err) err = copyParameters(rulOrigin, rul);
@@ -255,7 +255,7 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = listPayee.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGPayeeObject paylOrigin = listPayee.at(i);
+                    SKGPayeeObject paylOrigin(listPayee.at(i));
 
                     SKGPayeeObject pay;
                     err = SKGPayeeObject::createPayee(m_importer->getDocument(), paylOrigin.getName(), pay);
@@ -281,8 +281,8 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = listOperations.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGOperationObject operationOrigin = listOperations.at(i);
-                    SKGOperationObject operation = operationOrigin.cloneInto(m_importer->getDocument());
+                    SKGOperationObject operationOrigin(listOperations.at(i));
+                    SKGOperationObject operation(operationOrigin.cloneInto(m_importer->getDocument()));
                     if (!err) err = operation.setAttribute("r_recurrentoperation_id", "");
                     if (!err) err = operation.setImported(true);
                     if (!err) {
@@ -294,7 +294,7 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGAccountObject actOrig;
                         err = operationOrigin.getParentAccount(actOrig);
                         if (!err) {
-                            SKGAccountObject act = mapOriginNew[actOrig.getUniqueID()];
+                            SKGAccountObject act(mapOriginNew[actOrig.getUniqueID()]);
                             act.setClosed(false); //To be sure that the modification is possible. NOT SAVED
                             if (!err) err = operation.setParentAccount(act);
                         }
@@ -302,17 +302,17 @@ SKGError SKGImportPluginSkg::importFile()
                     if (!err) {
                         SKGPayeeObject payeeOrig;
                         operationOrigin.getPayee(payeeOrig);     //Error not managed
-                        if (!err) err = operation.setPayee(mapOriginNew[payeeOrig.getUniqueID()]);
+                        if (!err) err = operation.setPayee(SKGPayeeObject(mapOriginNew[payeeOrig.getUniqueID()]));
                     }
                     if (!err) {
                         SKGUnitObject unitOrig;
                         err = operationOrigin.getUnit(unitOrig);
-                        if (!err) err = operation.setUnit(mapOriginNew[unitOrig.getUniqueID()]);
+                        if (!err) err = operation.setUnit(SKGUnitObject(mapOriginNew[unitOrig.getUniqueID()]));
                     }
                     if (!err) {
                         SKGOperationObject groupOrig;
                         operationOrigin.getGroupOperation(groupOrig);
-                        err = operation.setGroupOperation(mapOriginNew[groupOrig.getUniqueID()]);
+                        err = operation.setGroupOperation(SKGOperationObject(mapOriginNew[groupOrig.getUniqueID()]));
                     }
                     if (!err) err = operation.save(false);    //Save only
 
@@ -326,19 +326,19 @@ SKGError SKGImportPluginSkg::importFile()
                     if (!err) err = operationOrigin.getSubOperations(listSuboperations);
                     int nb2 = listSuboperations.count();
                     for (int j = 0; !err && j < nb2; ++j) {
-                        SKGSubOperationObject subopOrigin = listSuboperations.at(j);
+                        SKGSubOperationObject subopOrigin(listSuboperations.at(j));
 
-                        SKGSubOperationObject subop = subopOrigin.cloneInto(m_importer->getDocument());
+                        SKGSubOperationObject subop(subopOrigin.cloneInto(m_importer->getDocument()));
                         err = subop.setParentOperation(operation);
                         if (!err) {
                             SKGCategoryObject catOrig;
                             subopOrigin.getCategory(catOrig);    //Error not managed
-                            err = subop.setCategory(mapOriginNew[catOrig.getUniqueID()]);
+                            err = subop.setCategory(SKGCategoryObject(mapOriginNew[catOrig.getUniqueID()]));
                         }
                         if (!err) {
                             SKGTrackerObject tracOrig;
                             subopOrigin.getTracker(tracOrig);    //Error not managed
-                            if (!err) err = subop.setTracker(mapOriginNew[tracOrig.getUniqueID()], true);
+                            if (!err) err = subop.setTracker(SKGTrackerObject(mapOriginNew[tracOrig.getUniqueID()]), true);
                         }
                         if (!err) err = subop.save(false);    //Save only
 
@@ -366,12 +366,12 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = ListRecurrentOperations.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled operations"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGRecurrentOperationObject recuOrigin = ListRecurrentOperations.at(i);
-                    SKGRecurrentOperationObject recu = recuOrigin.cloneInto(m_importer->getDocument());
+                    SKGRecurrentOperationObject recuOrigin(ListRecurrentOperations.at(i));
+                    SKGRecurrentOperationObject recu(recuOrigin.cloneInto(m_importer->getDocument()));
 
                     SKGOperationObject opOrig;
                     err = recuOrigin.getParentOperation(opOrig);
-                    if (!err) err = recu.setParentOperation(mapOriginNew[opOrig.getUniqueID()]);
+                    if (!err) err = recu.setParentOperation(SKGOperationObject(mapOriginNew[opOrig.getUniqueID()]));
                     if (!err) err = recu.save(false);    //Save only
 
                     //Duplicate properties
@@ -394,7 +394,7 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = listNodes.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import bookmarks"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGNodeObject nodeOrigin = listNodes.at(i);
+                    SKGNodeObject nodeOrigin(listNodes.at(i));
 
                     SKGNodeObject node;
                     err = SKGNodeObject::createPathNode(m_importer->getDocument(), i18n("Imported bookmarks") % OBJECTSEPARATOR % nodeOrigin.getFullName(), node);
@@ -419,12 +419,12 @@ SKGError SKGImportPluginSkg::importFile()
                 int nb = listInterests.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import interests"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGInterestObject interestOrigin = listInterests.at(i);
-                    SKGInterestObject interest = interestOrigin.cloneInto(m_importer->getDocument());
+                    SKGInterestObject interestOrigin(listInterests.at(i));
+                    SKGInterestObject interest(interestOrigin.cloneInto(m_importer->getDocument()));
                     if (!err) {
                         SKGAccountObject actOrig;
                         err = interestOrigin.getAccount(actOrig);
-                        if (!err) err = interest.setAccount(mapOriginNew[actOrig.getUniqueID()]);
+                        if (!err) err = interest.setAccount(SKGAccountObject(mapOriginNew[actOrig.getUniqueID()]));
                     }
                     if (!err) err = interest.save();
 
