@@ -30,6 +30,7 @@
 #include "skgtraces.h"
 #include "skginterfaceplugin.h"
 #include "skgtablewithgraph.h"
+#include "skgboardwidget.h"
 
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
@@ -51,7 +52,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     //Add report
     SKGInterfacePlugin* reportPlugin = SKGMainPanel::getMainPanel()->getPluginByName("Skrooge report plugin");
     if (reportPlugin) {
-        m_graph = qobject_cast< SKGWidget* >(reportPlugin->getDashboardWidget(0));
+        m_graph = reportPlugin->getDashboardWidget(0);
         if (m_graph) {
             //To avoid hidden page when no account exist
             QWidget* w = new QWidget(this);
@@ -335,7 +336,7 @@ void SKGBankPluginWidget::onRefreshGraph()
                                 wc += ',';
                                 title += ',';
                             }
-                            SKGAccountObject act = objs.at(i);
+                            SKGAccountObject act(objs.at(i));
                             wc += '\'' % SKGServices::stringToSqlString(act.getName()) % '\'';
                             title += i18n("'%1'", act.getName());
                         }
@@ -455,7 +456,7 @@ void SKGBankPluginWidget::onAddAccountClicked()
             if (!err) err = accountObj.setComment(ui.kAccountCreatorComment->text());
             if (!err) err = accountObj.setNumber(ui.kAccountCreatorNumber->text());
             if (!err) err = accountObj.setType(accountType);
-            if (!err) err = accountObj.save();
+            if (!err) err = accountObj.save(false);
             if (!err) err = setInitialBalanceFromEditor(accountObj);
             if (!err) err = accountObj.save();
         }
@@ -487,9 +488,9 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected accounts. Accounts have been merged."));
 
             //Do the merge
-            SKGAccountObject accountObj1 = selection[0];
+            SKGAccountObject accountObj1(selection[0]);
             for (int i = 1; !err && i < nb; ++i) {
-                SKGAccountObject accountObj = selection[i];
+                SKGAccountObject accountObj(selection[i]);
                 err = accountObj1.merge(accountObj);
             }
 
@@ -504,7 +505,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
         if (accountType == SKGAccountObject::WALLET) bankName = "";
 
         for (int i = 0; !err && i < nb; ++i) {
-            SKGAccountObject accountObj = selection[i];
+            SKGAccountObject accountObj(selection[i]);
             err = accountObj.setName(ui.kAccountCreatorAccount->text());
             if (!err) err = accountObj.setNumber(ui.kAccountCreatorNumber->text());
             if (!err) err = setInitialBalanceFromEditor(accountObj);
