@@ -44,7 +44,7 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     if (!iDocument) return;
 
     m_timer.setSingleShot(true);
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(onAmortizationComputation()));
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(onAmortizationComputation()), Qt::QueuedConnection);
 
     ui.setupUi(this);
     ui.kUnitEdit->setDocument(iDocument);
