@@ -39,13 +39,13 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGCategoriesPluginFactory, registerPlugin<SKGCategoriesPlugin>(););
+K_PLUGIN_FACTORY(SKGCategoriesPluginFactory, registerPlugin<SKGCategoriesPlugin>();)
 /**
  * This plugin export.
  */
-K_EXPORT_PLUGIN(SKGCategoriesPluginFactory("skrooge_categories", "skrooge_categories"));
+K_EXPORT_PLUGIN(SKGCategoriesPluginFactory("skrooge_categories", "skrooge_categories"))
 
-SKGCategoriesPlugin::SKGCategoriesPlugin(QObject* iParent, const QVariantList& /*iArg*/)
+SKGCategoriesPlugin::SKGCategoriesPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/)
     : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_importStdCatAction(NULL)
 {
     SKGTRACEIN(10, "SKGCategoriesPlugin::SKGCategoriesPlugin");
@@ -70,19 +70,18 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument, const QStringList
 
     //Import categories
     QStringList overlaycategories;
-    overlaycategories.push_back("skrooge_category");
+    overlaycategories.push_back(icon());
+
+    QStringList overlaydelete;
+    overlaydelete.push_back("edit-delete");
 
     m_importStdCatAction = new KAction(KIcon("document-import", NULL, overlaycategories), i18nc("Verb", "Import standard categories"), this);
     connect(m_importStdCatAction, SIGNAL(triggered(bool)), SLOT(importStandardCategories()));
-    actionCollection()->addAction(QLatin1String("import_standard_categories"), m_importStdCatAction);
+    registerGlobalAction("import_standard_categories", m_importStdCatAction);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("import_standard_categories", m_importStdCatAction);
-
-    KAction* deleteUnusedCategoriesAction = new KAction(KIcon("edit-delete"), i18nc("Verb", "Delete unused categories"), this);
+    KAction* deleteUnusedCategoriesAction = new KAction(KIcon(icon(), NULL, overlaydelete), i18nc("Verb", "Delete unused categories"), this);
     connect(deleteUnusedCategoriesAction, SIGNAL(triggered(bool)), SLOT(deleteUnusedCategories()));
-    actionCollection()->addAction(QLatin1String("edit_delete_unused_categories"), deleteUnusedCategoriesAction);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_delete_unused_categories", deleteUnusedCategoriesAction);
+    registerGlobalAction("edit_delete_unused_categories", deleteUnusedCategoriesAction);
     return true;
 }
 
@@ -101,7 +100,7 @@ QString SKGCategoriesPlugin::getDashboardWidgetTitle(int iIndex)
     return "";
 }
 
-SKGWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
 {
     SKGTRACEIN(1, "SKGCategoriesPlugin::getDashboardWidget");
     if (iIndex == 0) return new SKGHtmlBoardWidget(m_currentBankDocument,
@@ -228,74 +227,64 @@ bool SKGCategoriesPlugin::isInPagesChooser() const
     return true;
 }
 
-SKGAdviceList SKGCategoriesPlugin::advice() const
+SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGCategoriesPlugin::advice");
     SKGAdviceList output;
     //Check unused categies
-    bool exist = false;
-    m_currentBankDocument->existObjects("category", "id IN (SELECT id FROM v_category_display WHERE i_SUMNBOPERATIONS=0)", exist);
-    if (exist) {
-        SKGAdvice ad;
-        ad.setUUID("skgcategoriesplugin_unused");
-        ad.setPriority(5);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused categories"));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing categories that have no operations."));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Delete unused categories"));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+    if (!iIgnoredAdvice.contains("skgcategoriesplugin_unused")) {
+        SKGTRACEIN(10, "SKGCategoriesPlugin::advice-skgcategoriesplugin_unused");
+        bool exist = false;
+        m_currentBankDocument->existObjects("v_category_display", "i_NBOPERATIONS=0 AND i_SUMNBOPERATIONS=0", exist); //i_NBOPERATIONS=0 is there to improve performances
+        if (exist) {
+            SKGAdvice ad;
+            ad.setUUID("skgcategoriesplugin_unused");
+            ad.setPriority(5);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused categories"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing categories that have no operations."));
+            QStringList autoCorrections;
+            autoCorrections.push_back("skg://edit_delete_unused_categories");
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
 
     //Check operations not validated
-    QString month = QDate::currentDate().toString("yyyy-MM");
-    QDate datepreviousmonth = QDate::currentDate().addDays(-QDate::currentDate().day());
-    QString previousmonth = datepreviousmonth.toString("yyyy-MM");
+    if (!iIgnoredAdvice.contains("skgmonthlyplugin_maincategoriesvariation")) {
+        SKGTRACEIN(10, "SKGCategoriesPlugin::advice-skgmonthlyplugin_maincategoriesvariation");
+        QString month = QDate::currentDate().toString("yyyy-MM");
+        QDate datepreviousmonth = QDate::currentDate().addDays(-QDate::currentDate().day());
+        QString previousmonth = datepreviousmonth.toString("yyyy-MM");
 
-    QStringList listCategories;
-    QStringList listVariations = qobject_cast< SKGDocumentBank* >(m_currentBankDocument)->get5MainCategoriesVariationList(month, previousmonth, true, &listCategories);
+        QStringList listCategories;
+        QStringList listVariations = qobject_cast< SKGDocumentBank* >(m_currentBankDocument)->get5MainCategoriesVariationList(month, previousmonth, true, &listCategories);
 
-    int nb = listVariations.count();
-    for (int i = 0; i < nb; ++i) {
-        SKGAdvice ad;
-        ad.setUUID("skgmonthlyplugin_maincategoriesvariation|" % listCategories.at(i));
-        ad.setPriority(7);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Important variation for '%1'", listCategories.at(i)));
-        ad.setLongMessage(listVariations.at(i));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open sub operations with category containing '%1'", listCategories.at(i)));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+        int nb = listVariations.count();
+        for (int i = 0; i < nb; ++i) {
+            SKGAdvice ad;
+            ad.setUUID("skgmonthlyplugin_maincategoriesvariation|" % listCategories.at(i));
+            ad.setPriority(7);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Important variation for '%1'", listCategories.at(i)));
+            ad.setLongMessage(listVariations.at(i));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open sub operations with category containing '%1'", listCategories.at(i)));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
     return output;
 }
 
-SKGError SKGCategoriesPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+SKGError SKGCategoriesPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
-    if (iAdviceIdentifier == "skgcategoriesplugin_unused") {
-        deleteUnusedCategories();
-        return SKGError();
-    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgmonthlyplugin_maincategoriesvariation|"))) {
+    if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgmonthlyplugin_maincategoriesvariation|"))) {
         //Get parameters
         QString category = iAdviceIdentifier.right(iAdviceIdentifier.length() - 41);
         QString month = QDate::currentDate().toString("yyyy-MM");
 
         //Call operation plugin
-        QDomDocument doc("SKGML");
-        doc.setContent(m_currentBankDocument->getParameter("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("operationTable", "v_operation_consolidated");
-        root.setAttribute("operationWhereClause", "d_DATEMONTH='" % month % "' AND t_REALCATEGORY='" % SKGServices::stringToSqlString(category) % '\'');
-        root.setAttribute("title", i18nc("Noun, a list of items", "Sub operations with category containing '%1'",  category));
-        root.setAttribute("title_icon", "skrooge_category");
-        root.setAttribute("currentPage", "-1");
-
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=skrooge_category&operationTable=v_operation_consolidated&title=" %
+                                               SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub operations with category containing '%1'",  category)) % "&operationWhereClause=" % SKGServices::encodeForUrl("d_DATEMONTH='" % month % "' AND t_REALCATEGORY='" % SKGServices::stringToSqlString(category) % '\''));
         return SKGError();
     }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
