@@ -247,7 +247,7 @@ void SKGCategoriesPluginWidget::onAddCategory()
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Category creation '%1'", name)  , err);
 
         if (nb == 1) {
-            SKGCategoryObject parent = selection[0];
+            SKGCategoryObject parent(selection[0]);
             name = parent.getFullName() % OBJECTSEPARATOR % name;
         }
         if (!err) err = SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), name, cat, false, true);
@@ -279,9 +279,9 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
             getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected categories. Categories have been merged."));
 
             //Do the merge
-            SKGCategoryObject catObj1 = selection[0];
+            SKGCategoryObject catObj1(selection[0]);
             for (int i = 1; !err && i < nb; ++i) {
-                SKGCategoryObject catObj = selection[i];
+                SKGCategoryObject catObj(selection[i]);
                 err = catObj1.merge(catObj);
                 if (!err) err = getDocument()->stepForward(i);
             }
@@ -295,7 +295,7 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
         for (int i = 0; !err && i < nb; ++i) {
 
             //Modification of object
-            SKGCategoryObject cat = selection[i];
+            SKGCategoryObject cat(selection[i]);
             err = cat.setName(name);
             if (!err) err = cat.save();
         }
@@ -310,7 +310,7 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
 
 void SKGCategoriesPluginWidget::onDeleteUnused()
 {
-    KAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete_unused_categories");
+    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete_unused_categories");
     if (act) act->trigger();
 }
 
