@@ -36,6 +36,7 @@
 #include <KMessageBox>
 #include <kpassworddialog.h>
 #include <kgenericfactory.h>
+#include <kstandarddirs.h>
 
 #include <QTextCodec>
 #include <QDomDocument>
@@ -48,7 +49,7 @@ K_PLUGIN_FACTORY(SKGImportExportPluginFactory, registerPlugin<SKGImportExportPlu
  */
 K_EXPORT_PLUGIN(SKGImportExportPluginFactory("skrooge_importexport", "skrooge_importexport"))
 
-SKGImportExportPlugin::SKGImportExportPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGImportExportPlugin::SKGImportExportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGImportExportPlugin::SKGImportExportPlugin");
 }
@@ -59,6 +60,7 @@ SKGImportExportPlugin::~SKGImportExportPlugin()
     m_currentBankDocument = NULL;
 
     m_importAction = NULL;
+    m_importBackendAction = NULL;
     m_importCsvUnitAction = NULL;
     m_exportFileAction = NULL;
     m_processingFoundTransfert = NULL;
@@ -82,47 +84,50 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
 
     //Imports
     KActionMenu* imports = new  KActionMenu(KIcon("document-import"), i18nc("Verb, action to import items from another format", "Import"), this);
-    actionCollection()->addAction(QLatin1String("import"), imports);
+    registerGlobalAction("import", imports);
 
     //Import
     QStringList overlay;
     overlay.push_back("skrooge");
 
     m_importAction = new KAction(KIcon("document-import", NULL, overlay), i18nc("Verb, action to import items from another format", "Import..."), this);
-    m_importAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_I);
-    connect(m_importAction, SIGNAL(triggered(bool)), SLOT(import()));
-    actionCollection()->addAction(QLatin1String("import_operation"), m_importAction);
-    imports->addAction(m_importAction);
     m_importAction->setShortcut(Qt::CTRL + Qt::META + Qt::Key_I);
+    connect(m_importAction, SIGNAL(triggered(bool)), SLOT(import()));
+    imports->addAction(m_importAction);
+    registerGlobalAction("import_operation", m_importAction);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("import_operation", m_importAction);
+    //Import backends
+    QStringList overlay2;
+    overlay.push_back("download");
+
+    m_importBackendAction = new KAction(KIcon("document-import", NULL, overlay2), i18nc("Verb, action to import items from another format", "Import with backends"), this);
+    m_importBackendAction->setShortcut(Qt::CTRL + Qt::META + Qt::Key_W);
+    connect(m_importBackendAction, SIGNAL(triggered(bool)), SLOT(importbackends()));
+    imports->addAction(m_importBackendAction);
+    registerGlobalAction("import_backends", m_importBackendAction);
 
     //Import CSV Unit
     QStringList overlaycsv;
     overlaycsv.push_back("text-csv");
     m_importCsvUnitAction = new KAction(KIcon("document-import", NULL, overlaycsv), i18nc("Verb, action to import", "Import currency values..."), this);
     connect(m_importCsvUnitAction, SIGNAL(triggered(bool)), SLOT(import()));
-    actionCollection()->addAction(QLatin1String("import_csv_unit"), m_importCsvUnitAction);
     imports->addAction(m_importCsvUnitAction);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("import_csv_unit", m_importCsvUnitAction);
+    registerGlobalAction("import_csv_unit", m_importCsvUnitAction);
 
     //Exports
     KActionMenu* exports = new  KActionMenu(KIcon("document-export"), i18nc("Verb, action to export items in another format", "Export"), this);
-    actionCollection()->addAction(QLatin1String("export"), exports);
+    registerGlobalAction("export", exports);
 
     //Export
     m_exportFileAction = new KAction(KIcon("document-export"), i18nc("Verb, action to export items to another format", "Export..."), this);
     connect(m_exportFileAction, SIGNAL(triggered(bool)), SLOT(exportFile()));
-    actionCollection()->addAction(QLatin1String("export_operation"), m_exportFileAction);
     exports->addAction(m_exportFileAction);
     m_exportFileAction->setShortcut(Qt::CTRL + Qt::META + Qt::Key_E);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("export_operation", m_exportFileAction);
+    registerGlobalAction("export_operation", m_exportFileAction);
 
     //Processing
     KActionMenu* processing = new  KActionMenu(KIcon("tools-wizard"), i18nc("Noun, apply some kind of transformation on an item", "Processing"), this);
-    actionCollection()->addAction(QLatin1String("processing"), processing);
+    registerGlobalAction("processing", processing);
 
     //Processing found and group
     QStringList overlaytransfers;
@@ -130,55 +135,51 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
 
     m_processingFoundTransfert = new KAction(KIcon("tools-wizard", NULL, overlaytransfers), i18nc("Verb, action to find and group transfers", "Find and group transfers"), this);
     connect(m_processingFoundTransfert, SIGNAL(triggered(bool)), SLOT(foundTransfer()));
-    actionCollection()->addAction(QLatin1String("process_foundtransfer"), m_processingFoundTransfert);
     processing->addAction(m_processingFoundTransfert);
     m_processingFoundTransfert->setShortcut(Qt::CTRL + Qt::META + Qt::Key_G);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("process_foundtransfer", m_processingFoundTransfert);
+    registerGlobalAction("process_foundtransfer", m_processingFoundTransfert);
 
     m_processingAnonymize = new KAction(KIcon("tools-wizard", NULL, overlaytransfers), i18nc("Verb, action to anonymize a document", "Anonymize"), this);
     connect(m_processingAnonymize, SIGNAL(triggered(bool)), SLOT(anonymize()));
-    actionCollection()->addAction(QLatin1String("process_anonymize"), m_processingAnonymize);
     processing->addAction(m_processingAnonymize);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("process_anonymize", m_processingAnonymize);
+    registerGlobalAction("process_anonymize", m_processingAnonymize);
 
     //Processing banks
     m_processingBank = new KAction(KIcon("tools-wizard"), i18nc("Verb, action to clean an import", "Clean bank's imports"), this);
     connect(m_processingBank, SIGNAL(triggered(bool)), SLOT(cleanBanks()));
-    actionCollection()->addAction(QLatin1String("process_banks"), m_processingBank);
     processing->addAction(m_processingBank);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("process_banks", m_processingBank);
+    registerGlobalAction("process_banks", m_processingBank);
 
     //Processing banks
     QStringList overlayValidate;
     overlayValidate.push_back("dialog-ok-apply");
     m_validateImportedOperationsAction = new KAction(KIcon("document-import", NULL, overlayValidate), i18nc("Verb, action to validate imported operations", "Validate imported operations"), this);
     connect(m_validateImportedOperationsAction, SIGNAL(triggered(bool)), SLOT(validateImportedOperations()));
-    actionCollection()->addAction(QLatin1String("validate_imported_operation"), m_validateImportedOperationsAction);
     m_validateImportedOperationsAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_V);
+    registerGlobalAction("validate_imported_operation", m_validateImportedOperationsAction);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("validate_imported_operation", m_validateImportedOperationsAction);
+
+    KAction* act = new KAction(KIcon("document-import", NULL, overlayValidate), i18nc("Verb, action to merge", "Validate operations that do not require further action"), this);
+    connect(act, SIGNAL(triggered(bool)), SLOT(validateAllOperations()));
+    registerGlobalAction("process_validate", act);
 
     QStringList overlayopen;
     overlayopen.push_back("skg_open");
     m_openNotValidatedAction = new KAction(KIcon("document-import", NULL, overlayopen), i18nc("Verb, action to open", "Open imported operations not yet validated..."), this);
-    connect(m_openNotValidatedAction, SIGNAL(triggered(bool)), this, SLOT(openNotValidated()));
-    actionCollection()->addAction(QLatin1String("view_open_not_validated"), m_openNotValidatedAction);
+    m_openNotValidatedAction->setData(QString("skg://skrooge_operation_plugin/?title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations imported and not yet validated")) %
+                                      "&title_icon=" % SKGServices::encodeForUrl(icon()) %
+                                      "&operationWhereClause=" % SKGServices::encodeForUrl("t_imported='P'")));
+    connect(m_openNotValidatedAction, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
     m_openNotValidatedAction->setShortcut(Qt::META + Qt::Key_V);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("view_open_not_validated", m_openNotValidatedAction);
+    registerGlobalAction("view_open_not_validated", m_openNotValidatedAction);
 
     m_mergeImportedOperationAction = new KAction(KIcon("merge"), i18nc("Verb, action to merge", "Merge imported operations"), this);
     connect(m_mergeImportedOperationAction, SIGNAL(triggered(bool)), SLOT(mergeImportedOperation()));
-    actionCollection()->addAction(QLatin1String("merge_imported_operation"), m_mergeImportedOperationAction);
     m_mergeImportedOperationAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_M);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("merge_imported_operation", m_mergeImportedOperationAction);
+    registerGlobalAction("merge_imported_operation", m_mergeImportedOperationAction);
 
     //Get last argument
-    connect(this, SIGNAL(importFile(QString)), this, SLOT(import(QString)), Qt::QueuedConnection);
+    connect(this, SIGNAL(importFile(QStringList)), this, SLOT(import(QStringList)), Qt::QueuedConnection);
 
     //Open/import input file
     int nbArg = iArgument.count();
@@ -205,7 +206,7 @@ void SKGImportExportPlugin::processArguments(const QStringList& iArgument)
     int nbArg = iArgument.count();
     if (nbArg) {
         QString filename = iArgument.at(nbArg - 1);
-        if (QFile(filename).exists()) Q_EMIT importFile(filename);
+        if (QFile(filename).exists()) Q_EMIT importFile(QStringList() << filename);
     }
 }
 
@@ -219,6 +220,13 @@ QWidget* SKGImportExportPlugin::getPreferenceWidget()
     ui.kColumnsPositionsFrm->hide();
     ui.kCsvMappingFrm->hide();
 
+    //Build list of known backends
+    QStringList backends;
+    foreach(const QString & file, KStandardDirs().findAllResources("data", KGlobal::mainComponent().aboutData()->appName() % "/backends/*.backend")) {
+        backends.push_back(QFileInfo(file).baseName().toLower());
+    }
+    ui.kbackendText->setText(i18nc("Information", "You must enter the list of backends to use separated by a ';'.\nExample: backendA;backendB.\n\nHere is the list of known backends: %1.", backends.join(";")));
+
     return widget;
 }
 
@@ -246,6 +254,7 @@ QStringList SKGImportExportPlugin::tips() const
 {
     QStringList output;
     output.push_back(i18nc("Description of a tips", "<p>... skrooge is able to detect automatically transfers after an import.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>... you can automatically import operation with backend.</p>"));
     output.push_back(i18nc("Description of a tips", "<p>... you can import many files in one shot.</p>"));
     output.push_back(i18nc("Description of a tips", "<p>... unit amounts can be imported through a CSV file.</p>"));
     output.push_back(i18nc("Description of a tips", "<p>... you can customize your CSV import with regular expressions defined in setting panel.</p>"));
@@ -285,7 +294,59 @@ void SKGImportExportPlugin::refresh()
     }
 }
 
-void SKGImportExportPlugin::import(const QString& iFile)
+void SKGImportExportPlugin::importbackends()
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGImportExportPlugin::importbackends", err);
+    if (m_currentBankDocument) {
+        //Get backends list to used
+        QStringList backends = SKGServices::splitCSVLine(skgimportexport_settings::backends());
+        int nbBackends = backends.count();
+
+        //Import
+        SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Import with backends"), err, nbBackends);
+        for (int i = 0; !err && i < nbBackends; ++i) {
+            //Is password needed?
+            QString pwd;
+            QHash< QString, QString > properties;
+            err = SKGServices::readPropertyFile(KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/backends/" % backends[i] % ".backend"), properties);
+            if (!err && (properties["getaccounts"].contains("%3") || properties["getoperations"].contains("%3"))) {
+                QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+                QPointer<KPasswordDialog> dlg = new KPasswordDialog(SKGMainPanel::getMainPanel());
+                dlg->setPrompt(i18nc("Question", "The backend '%1' needs a password.\nPlease enter the password.", backends[i]));
+                int rc = dlg->exec();
+                pwd = dlg->password();
+                delete dlg;
+                QApplication::restoreOverrideCursor();
+
+                if (rc != QDialog::Accepted) continue;
+            }
+
+            QString codec = m_currentBankDocument->getParameter("SKG_LAST_CODEC_USED_FOR_IMPORT");
+            if (codec.isEmpty()) codec = QTextCodec::codecForLocale()->name();
+            if (!err) err = m_currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec);
+
+            SKGImportExportManager imp1(m_currentBankDocument, "." % backends[i]);
+            QMap<QString, QString> parameters = imp1.getImportParameters();
+            parameters["password"] = pwd;
+            imp1.setImportParameters(parameters);
+            imp1.setAutomaticValidation(skgimportexport_settings::automatic_validation());
+            imp1.setAutomaticApplyRules(skgimportexport_settings::apply_rules());
+            imp1.setSinceLastImportDate(skgimportexport_settings::since_last_import());
+            imp1.setCodec(codec);
+            if (!err) err = imp1.importFile();
+            if (!err) err = m_currentBankDocument->stepForward(i + 1);
+        }
+    }
+
+    //Display error
+    SKGMainPanel::displayErrorMessage(err);
+
+    //Open last modified operations if setting activated
+    if (!err) openLastModifiedIfSetting();
+}
+
+void SKGImportExportPlugin::import(const QStringList& iFiles)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGImportExportPlugin::import", err);
@@ -295,7 +356,7 @@ void SKGImportExportPlugin::import(const QString& iFile)
         if (lastCodecUsed.isEmpty()) lastCodecUsed = QTextCodec::codecForLocale()->name();
         QString codec;
 
-        if (iFile.isEmpty()) {
+        if (iFiles.isEmpty()) {
             //Panel to ask files
             KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenUrlsAndEncoding(lastCodecUsed, "kfiledialog:///IMPEXP",
                                                  sender() == m_importCsvUnitAction ? QString("*.csv|" % i18nc("A file format", "CSV Files")) :
@@ -304,7 +365,7 @@ void SKGImportExportPlugin::import(const QString& iFile)
             fileNames = result.URLs.toStringList();
             codec = result.encoding;
         } else {
-            fileNames.push_back(iFile);
+            fileNames = iFiles;
             QString codec = lastCodecUsed;
         }
 
@@ -316,6 +377,7 @@ void SKGImportExportPlugin::import(const QString& iFile)
                 //Read Setting
                 bool automatic_validation = skgimportexport_settings::automatic_validation();
                 bool automatic_rule = skgimportexport_settings::apply_rules();
+                bool since_last = skgimportexport_settings::since_last_import();
 
                 if (!err) err = m_currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec);
 
@@ -326,7 +388,8 @@ void SKGImportExportPlugin::import(const QString& iFile)
                     //Import
                     SKGImportExportManager imp1(m_currentBankDocument, fileName);
                     imp1.setAutomaticValidation(automatic_validation);
-                    imp1.setAutomaticApplyRules(i == nbFiles - 1 ? automatic_rule : false); //Apply rules only on the last import for better performances
+                    imp1.setAutomaticApplyRules(automatic_rule);
+                    imp1.setSinceLastImportDate(since_last);
                     imp1.setCodec(codec);
 
                     if (QFileInfo(fileName).suffix().toUpper() == "CSV") { //TODO: Better
@@ -360,7 +423,6 @@ void SKGImportExportPlugin::import(const QString& iFile)
                         imp1.setImportParameters(parameters);
                     }
 
-
                     if (!err) err = imp1.importFile();
                     if (err && err.getReturnCode() == ERR_ENCRYPTION) {
                         QString pwd;
@@ -530,7 +592,7 @@ void SKGImportExportPlugin::validateImportedOperations()
         {
             SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Validate imported operations"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
-                SKGOperationObject op = selection[i];
+                SKGOperationObject op(selection[i]);
                 if (op.getAttribute("t_imported") == "P") {
                     err = op.setImported(true);
                     if (!err) err = op.save();
@@ -558,8 +620,8 @@ void SKGImportExportPlugin::mergeImportedOperation()
         int nb = selection.count();
         err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Invalid selection, you must select one imported operation and one manual operation with same amounts"));
         if (nb == 2) {
-            SKGOperationObject opImported = selection.at(0);
-            SKGOperationObject opManual = selection.at(1);
+            SKGOperationObject opImported(selection.at(0));
+            SKGOperationObject opManual(selection.at(1));
             if (opImported.isImported() != opManual.isImported()) {
                 if (!opImported.isImported())  qSwap(opImported, opManual);
                 int rc = KMessageBox::Yes;
@@ -593,54 +655,51 @@ void SKGImportExportPlugin::openLastModifiedIfSetting()
     bool open_after_import_or_processing = skgimportexport_settings::open_after_import_or_processing();
     if (open_after_import_or_processing) {
         //Open last operations
-        KAction* action = SKGMainPanel::getMainPanel()->getGlobalAction("view_open_last_modified");
+        QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction("view_open_last_modified");
         if (action) {
             action->trigger();
         }
     }
 }
 
-void SKGImportExportPlugin::openNotValidated() const
+void SKGImportExportPlugin::validateAllOperations()
 {
-    SKGTRACEIN(10, "SKGImportExportPlugin::openNotValidated");
-    QString wc = "t_imported='P'";
-    QString title = i18nc("Noun, a list of items", "Operations imported and not yet validated");
-
-    //Call operation plugin
-    QDomDocument doc("SKGML");
-    if (m_currentBankDocument) doc.setContent(m_currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-    QDomElement root = doc.documentElement();
-    if (root.isNull()) {
-        root = doc.createElement("parameters");
-        doc.appendChild(root);
+    SKGError err;
+    SKGTRACEINRC(10, "SKGImportExportPlugin::validateAllOperations", err);
+    {
+        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Validate all operations"), err);
+        err = m_currentBankDocument->executeSqliteOrder("UPDATE operation SET t_imported='Y' WHERE t_imported='P'");
     }
 
-    root.setAttribute("operationWhereClause", wc);
-    root.setAttribute("title", title);
-    root.setAttribute("title_icon", icon());
+    //status bar
+    if (!err) err = SKGError(0, i18nc("Message for successful user action", "Operations validated."));
+    else err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+    //Display error
+    SKGMainPanel::displayErrorMessage(err);
 }
 
-SKGAdviceList SKGImportExportPlugin::advice() const
+SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGImportExportPlugin::advice");
     SKGAdviceList output;
 
     //Check operations not validated
-    bool exist = false;
-    m_currentBankDocument->existObjects("operation", "t_imported='P'", exist);
-    if (exist) {
-        SKGAdvice ad;
-        ad.setUUID("skgimportexportplugin_notvalidated");
-        ad.setPriority(4);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations imported and not yet validated"));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "After importing operations, you should review them, make corrections on, for instance, category, payee. Once done, you should mark the imported operation as validated, so that you know the operation has been fully processed."));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open operations imported and not yet validated"));
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Validate operations that do not require further action"));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+    if (!iIgnoredAdvice.contains("skgimportexportplugin_notvalidated")) {
+        bool exist = false;
+        m_currentBankDocument->existObjects("operation", "t_imported='P'", exist);
+        if (exist) {
+            SKGAdvice ad;
+            ad.setUUID("skgimportexportplugin_notvalidated");
+            ad.setPriority(4);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations imported and not yet validated"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "After importing operations, you should review them, make corrections on, for instance, category, payee. Once done, you should mark the imported operation as validated, so that you know the operation has been fully processed."));
+            QStringList autoCorrections;
+            autoCorrections.push_back("skg://view_open_not_validated");
+            autoCorrections.push_back("skg://process_validate");
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
 
     //Krunner operations
@@ -681,29 +740,9 @@ SKGAdviceList SKGImportExportPlugin::advice() const
     return output;
 }
 
-SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
-    if (iAdviceIdentifier == "skgimportexportplugin_notvalidated" && m_currentBankDocument) {
-        if (iSolution == 0) {
-            //Open operations imported and not yet validated
-            this->openNotValidated();
-        } else {
-            //Validate all operations
-            SKGError err;
-            {
-                SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Validate all operations"), err);
-                err = m_currentBankDocument->executeSqliteOrder("UPDATE operation SET t_imported='Y' WHERE t_imported='P'");
-            }
-
-            //status bar
-            if (!err) err = SKGError(0, i18nc("Message for successful user action", "Operations validated."));
-            else err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
-
-            //Display error
-            SKGMainPanel::displayErrorMessage(err);
-        }
-        return SKGError();
-    } else if (iAdviceIdentifier.startsWith(QLatin1String("skgimportexportplugin_krunner_")) && m_currentBankDocument) {
+    if (iAdviceIdentifier.startsWith(QLatin1String("skgimportexportplugin_krunner_")) && m_currentBankDocument) {
         SKGError err;
         //Get file name
         QString fileName = iAdviceIdentifier.right(iAdviceIdentifier.length() - 30);
@@ -765,10 +804,12 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                 if (!err) {
                     bool automatic_validation = skgimportexport_settings::automatic_validation();
                     bool automatic_rule = skgimportexport_settings::apply_rules();
+                    bool since_last = skgimportexport_settings::since_last_import();
 
                     SKGImportExportManager imp1(m_currentBankDocument);
                     imp1.setAutomaticValidation(automatic_validation);
                     imp1.setAutomaticApplyRules(automatic_rule);
+                    imp1.setSinceLastImportDate(since_last);
                     err = imp1.finalizedImportedOperations();
                 }
 
