@@ -35,13 +35,13 @@ class SKGMainPanel;
 class SKGImportExportPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGImportExportPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGImportExportPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -113,7 +113,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -122,29 +122,31 @@ public:
      * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
      *   @see SKGError
      */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution);
 
 Q_SIGNALS:
     /**
-     * request to import a file
-     * @param iFile file name
+     * Request to import a list of files
+     * @param iFiles the list of files
      */
-    void importFile(const QString& iFile);
+    void importFile(const QStringList& iFiles);
 
 private Q_SLOTS:
-    void import(const QString& iFile = "");
+    void import(const QStringList& iFiles = QStringList());
+    void importbackends();
     void exportFile();
     void foundTransfer();
     void anonymize();
     void cleanBanks();
     void validateImportedOperations();
-    void openNotValidated() const;
+    void validateAllOperations();
     void mergeImportedOperation();
 private:
-    Q_DISABLE_COPY(SKGImportExportPlugin);
+    Q_DISABLE_COPY(SKGImportExportPlugin)
     void openLastModifiedIfSetting();
 
     KAction* m_importAction;
+    KAction* m_importBackendAction;
     KAction* m_importCsvUnitAction;
     KAction* m_exportFileAction;
     KAction* m_processingFoundTransfert;
