@@ -31,25 +31,34 @@
 #include <kaction.h>
 
 SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
-    : SKGWidget(iDocument)
+    : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Income & Expenditure"))
 {
     SKGTRACEIN(10, "SKGOperationBoardWidget::SKGOperationBoardWidget");
 
-    ui.setupUi(this);
+    QFrame* f = new QFrame();
+    ui.setupUi(f);
+    setMainWidget(f);
 
     ui.kIncomeLabel->setText("<a href=\"IC\">" % ui.kIncomeLabel->text() % "</a>");
     ui.kExpenseLabel->setText("<a href=\"EC\">" % ui.kExpenseLabel->text() % "</a>");
-    ui.kSavingLabel->setText("<a href=\"SP\">" % ui.kSavingLabel->text() % "</a>");
+    ui.kSavingLabel->setText("<a href=\"SC\">" % ui.kSavingLabel->text() % "</a>");
     ui.kIncome_previousLabel->setText("<a href=\"IP\">" % ui.kIncome_previousLabel->text() % "</a>");
     ui.kExpense_previousLabel->setText("<a href=\"EP\">" % ui.kExpense_previousLabel->text() % "</a>");
     ui.kSaving_previousLabel->setText("<a href=\"SP\">" % ui.kSaving_previousLabel->text() % "</a>");
 
+    connect(ui.kIncomeLabel, SIGNAL(linkActivated(QString)), this, SLOT(onOpen(QString)));
+    connect(ui.kExpenseLabel, SIGNAL(linkActivated(QString)), this, SLOT(onOpen(QString)));
+    connect(ui.kSavingLabel, SIGNAL(linkActivated(QString)), this, SLOT(onOpen(QString)));
+    connect(ui.kIncome_previousLabel, SIGNAL(linkActivated(QString)), this, SLOT(onOpen(QString)));
+    connect(ui.kExpense_previousLabel, SIGNAL(linkActivated(QString)), this, SLOT(onOpen(QString)));
+    connect(ui.kSaving_previousLabel, SIGNAL(linkActivated(QString)), this, SLOT(onOpen(QString)));
+
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
     m_menuTransfert = new KAction(i18nc("Noun, a type of operations", "Transfers"), this);
     m_menuTransfert->setCheckable(true);
-    m_menuTransfert->setChecked(true);
+    m_menuTransfert->setChecked(false);
     connect(m_menuTransfert, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuTransfert);
 
@@ -86,7 +95,7 @@ void SKGOperationBoardWidget::setState(const QString& iState)
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
-    if (m_menuTransfert) m_menuTransfert->setChecked(root.attribute("menuTransfert") != "N");
+    if (m_menuTransfert) m_menuTransfert->setChecked(root.attribute("menuTransfert") == "Y");
     if (m_menuTracked) m_menuTracked->setChecked(root.attribute("menuTracked") != "N");
 
     dataModified("", 0);
@@ -95,24 +104,15 @@ void SKGOperationBoardWidget::setState(const QString& iState)
 void SKGOperationBoardWidget::onOpen(const QString& iLink)
 {
     //Call operation plugin
-    QDomDocument doc("SKGML");
-
-    //Get month
     QString wc;
-    if (iLink.endsWith(QLatin1String("C"))) wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now'))";
-    else wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now','-1 Month'))";
+    if (iLink.endsWith(QLatin1String("C"))) wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now')) AND t_TYPEACCOUNT<>'L'";
+    else wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now','-1 Month')) AND t_TYPEACCOUNT<>'L'";
 
     if (iLink.startsWith(QLatin1String("I"))) wc = wc % " AND t_TYPEEXPENSE='+'";
     else if (iLink.startsWith(QLatin1String("E"))) wc = wc % " AND t_TYPEEXPENSE='-'";
 
     wc = wc % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : " AND t_TRANSFER='N'") % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND t_REFUND=''");
 
-    doc.setContent(getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-    QDomElement root = doc.documentElement();
-    if (root.isNull()) {
-        root = doc.createElement("parameters");
-        doc.appendChild(root);
-    }
     QString title;
     if (iLink == "IC") title = i18nc("Title of a list of operations", "Incomes of current month");
     else if (iLink == "EC") title = i18nc("Title of a list of operations", "Expenses of current month");
@@ -121,19 +121,9 @@ void SKGOperationBoardWidget::onOpen(const QString& iLink)
     else if (iLink == "EP") title = i18nc("Title of a list of operations", "Expenses of previous month");
     else if (iLink == "SP") title = i18nc("Title of a list of operations", "Savings of previous month");
 
-    if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
-        //Call debug plugin
-        root.setAttribute("sqlOrder", "SELECT * from v_operation_consolidated WHERE " % wc);
-
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
-    } else {
-        root.setAttribute("operationWhereClause", wc);
-        root.setAttribute("title", title);
-        root.setAttribute("title_icon", "view-financial-list");
-        root.setAttribute("currentPage", "-1");
-
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-    }
+    SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/?title_icon=view-financial-list&currentPage=-1&title=" % SKGServices::encodeForUrl(title) %
+                                           "&operationWhereClause=" % SKGServices::encodeForUrl(wc)
+                                          );
 }
 
 void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
@@ -156,7 +146,7 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
 
             SKGStringListList listTmp;
             SKGError err = getDocument()->executeSelectSqliteOrder(
-                               "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') "
+                               "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TYPEACCOUNT<>'L'"
                                % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : "AND t_TRANSFER='N'")
                                % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND t_REFUND=''")
                                % " group by d_DATEMONTH, t_TYPEEXPENSE",
