@@ -22,14 +22,14 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
 #include "ui_skgoperationpluginwidget_board.h"
-#include "skgwidget.h"
+#include "skgboardwidget.h"
 
 class KAction;
 
 /**
  * This file is Skrooge plugin for operation management
  */
-class SKGOperationBoardWidget : public SKGWidget
+class SKGOperationBoardWidget : public SKGBoardWidget
 {
     Q_OBJECT
 
@@ -64,7 +64,7 @@ private Q_SLOTS:
     void onOpen(const QString& iLink);
 
 private:
-    Q_DISABLE_COPY(SKGOperationBoardWidget);
+    Q_DISABLE_COPY(SKGOperationBoardWidget)
 
     Ui::skgoperationplugin_board ui;
 
