@@ -111,7 +111,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
             ui.kOperationView->getView()->insertGlobalAction("edit_duplicate_operation");
             ui.kOperationView->getView()->insertGlobalAction("edit_template_operation");
             ui.kOperationView->getView()->insertGlobalAction("schedule_operation");
-            ui.kOperationView->getView()->insertGlobalAction("add-property");
+            ui.kOperationView->getView()->insertGlobalAction("add_property");
         }
 
         connect(ui.kOperationView->getView(), SIGNAL(clickEmptyArea()), this, SLOT(cleanEditor()));
@@ -250,8 +250,8 @@ QString SKGOperationPluginWidget::currentAccount()
 {
     QStringList accounts = SKGServices::splitCSVLine(ui.kOperationView->getShowWidget()->getState());
     foreach(const QString & item, accounts) {
-        if (item.startsWith(QLatin1String("##"))) {
-            return ui.kOperationView->getShowWidget()->getAction(item)->toolTip();
+        if (item.startsWith(QLatin1String("##_"))) {
+            return item.right(item.length() - 3);
         }
     }
     return "";
@@ -580,6 +580,9 @@ void SKGOperationPluginWidget::onUpdateOperationClicked()
 
     //Display error
     SKGMainPanel::displayErrorMessage(err);
+
+    //Set focus on date
+    ui.kDateEdit->setFocus();
 }
 
 SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListSKGObjectBase& iSelection, bool forceCreation)
@@ -658,7 +661,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
             }
 
             if (!err && ui.kCommentEdit->text() != NOUPDATE) {
-                if (obj.getTable() == "v_operation_consolidated") err = subOp.setComment(ui.kCommentEdit->text());
+                err = subOp.setComment(ui.kCommentEdit->text());
             }
             if (!err) err = subOp.save();
         } else if (ui.kWidgetSelector->getSelectedMode() == 1) {
@@ -761,6 +764,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
                 err = SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), ui.kCategoryEdit->text(), cat, true);
                 if (!err) err = subOperation.setCategory(cat);
             }
+            if (!err) err = subOperation.setComment(operationObj.getComment());
             if (!err) err = subOperation.save();
 
             //Get account
@@ -840,6 +844,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
             }
             if (!err) err = subOperation2.setQuantity(operationQuantity);
             if (!err) err = subOperation2.setCategory(cat);
+            if (!err) err = subOperation2.setComment(operationObj.getComment());
             if (!err) err = subOperation2.save();
 
         }
@@ -899,7 +904,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
                     err = operationObj.getSubOperations(subops);
                     int nbsubops = subops.count();
                     for (int i = 0; !err && i < nbsubops; ++i) {
-                        SKGSubOperationObject subop = subops.at(i);
+                        SKGSubOperationObject subop(subops.at(i));
                         err = subop.setQuantity(subop.getQuantity() * ratio);
                         if (!err) err = subop.save(true, false);
                     }
@@ -1064,6 +1069,9 @@ void SKGOperationPluginWidget::onAddOperationClicked()
 
     //Display error
     SKGMainPanel::displayErrorMessage(err);
+
+    //Set focus on date
+    ui.kDateEdit->setFocus();
 }
 
 SKGTreeView* SKGOperationPluginWidget::getTableView()
@@ -1156,13 +1164,9 @@ void SKGOperationPluginWidget::setState(const QString& iState)
         m_objectModel->blockRefresh(previous);
     }
 
-    //Due to the refresh of the information zone, this must be done here
-    if (!modeInfoZoneS.isEmpty()) m_modeInfoZone = SKGServices::stringToInt(modeInfoZoneS) - 1;
-    else m_modeInfoZone = -1;
-    onRotateAccountTools();
-
     //!!! Must be done here after onFilterChanged
-    ui.kOperationView->setState(root.attribute("view"));
+    QString v = root.attribute("view");
+    if (!v.isEmpty()) ui.kOperationView->setState(v);
     if (!account.isEmpty()) {
         QStringList parameters = SKGServices::splitCSVLine(ui.kOperationView->getShowWidget()->getState());
         if (parameters.count() == 0) {
@@ -1170,15 +1174,15 @@ void SKGOperationPluginWidget::setState(const QString& iState)
             parameters.push_back("operations");
             parameters.push_back("hide");
         }
-        parameters[0] = "##_" % account.remove(';');
-        ui.kOperationView->getShowWidget()->setState(parameters.join(";"));
+        parameters[0] = "##_" % account;
+        ui.kOperationView->getShowWidget()->setState(SKGServices::stringsToCsv(parameters));
     }
 
     if (templates == "Y") {
         QStringList parameters = SKGServices::splitCSVLine(ui.kOperationView->getShowWidget()->getState());
         parameters.removeAll("operations");
         parameters.push_back("templates");
-        ui.kOperationView->getShowWidget()->setState(parameters.join(";"));
+        ui.kOperationView->getShowWidget()->setState(SKGServices::stringsToCsv(parameters));
     }
 
     if (!selection.isEmpty()) {
@@ -1186,12 +1190,17 @@ void SKGOperationPluginWidget::setState(const QString& iState)
         ui.kOperationView->getView()->selectObjects(uuids, true);  //FIXME //TODO
         onSelectionChanged();
     }
+
+    //Refresh of the information zone
+    if (!modeInfoZoneS.isEmpty()) m_modeInfoZone = SKGServices::stringToInt(modeInfoZoneS) - 1;
+    else m_modeInfoZone = -1;
+    onRotateAccountTools();
 }
 
 QString SKGOperationPluginWidget::getDefaultStateAttribute()
 {
+    if (!m_operationWhereClause.isEmpty()) return "";
     if (m_objectModel && m_objectModel->getTable() == "v_operation_consolidated") return "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS";
-    if (ui.kTitle->isVisible()) return "";
     return "SKGOPERATION_DEFAULT_PARAMETERS";
 }
 
@@ -1237,63 +1246,64 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
             getDocument()->executeSelectSqliteOrder(QString("SELECT t_ICON, t_name from v_account_display ") % (m_showClosedAccounts ? "" : "where t_close='N' ") % "order by t_name", listAccount);
 
             int nbAccounts = listAccount.count() - 1;
-            if (nbAccounts == 0) {
-                ui.kTitle->setText(i18nc("Message", "First you have to create an account."));
-                ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22) , KTitleWidget::ImageLeft);
-                ui.kTitle->show();
-            } else {
-                if (!m_lastState.hasChildNodes()) ui.kTitle->hide();
+            if (!m_lastState.hasChildNodes()) ui.kTitle->hide();
 
-                //Set show widget
-                show->clear();
+            //Set show widget
+            show->clear();
 
-                if (nbAccounts != 1) show->addGroupedItem("all", i18nc("Option to for display of operations", "All"), "", "1=1", "account");
-                QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
-                QString uncheck;
-                for (int i = 1; i <= nbAccounts; ++i) { //Ignore header
-                    QString iconName = dirLogo.absoluteFilePath(listAccount.at(i).at(0));
-                    QIcon icon(iconName);
-                    QString text = listAccount.at(i).at(1);
-                    QString id = "##_" % text.remove(';');
-                    if (nbAccounts == 1) {
-                        if (currentState.startsWith(QLatin1String("all;"))) currentState = currentState.replace("all;", id % ";");
-                        if (!currentState.startsWith(QLatin1String("##_"))) currentState = id % ";" % (currentState.isEmpty() ? "operations;hide" : currentState);
+            if (nbAccounts > 1) show->addGroupedItem("all", i18nc("Option to for display of operations", "All"), "", "1=1", "account");
+            QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
+            QString uncheck;
+            for (int i = 1; i <= nbAccounts; ++i) { //Ignore header
+                QString iconName = dirLogo.absoluteFilePath(listAccount.at(i).at(0));
+                QIcon icon(iconName);
+                QString text = listAccount.at(i).at(1);
+                QString id = "##_" % text;
+                if (nbAccounts == 1) {
+                    QStringList items = SKGServices::splitCSVLine(currentState);
+                    if (items.count() == 0) items.push_back("all");
+                    if (items[0] == "all" || !items[0].startsWith(QLatin1String("##_"))) items[0] = id;
+                    if (items.count() == 1) {
+                        items.push_back("operations");
+                        items.push_back("hide");
                     }
-                    ui.kAccountEdit->addItem(icon, text);
-                    ui.kPaymentAccountEdit->addItem(icon, text);
+                    currentState = SKGServices::stringsToCsv(items);
 
-                    show->addGroupedItem(id, text, iconName, "t_ACCOUNT='" + SKGServices::stringToSqlString(text) + '\'', "account");
-
-                    if (!uncheck.isEmpty()) uncheck = uncheck % ";";
-                    uncheck = uncheck % id;
                 }
+                ui.kAccountEdit->addItem(icon, text);
+                ui.kPaymentAccountEdit->addItem(icon, text);
 
-                int nb = show->count();
-                for (int i = 1; i < nb; ++i) {
-                    show->setListIdToUncheckWhenChecked(i, uncheck % ";all");
-                }
-                if (nbAccounts != 1) show->setListIdToUncheckWhenChecked(0, uncheck);
+                show->addGroupedItem(id, text, iconName, "t_ACCOUNT='" + SKGServices::stringToSqlString(text) + '\'', "account");
 
-                show->addSeparator();
-                show->addGroupedItem("operations", i18nc("Option to for display of operations", "Operations"), "view-financial-list", "d_date!='0000-00-00' AND t_template='N'",
-                                     "type");
-                show->addGroupedItem("templates", i18nc("Option to for display of operations", "Templates"), "skrooge_template", "d_date!='0000-00-00' AND t_template='Y'",
-                                     "type");
-                show->addSeparator();
-                show->addGroupedItem("hidenone", i18nc("Option to for display of operations", "All"), "dialog-ok", "1=1", "checked");
-                show->addGroupedItem("hide", i18nc("Option to for display of operations", "Hide all checked operations"), "dialog-ok", "t_status<>'Y'", "checked");
-                show->addGroupedItem("hide1w", i18nc("Option to for display of operations", "Hide checked operations > 1 week"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-7 day')", "checked");
-                show->addGroupedItem("hide2w", i18nc("Option to for display of operations", "Hide checked operations > 2 weeks"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-14 day')", "checked");
-                show->addGroupedItem("hide1m", i18nc("Option to for display of operations", "Hide checked operations > 1 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 month')", "checked");
-                show->addGroupedItem("hide3m", i18nc("Option to for display of operations", "Hide checked operations > 3 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-3 month')", "checked");
-                show->addGroupedItem("hide6m", i18nc("Option to for display of operations", "Hide checked operations > 6 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-6 month')", "checked");
-                show->addGroupedItem("hide1y", i18nc("Option to for display of operations", "Hide checked operations > 1 year"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 year')", "checked");
-                show->setMode(SKGShow::AND);
-                if (currentState.isEmpty()) {
-                    show->setDefaultState("all;operations;hide");
-                } else {
-                    show->setState(currentState);
-                }
+                if (!uncheck.isEmpty()) uncheck = uncheck % ";";
+                uncheck = uncheck % id;
+            }
+
+            int nb = show->count();
+            for (int i = 1; i < nb; ++i) {
+                show->setListIdToUncheckWhenChecked(i, uncheck % ";all");
+            }
+            if (nbAccounts > 1) show->setListIdToUncheckWhenChecked(0, uncheck);
+
+            show->addSeparator();
+            show->addGroupedItem("operations", i18nc("Option to for display of operations", "Operations"), "view-financial-list", "d_date!='0000-00-00' AND t_template='N'",
+                                 "type");
+            show->addGroupedItem("templates", i18nc("Option to for display of operations", "Templates"), "skrooge_template", "d_date!='0000-00-00' AND t_template='Y'",
+                                 "type");
+            show->addSeparator();
+            show->addGroupedItem("hidenone", i18nc("Option to for display of operations", "All"), "dialog-ok", "1=1", "checked");
+            show->addGroupedItem("hide", i18nc("Option to for display of operations", "Hide all checked operations"), "dialog-ok", "t_status<>'Y'", "checked");
+            show->addGroupedItem("hide1w", i18nc("Option to for display of operations", "Hide checked operations > 1 week"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-7 day')", "checked");
+            show->addGroupedItem("hide2w", i18nc("Option to for display of operations", "Hide checked operations > 2 weeks"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-14 day')", "checked");
+            show->addGroupedItem("hide1m", i18nc("Option to for display of operations", "Hide checked operations > 1 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 month')", "checked");
+            show->addGroupedItem("hide3m", i18nc("Option to for display of operations", "Hide checked operations > 3 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-3 month')", "checked");
+            show->addGroupedItem("hide6m", i18nc("Option to for display of operations", "Hide checked operations > 6 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-6 month')", "checked");
+            show->addGroupedItem("hide1y", i18nc("Option to for display of operations", "Hide checked operations > 1 year"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 year')", "checked");
+            show->setMode(SKGShow::AND);
+            if (currentState.isEmpty()) {
+                show->setDefaultState("all;operations;hide");
+            } else {
+                show->setState(currentState);
             }
 
             if (!current.isEmpty()) ui.kAccountEdit->setText(current);
@@ -1305,6 +1315,13 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
             connect(show, SIGNAL(stateChanged()), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
 
             fillTargetAccount();
+
+            if (nbAccounts == 0) {
+                ui.kTitle->setText(i18nc("Message", "First you have to create an account."));
+                ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22) , KTitleWidget::ImageLeft);
+                ui.kTitle->show();
+                show->hide();
+            } else show->show();
         }
         if (iTableName == "category" || iTableName.isEmpty()) {
             SKGMainPanel::fillWithDistinctValue(ui.kCategoryEdit, getDocument(), "category", "t_fullname", "");
@@ -1516,7 +1533,7 @@ void SKGOperationPluginWidget::onRefreshInformationZone()
             QMap<QString, double> amountPerUnit;
             QMap<QString, int> decimalPerUnit;
             for (int i = 0; i < nb; ++i) {
-                SKGObjectBase obj = selection.at(i);
+                SKGObjectBase obj(selection.at(i));
                 SKGOperationObject op;
                 double val;
                 double quantity;
@@ -1705,7 +1722,7 @@ void SKGOperationPluginWidget::onFastEdition()
         SKGObjectBase::SKGListSKGObjectBase operations;
         err = getDocument()->getObjects("v_operation_display_all", wc, operations);
         if (!err && operations.count()) {
-            SKGOperationObject op = operations.at(0);
+            SKGOperationObject op(operations.at(0));
 
             m_lastFastEditionOperationFound = op.getID();
             if (isWidgetEditionEnabled(ui.kTypeEdit->lineEdit())) ui.kTypeEdit->setText(op.getMode());
@@ -1763,7 +1780,7 @@ void SKGOperationPluginWidget::onFastEdition()
             } else {
                 if (nbGroupedOp > 1) {
                     //It is a TRANSFER
-                    SKGOperationObject op2 = groupedOperations.at(0);
+                    SKGOperationObject op2(groupedOperations.at(0));
                     if (op2 == op) op2 = groupedOperations.at(1);
 
                     SKGAccountObject targetAccount;
@@ -1833,7 +1850,7 @@ void SKGOperationPluginWidget::displaySubOperations(const SKGOperationObject& iO
     SKGError err =  iOperation.getSubOperations(subOperations);
     nbSubOperations = subOperations.count();
     for (int i = 0; i < nbSubOperations; ++i) {
-        SKGSubOperationObject subOperation = subOperations.at(i);
+        SKGSubOperationObject subOperation(subOperations.at(i));
 
         SKGCategoryObject category;
         subOperation.getCategory(category);
@@ -2094,7 +2111,7 @@ void SKGOperationPluginWidget::onValidatePointedOperations()
     if (!err) {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Switch to checked"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
-            SKGOperationObject op = list[i];
+            SKGOperationObject op(list[i]);
             err = op.setStatus(SKGOperationObject::CHECKED);
             if (!err) err = op.save();
             if (!err) err = getDocument()->stepForward(i + 1);
