@@ -143,7 +143,7 @@ private Q_SLOTS:
     void fillTargetAccount();
 
 private:
-    Q_DISABLE_COPY(SKGOperationPluginWidget);
+    Q_DISABLE_COPY(SKGOperationPluginWidget)
 
     SKGError getSelectedOperation(SKGOperationObject& operation);
 
@@ -166,7 +166,7 @@ private:
     QString m_previousValue;
     QDomDocument m_lastState;
 
-    KAction* m_fastEditionAction;
+    QAction* m_fastEditionAction;
 
     QString m_lastFastEditionWhereClause;
     int m_lastFastEditionOperationFound;
