@@ -209,9 +209,9 @@ void SKGPayeePluginWidget::onModifyPayee()
             getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected payees. Payees have been merged."));
 
             //Do the merge
-            SKGPayeeObject payeeObj1 = selection[0];
+            SKGPayeeObject payeeObj1(selection[0]);
             for (int i = 1; !err && i < nb; ++i) {
-                SKGPayeeObject payeeObj = selection[i];
+                SKGPayeeObject payeeObj(selection[i]);
                 err = payeeObj1.merge(payeeObj);
             }
 
@@ -223,7 +223,7 @@ void SKGPayeePluginWidget::onModifyPayee()
 
         for (int i = 0; !err && i < nb; ++i) {
             //Modification of object
-            SKGPayeeObject payee = selection[i];
+            SKGPayeeObject payee(selection[i]);
             err = payee.setName(ui.kNameInput->text());
             if (!err) err = payee.setAddress(ui.kAddressEdit->text());
             if (!err) err = payee.save();
@@ -258,7 +258,7 @@ bool SKGPayeePluginWidget::isEditor()
 
 void SKGPayeePluginWidget::onDeleteUnused()
 {
-    KAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete_unused_payees");
+    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete_unused_payees");
     if (act) act->trigger();
 }
 
