@@ -28,21 +28,26 @@
 #include <kinputdialog.h>
 
 SKGReportBoardWidget::SKGReportBoardWidget(SKGDocumentBank* iDocument)
-    : SKGWidget(iDocument)
+    : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Report"), true)
 {
     SKGTRACEIN(10, "SKGReportBoardWidget::SKGReportBoardWidget");
 
-    ui.setupUi(this);
+    //This must be done at the beginning
+    this->setMinimumSize(200, 200);
+
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
+    KAction* open = new KAction(KIcon("skg_open"), i18nc("Verb, open a page", "Open..."), this);
+    connect(open, SIGNAL(triggered(bool)), this, SLOT(onOpen()));
+    addAction(open);
+
     m_menuRename = new KAction(KIcon("edit-rename"), i18nc("Verb, change the name of an item", "Rename"), this);
     connect(m_menuRename, SIGNAL(triggered(bool)), this, SLOT(onRenameTitle()));
     addAction(m_menuRename);
 
     m_graph = new SKGReportPluginWidget(iDocument, true);
-    ui.gridLayout->addWidget(m_graph, 0, 0, 1, 1);
-    this->setMinimumSize(200, 200);
+    setMainWidget(m_graph);
 
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
@@ -61,7 +66,7 @@ QString SKGReportBoardWidget::getState()
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
 
-    root.setAttribute("title", ui.kGroup->title());
+    root.setAttribute("title", getMainTitle());
     if (m_graph) root.setAttribute("graph", m_graph->getState());
     return doc.toString();
 
@@ -75,7 +80,7 @@ void SKGReportBoardWidget::setState(const QString& iState)
         QDomElement root = doc.documentElement();
 
         QString title = root.attribute("title");
-        if (!title.isEmpty()) ui.kGroup->setTitle(title);
+        if (!title.isEmpty()) setMainTitle(title);
 
 
         QString graphS = root.attribute("graph");
@@ -92,9 +97,9 @@ void SKGReportBoardWidget::onRenameTitle()
 {
     bool ok = false;
     QString newTitle = KInputDialog::getText(i18nc("Question", "Title"),
-                       i18nc("Question", "New title:"), ui.kGroup->title(), &ok, SKGMainPanel::getMainPanel());
+                       i18nc("Question", "New title:"), getMainTitle(), &ok, SKGMainPanel::getMainPanel());
     if (ok) {
-        ui.kGroup->setTitle(newTitle);
+        setMainTitle(newTitle);
     }
 }
 
@@ -111,16 +116,10 @@ void SKGReportBoardWidget::dataModified(const QString& iTableName, int iIdTransa
 
 void SKGReportBoardWidget::onOpen()
 {
-    ui.kGroup->setChecked(true);
-
     QDomDocument doc("SKGML");
     QString graphS;
     if (doc.setContent(getState())) {
         QDomElement root = doc.documentElement();
-
-        QString title = root.attribute("title");
-        if (!title.isEmpty()) ui.kGroup->setTitle(title);
-
         graphS = root.attribute("graph");
 
         QDomDocument doc2("SKGML");
