@@ -21,8 +21,7 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include "ui_skgreportboardwidget_board.h"
-#include "skgwidget.h"
+#include "skgboardwidget.h"
 
 class SKGReportPluginWidget;
 class SKGDocumentBank;
@@ -32,7 +31,7 @@ class KAction;
 /**
  * This file is Skrooge plugin for bank management
  */
-class SKGReportBoardWidget : public SKGWidget
+class SKGReportBoardWidget : public SKGBoardWidget
 {
     Q_OBJECT
 
@@ -68,11 +67,8 @@ private Q_SLOTS:
     void onRenameTitle();
 
 private:
-    Q_DISABLE_COPY(SKGReportBoardWidget);
-
-    Ui::skgreportboardwidget_board ui;
+    Q_DISABLE_COPY(SKGReportBoardWidget)
     SKGReportPluginWidget* m_graph;
-
     KAction* m_menuRename;
 };
 
