@@ -34,13 +34,13 @@ class SKGDocumentBank;
 class SKGReportPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGReportPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGReportPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -73,7 +73,7 @@ public:
      * @param iIndex the index of the widget
      * @return The dashboard widget of the plugin
      */
-    virtual SKGWidget* getDashboardWidget(int iIndex);
+    virtual SKGBoardWidget* getDashboardWidget(int iIndex);
 
     /**
      * The preference widget of the plugin.
@@ -138,22 +138,13 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
-
-    /**
-     * Must be implemented to execute the automatic correction for the advice.
-     * @param iAdviceIdentifier the identifier of the advice
-     * @param iSolution the identifier of the possible solution
-     * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
-     *   @see SKGError
-     */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
 private Q_SLOTS:
-    void actionOpenReport();
+    void onOpenReport();
 
 private:
-    Q_DISABLE_COPY(SKGReportPlugin);
+    Q_DISABLE_COPY(SKGReportPlugin)
 
     KAction* m_openReportAction;
     SKGDocumentBank* m_currentBankDocument;
