@@ -115,7 +115,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     //Init comboboxes
     m_attsForColumns << "d_date" << "d_DATEWEEK" << "d_DATEMONTH" << "d_DATEQUARTER" << "d_DATESEMESTER" << "d_DATEYEAR";
     m_attsForLines << "#NOTHING#" <<
-                   "t_ACCOUNTTYPE" << "t_ACCOUNT" <<
+                   "t_BANK" << "t_ACCOUNTTYPE" << "t_ACCOUNT" <<
                    "t_REALCATEGORY" <<
                    "t_PAYEE" <<
                    "t_TYPEEXPENSENLS" <<
@@ -295,7 +295,7 @@ void SKGReportPluginWidget::setState(const QString& iState)
     if (timeline.isEmpty()) timeline = '1';
     if (incomes.isEmpty()) incomes = 'Y';
     if (expenses.isEmpty()) expenses = 'Y';
-    if (transfers.isEmpty()) transfers = 'Y';
+    if (transfers.isEmpty()) transfers = 'N';
     if (grouped.isEmpty()) grouped = 'Y';
     if (tracked.isEmpty()) tracked = 'Y';
     if (currentPage.isEmpty()) currentPage = '0';
@@ -477,34 +477,7 @@ void SKGReportPluginWidget::onDoubleClick(int row, int column)
     QString wc;
     QString title;
     getWhereClauseAndTitleForSelection(row, column, wc, title);
-
-    //Open
-    if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
-        //Call debug plugin
-        QDomDocument doc("SKGML");
-        QDomElement root = doc.createElement("parameters");
-        doc.appendChild(root);
-        root.setAttribute("sqlOrder", "SELECT * from v_operation_consolidated WHERE " % wc);
-
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
-    } else {
-        //Call operation plugin
-        QDomDocument doc("SKGML");
-        doc.setContent(getDocument()->getParameter("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("operationTable", "v_operation_consolidated");
-        root.setAttribute("operationWhereClause", wc);
-        root.setAttribute("title", title);
-        root.setAttribute("title_icon", "view-investment");
-        root.setAttribute("currentPage", "-1");
-
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-    }
+    SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=view-investment&operationTable=v_operation_consolidated&operationWhereClause=" % SKGServices::encodeForUrl(wc) % "&title=" % SKGServices::encodeForUrl(title));
 }
 
 void SKGReportPluginWidget::onBtnModeClicked(int mode)
@@ -958,7 +931,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 
                                 doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create budgeted operations"), nb);
                                 for (int i = 0; !err && i < nb; ++i) {
-                                    SKGBudgetObject budget = budgets.at(i);
+                                    SKGBudgetObject budget(budgets.at(i));
 
                                     SKGCategoryObject cat;
                                     budget.getCategory(cat);
@@ -1029,7 +1002,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 if (!attCol.isEmpty()) condition = '(' % condition % ") AND " % attCol % " NOT LIKE '%#NULL#%'";
 
                 //Limit size of the result
-                condition = '(' % condition % ") AND d_date>date('now', '-50 year')";
+                condition = '(' % condition % ") AND (d_date>(SELECT date('now', '-50 year')) OR d_date='0000')";
 
                 QString coef;
                 if (ui.kCorrectedBy->currentIndex() > 0 && mode != 3) {
