@@ -45,7 +45,7 @@ K_PLUGIN_FACTORY(SKGScheduledPluginFactory, registerPlugin<SKGScheduledPlugin>()
  */
 K_EXPORT_PLUGIN(SKGScheduledPluginFactory("skrooge_scheduled", "skrooge_scheduled"))
 
-SKGScheduledPlugin::SKGScheduledPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGScheduledPlugin::SKGScheduledPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_counterAdvice(0)
 {
     SKGTRACEIN(10, "SKGScheduledPlugin::SKGScheduledPlugin");
 }
@@ -69,11 +69,9 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     //Create yours actions here
     m_scheduleOperationAction = new KAction(KIcon("skrooge_schedule"), i18nc("Verb, create a scheduled operation", "Schedule"), this);
-    connect(m_scheduleOperationAction, SIGNAL(triggered(bool)), this, SLOT(actionScheduleOperation()));
-    actionCollection()->addAction(QLatin1String("schedule_operation"), m_scheduleOperationAction);
+    connect(m_scheduleOperationAction, SIGNAL(triggered(bool)), this, SLOT(onScheduleOperation()));
     m_scheduleOperationAction->setShortcut(Qt::CTRL + Qt::Key_I);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("schedule_operation", m_scheduleOperationAction);
+    registerGlobalAction("schedule_operation", m_scheduleOperationAction);
     return true;
 }
 
@@ -123,7 +121,7 @@ QString SKGScheduledPlugin::getDashboardWidgetTitle(int iIndex)
     return "";
 }
 
-SKGWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGHtmlBoardWidget(m_currentBankDocument,
                                 getDashboardWidgetTitle(iIndex),
@@ -201,7 +199,7 @@ SKGError SKGScheduledPlugin::savePreferences() const
                 SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Conversion schedule"), err, nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     //Migration of existing schedule in template mode
-                    SKGRecurrentOperationObject recOp = recurrents.at(i);
+                    SKGRecurrentOperationObject recOp(recurrents.at(i));
                     SKGOperationObject operationObj;
 
                     if (!err) recOp.getParentOperation(operationObj);
@@ -262,10 +260,10 @@ SKGError SKGScheduledPlugin::scheduleOperation(const SKGOperationObject& iOperat
     return err;
 }
 
-void SKGScheduledPlugin::actionScheduleOperation()
+void SKGScheduledPlugin::onScheduleOperation()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGScheduledPlugin::actionScheduleOperation", err);
+    SKGTRACEINRC(10, "SKGScheduledPlugin::onScheduleOperation", err);
 
     //Get Selection
     if (SKGMainPanel::getMainPanel()) {
@@ -275,7 +273,7 @@ void SKGScheduledPlugin::actionScheduleOperation()
             QStringList list;
             SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Operation schedule"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
-                SKGOperationObject operationObj = selection.at(i);
+                SKGOperationObject operationObj(selection.at(i));
                 SKGRecurrentOperationObject rop;
                 err = scheduleOperation(operationObj, rop);
                 if (!err) err = m_currentBankDocument->stepForward(i + 1);
@@ -283,14 +281,8 @@ void SKGScheduledPlugin::actionScheduleOperation()
             }
 
             if (!err) {
-                //Call operation plugin
-                QDomDocument doc("SKGML");
-                QDomElement root = doc.createElement("parameters");
-                doc.appendChild(root);
-
-                root.setAttribute("selection", SKGServices::stringsToCsv(list));
-
-                SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge scheduled plugin"), -1, doc.toString());
+                //Open the scheduled operation
+                SKGMainPanel::getMainPanel()->openPage("skg://skrooge_scheduled_plugin/?selection=" % SKGServices::encodeForUrl(SKGServices::stringsToCsv(list)));
             }
         }
 
@@ -303,60 +295,77 @@ void SKGScheduledPlugin::actionScheduleOperation()
     }
 }
 
-SKGAdviceList SKGScheduledPlugin::advice() const
+SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGScheduledPlugin::advice");
     SKGAdviceList output;
 
     //Recurrent operation with the last inserted operation having a different amount
-    SKGStringListList result;
-    m_currentBankDocument->executeSelectSqliteOrder("SELECT r.id, r.rd_operation_id, r.f_CURRENTAMOUNT, r2.f_CURRENTAMOUNT FROM v_recurrentoperation_display r INNER JOIN (SELECT MAX(d_date), f_CURRENTAMOUNT, r_recurrentoperation_id FROM v_operation_display GROUP BY r_recurrentoperation_id) r2 WHERE r2.r_recurrentoperation_id=r.id AND r.f_CURRENTAMOUNT<>r2.f_CURRENTAMOUNT", result);
-    int nb = result.count();
-    for (int i = 1; i < nb; ++i) { //Ignore header
-        //Get parameters
-        QStringList line = result.at(i);
-        int idRecu = SKGServices::stringToInt(line.at(0));
-        QString idOper = line.at(1);
-        QString amountRecu = line.at(2);
-        QString amountLastOperation = line.at(3);
+    if (!iIgnoredAdvice.contains("skgscheduledplugin_notuptodate")) {
+        SKGTRACEIN(10, "SKGScheduledPlugin::advice-skgscheduledplugin_notuptodate");
+        SKGStringListList result;
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT r.id, r.rd_operation_id, r.f_CURRENTAMOUNT, r2.f_CURRENTAMOUNT FROM v_recurrentoperation_display r INNER JOIN (SELECT MAX(d_date), f_CURRENTAMOUNT, r_recurrentoperation_id FROM v_operation_display GROUP BY r_recurrentoperation_id) r2 WHERE r2.r_recurrentoperation_id=r.id AND r.f_CURRENTAMOUNT<>r2.f_CURRENTAMOUNT", result);
+        int nb = result.count();
+        for (int i = 1; i < nb; ++i) { //Ignore header
+            //Get parameters
+            QStringList line = result.at(i);
+            int idRecu = SKGServices::stringToInt(line.at(0));
+            QString idOper = line.at(1);
+            QString amountRecu = line.at(2);
+            QString amountLastOperation = line.at(3);
 
-        SKGRecurrentOperationObject recu(m_currentBankDocument, idRecu);
-        QString name = recu.getDisplayName();
+            SKGRecurrentOperationObject recu(m_currentBankDocument, idRecu);
+            QString name = recu.getDisplayName();
 
-        SKGAdvice ad;
-        ad.setUUID("skgscheduledplugin_notuptodate|" % idOper % ';' % amountLastOperation);
-        ad.setPriority(4);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled operation '%1' not uptodate", name));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled operation '%1' does not have the amount of the last inserted operation (%2)", name, amountLastOperation));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Update the operation amount (%1)", amountLastOperation));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+            SKGAdvice ad;
+            ad.setUUID("skgscheduledplugin_notuptodate|" % idOper % ';' % amountLastOperation);
+            ad.setPriority(4);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled operation '%1' not uptodate", name));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled operation '%1' does not have the amount of the last inserted operation (%2)", name, amountLastOperation));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Update the operation amount (%1)", amountLastOperation));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
 
     //Possible recurrent operations
-    m_currentBankDocument->executeSelectSqliteOrder("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1 WHERE op1.d_date>(SELECT date('now','-2 month')) AND op1.t_TRANSFER='N' AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND EXISTS (SELECT 1 FROM v_operation_tmp1 op2 WHERE op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.rc_unit_id=op2.rc_unit_id AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.d_date=(SELECT date(op2.d_date, '+1 month'))) AND NOT EXISTS (SELECT 1 FROM recurrentoperation ro, v_operation_tmp1 op2  WHERE ro.rd_operation_id=op2.id AND ro.i_period_increment=1 AND ro.t_period_unit='M' AND op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.rc_unit_id=op2.rc_unit_id)", result);
-    nb = result.count();
-    for (int i = 1; i < nb; ++i) { //Ignore header
-        //Get parameters
-        QStringList line = result.at(i);
-        QString id = line.at(0);
-        QString name = line.at(1);
+    if (!iIgnoredAdvice.contains("skgscheduledplugin_possibleschedule")) {
+        SKGTRACEIN(10, "SKGScheduledPlugin::advice-skgscheduledplugin_possibleschedule");
+        if (m_counterAdvice % 10 != 0) {
+            output.append(m_cacheAdvice);
+        } else {
+            m_cacheAdvice.clear();
+            SKGStringListList result;
+            m_currentBankDocument->executeSelectSqliteOrder("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1, v_operation_tmp1 op2 "
+                    "WHERE op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.rc_unit_id=op2.rc_unit_id AND op1.d_date>(SELECT date('now','-2 month')) AND op2.d_date>(SELECT date('now','-3 month')) "
+                    "AND op1.t_TRANSFER='N' AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.d_date=date(op2.d_date, '+1 month') "
+                    "AND NOT EXISTS (SELECT 1 FROM recurrentoperation ro, v_operation_tmp1 op2  WHERE ro.rd_operation_id=op2.id AND ro.i_period_increment=1 AND ro.t_period_unit='M' AND op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.f_QUANTITY=op2.f_QUANTITY AND op1.rc_unit_id=op2.rc_unit_id)", result);
+            int nb = result.count();
+            for (int i = 1; i < nb; ++i) { //Ignore header
+                //Get parameters
+                QStringList line = result.at(i);
+                QString id = line.at(0);
+                QString name = line.at(1);
 
-        SKGAdvice ad;
-        ad.setUUID("skgscheduledplugin_possibleschedule|" % id);
-        ad.setPriority(4);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Possible schedule '%1'", name));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "The operation '%1' seems to be regularly created and could be scheduled", name));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Monthly schedule the operation '%1'", name));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+                SKGAdvice ad;
+                ad.setUUID("skgscheduledplugin_possibleschedule|" % id);
+                ad.setPriority(4);
+                ad.setShortMessage(i18nc("Advice on making the best (short)", "Possible schedule '%1'", name));
+                ad.setLongMessage(i18nc("Advice on making the best (long)", "The operation '%1' seems to be regularly created and could be scheduled", name));
+                QStringList autoCorrections;
+                autoCorrections.push_back(i18nc("Advice on making the best (action)", "Monthly schedule the operation '%1'", name));
+                ad.setAutoCorrections(autoCorrections);
+                output.push_back(ad);
+                m_cacheAdvice.push_back(ad);
+            }
+        }
     }
+    m_counterAdvice++;
     return output;
 }
 
-SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     SKGError err;
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_notuptodate|"))) {
@@ -375,7 +384,7 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
 
             if (subOps.count() == 1) {
                 //Change the quantity of the sub operation
-                SKGSubOperationObject so1 = subOps.at(0);
+                SKGSubOperationObject so1(subOps.at(0));
                 if (!err) err = so1.setQuantity(amount);
                 if (!err) err = so1.save();
             } else if (subOps.count() >= 1) {
@@ -410,6 +419,8 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             if (!err) err = rop.setDate(op.getDate());
             if (!err) err = rop.setDate(rop.getNextDate());
             if (!err) err = rop.save(true, false);
+
+            m_counterAdvice = 0; //To force the update
         }
 
         //status bar
