@@ -45,7 +45,7 @@ K_PLUGIN_FACTORY(SKGSearchPluginFactory, registerPlugin<SKGSearchPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGSearchPluginFactory("skrooge_search", "skrooge_search"))
 
-SKGSearchPlugin::SKGSearchPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGSearchPlugin::SKGSearchPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGSearchPlugin::SKGSearchPlugin");
     m_timer.setSingleShot(true);
@@ -73,7 +73,7 @@ QString SKGSearchPlugin::getDashboardWidgetTitle(int iIndex)
     return "";
 }
 
-SKGWidget* SKGSearchPlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget* SKGSearchPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGAlarmBoardWidget(m_currentBankDocument);
     return NULL;
@@ -93,9 +93,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     //Execute on all operation
     m_executeAll = new KAction(KIcon("system-run"), i18nc("Verb, action to execute", "Execute on all operations"), this);
     connect(m_executeAll, SIGNAL(triggered(bool)), SLOT(execute()));
-    actionCollection()->addAction(QLatin1String("execute_all"), m_executeAll);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("execute_all", m_executeAll);
+    registerGlobalAction("execute_all", m_executeAll);
 
     //Execute on imported operation
     {
@@ -103,9 +101,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
         overlaycsv.push_back("document-import");
         m_executeImported = new KAction(KIcon("system-run", NULL, overlaycsv), i18nc("Verb, action to execute", "Execute on imported operations"), this);
         connect(m_executeImported, SIGNAL(triggered(bool)), SLOT(execute()));
-        actionCollection()->addAction(QLatin1String("execute_imported"), m_executeImported);
-
-        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("execute_imported", m_executeImported);
+        registerGlobalAction("execute_imported", m_executeImported);
     }
 
     //Execute on not validated
@@ -114,15 +110,12 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
         overlaycsv.push_back("dialog-ok-apply");
         m_executeNotValidated = new KAction(KIcon("system-run", NULL, overlaycsv), i18nc("Verb, action to execute", "Execute on not validated operations"), this);
         connect(m_executeNotValidated, SIGNAL(triggered(bool)), SLOT(execute()));
-        actionCollection()->addAction(QLatin1String("execute_not_validated"), m_executeNotValidated);
-
-        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("execute_not_validated", m_executeNotValidated);
+        registerGlobalAction("execute_not_validated", m_executeNotValidated);
     }
 
     //Search
     m_searchAction = actionCollection()->addAction(KStandardAction::Find, "edit_find", this, SLOT(find()));
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_find", m_searchAction);
+    registerGlobalAction("edit_find", m_searchAction);
 
     return true;
 }
@@ -158,7 +151,7 @@ void SKGSearchPlugin::raiseAlarms()
         int nb = rules.count();
         if (!err && nb) {
             for (int i = 0; !err && i < nb; ++i) {
-                SKGRuleObject rule = rules.at(i);
+                SKGRuleObject rule(rules.at(i));
                 rule.execute();
             }
         }
@@ -185,7 +178,7 @@ void SKGSearchPlugin::execute()
         if (sender() == m_executeImported) mode = SKGRuleObject::IMPORTED;
         else if (sender() == m_executeNotValidated) mode = SKGRuleObject::IMPORTEDNOTVALIDATE;
         for (int i = 0; !err && i < nb; ++i) {
-            SKGRuleObject rule = rules.at(i);
+            SKGRuleObject rule(rules.at(i));
             err = rule.execute(mode);
             if (!err) err = m_currentBankDocument->stepForward(i + 1);
         }
@@ -239,7 +232,7 @@ void SKGSearchPlugin::find()
 
                     elementElement.setAttribute("attribute", "t_REALCATEGORY");
                     elementElement.setAttribute("operator", "#ATT#='#V1S#'");
-                    SKGCategoryObject cat = selection.at(i);
+                    SKGCategoryObject cat(selection.at(i));
                     elementElement.setAttribute("value", cat.getFullName());
                 }
                 xmlsearchcondition = doc.toString();
@@ -308,18 +301,8 @@ void SKGSearchPlugin::find()
             }
         }
 
-        //Call report plugin
-        QDomDocument doc("SKGML");
-        if (m_currentBankDocument) doc.setContent(m_currentBankDocument->getParameter("SKGSEARCH_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("xmlsearchcondition", xmlsearchcondition);
-        root.setAttribute("currentPage", "0");
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge search plugin"), -1, doc.toString());
+        //Call search plugin
+        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_search_plugin/?currentPage=0&xmlsearchcondition=" % SKGServices::encodeForUrl(xmlsearchcondition));
     }
 }
 
@@ -375,33 +358,35 @@ bool SKGSearchPlugin::isInPagesChooser() const
     return true;
 }
 
-SKGAdviceList SKGSearchPlugin::advice() const
+SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGSearchPlugin::advice");
     SKGAdviceList output;
 
     //Alarms
-    SKGObjectBase::SKGListSKGObjectBase rules;
-    SKGError err = m_currentBankDocument->getObjects("v_rule", "t_action_type='A' ORDER BY i_ORDER", rules);
-    int nb = rules.count();
-    if (nb) {
-        SKGServices::SKGUnitInfo primary = m_currentBankDocument->getPrimaryUnit();
+    if (!iIgnoredAdvice.contains("skgsearchplugin_alarm")) {
+        SKGObjectBase::SKGListSKGObjectBase rules;
+        SKGError err = m_currentBankDocument->getObjects("v_rule", "t_action_type='A' ORDER BY i_ORDER", rules);
+        int nb = rules.count();
+        if (nb) {
+            SKGServices::SKGUnitInfo primary = m_currentBankDocument->getPrimaryUnit();
 
-        for (int i = 0; !err && i < nb; ++i) {
-            SKGRuleObject rule = rules.at(i);
-            SKGRuleObject::SKGAlarmInfo alarm = rule.getAlarmInfo();
+            for (int i = 0; !err && i < nb; ++i) {
+                SKGRuleObject rule(rules.at(i));
+                SKGRuleObject::SKGAlarmInfo alarm = rule.getAlarmInfo();
 
-            double percent = 100 * alarm.Amount / alarm.Limit;
-            if (percent >= 80) {
-                SKGAdvice ad;
-                ad.setUUID("skgsearchplugin_alarm|" % SKGServices::intToString(rule.getID()));
-                ad.setPriority(9);
-                ad.setShortMessage(alarm.Message);
-                ad.setLongMessage(i18nc("Advice on making the best (long)", "Take care to your alarms.<br> %1.<br>%2 / %3", alarm.Message, m_currentBankDocument->formatMoney(alarm.Amount, primary), m_currentBankDocument->formatMoney(alarm.Limit, primary)));
-                QStringList autoCorrections;
-                autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open operations corresponding to this alarm"));
-                ad.setAutoCorrections(autoCorrections);
-                output.push_back(ad);
+                double percent = 100 * alarm.Amount / alarm.Limit;
+                if (percent >= 70) {
+                    SKGAdvice ad;
+                    ad.setUUID("skgsearchplugin_alarm|" % SKGServices::intToString(rule.getID()));
+                    ad.setPriority(percent >= 90 ? 9 : 6);
+                    ad.setShortMessage(alarm.Message);
+                    ad.setLongMessage(i18nc("Advice on making the best (long)", "Take care to your alarms.<br> %1.<br>%2 / %3", alarm.Message, m_currentBankDocument->formatMoney(alarm.Amount, primary), m_currentBankDocument->formatMoney(alarm.Limit, primary)));
+                    QStringList autoCorrections;
+                    autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open operations corresponding to this alarm"));
+                    ad.setAutoCorrections(autoCorrections);
+                    output.push_back(ad);
+                }
             }
         }
     }
@@ -409,7 +394,7 @@ SKGAdviceList SKGSearchPlugin::advice() const
     return output;
 }
 
-SKGError SKGSearchPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+SKGError SKGSearchPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgsearchplugin_alarm|"))) {
         //Get parameters
