@@ -36,13 +36,13 @@ class KAction;
 class SKGSearchPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGSearchPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGSearchPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -75,7 +75,7 @@ public:
      * @param iIndex the index of the widget
      * @return The dashboard widget of the plugin
      */
-    virtual SKGWidget* getDashboardWidget(int iIndex);
+    virtual SKGBoardWidget* getDashboardWidget(int iIndex);
 
     /**
      * Must be modified to refresh widgets after a modification.
@@ -140,7 +140,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -149,7 +149,7 @@ public:
      * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
      *   @see SKGError
      */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution);
 
 private Q_SLOTS:
     void raiseAlarms();
@@ -157,7 +157,7 @@ private Q_SLOTS:
     void find();
 
 private:
-    Q_DISABLE_COPY(SKGSearchPlugin);
+    Q_DISABLE_COPY(SKGSearchPlugin)
 
 
     SKGDocumentBank* m_currentBankDocument;
