@@ -289,7 +289,7 @@ void SKGSearchPluginWidget::onModifyRule()
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Search and process update"), err);
         SKGObjectBase::SKGListSKGObjectBase rules = getSelectedObjects();
         if (rules.count() == 1) {
-            SKGRuleObject rule = rules.at(0);
+            SKGRuleObject rule(rules.at(0));
             if (!err) err = rule.setXMLSearchDefinition(ui.kQueryCreator->getXMLCondition());
             QString xml = getXMLActionDefinition();
             if (!err) err = rule.setActionType(xml.isEmpty() ? SKGRuleObject::SEARCH : SKGRuleObject::ActionType(ui.kWidgetSelector->getSelectedMode()));
@@ -319,7 +319,7 @@ void SKGSearchPluginWidget::onSelectionChanged()
     ui.kApply->setEnabled(nbSel > 0);
 
     if (nbSel > 0) {
-        SKGRuleObject rule = selection.at(0);
+        SKGRuleObject rule(selection.at(0));
         ui.kQueryCreator->setXMLCondition(rule.getXMLSearchDefinition());
 
         int index = qMax(0, ((int) rule.getActionType()));
@@ -356,7 +356,7 @@ void SKGSearchPluginWidget::onTop()
     {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Search update"), err, nb);
         for (int i = nb - 1; !err && i >= 0; --i) {
-            SKGRuleObject rule = rules.at(i);
+            SKGRuleObject rule(rules.at(i));
 
             double order = 1;
             SKGStringListList result;
@@ -389,7 +389,7 @@ void SKGSearchPluginWidget::onUp()
     {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Search update"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
-            SKGRuleObject rule = rules.at(i);
+            SKGRuleObject rule(rules.at(i));
 
             double order = rule.getOrder();
             SKGStringListList result;
@@ -428,7 +428,7 @@ void SKGSearchPluginWidget::onDown()
     {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Search update"), err, nb);
         for (int i = nb - 1; !err && i >= 0; --i) {
-            SKGRuleObject rule = rules.at(i);
+            SKGRuleObject rule(rules.at(i));
 
             double order = rule.getOrder();
             SKGStringListList result;
@@ -467,7 +467,7 @@ void SKGSearchPluginWidget::onBottom()
     {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Search update"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
-            SKGRuleObject rule = rules.at(i);
+            SKGRuleObject rule(rules.at(i));
 
             double order = 1;
             SKGStringListList result;
@@ -497,37 +497,26 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule, OpenMode iMode)
     QString wc = "i_SUBOPID in (SELECT i_SUBOPID FROM v_operation_prop WHERE " % iRule.getSelectSqlOrder() % ')';
     QString title = i18nc("Noun, a list of items", "Sub operations corresponding to rule '%1'",  iRule.getSearchDescription());
 
-    //Open
-    if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
-        //Call debug plugin
-        QDomDocument doc("SKGML");
-        QDomElement root = doc.createElement("parameters");
+    //Call operation plugin
+    QDomDocument doc("SKGML");
+    doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(iMode == TABLE ? "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS" : "SKGREPORT_DEFAULT_PARAMETERS"));
+    QDomElement root = doc.documentElement();
+    if (root.isNull()) {
+        root = doc.createElement("parameters");
         doc.appendChild(root);
-        root.setAttribute("sqlOrder", "SELECT * from v_operation_consolidated WHERE " % wc);
+    }
 
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
+    root.setAttribute("operationWhereClause", wc);
+    root.setAttribute("title", title);
+    root.setAttribute("title_icon", "edit-find");
+
+    if (iMode == TABLE) {
+        root.setAttribute("operationTable", "v_operation_consolidated");
+        root.setAttribute("currentPage", "-1");
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
     } else {
-        //Call operation plugin
-        QDomDocument doc("SKGML");
-        doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(iMode == TABLE ? "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS" : "SKGREPORT_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("operationWhereClause", wc);
-        root.setAttribute("title", title);
-        root.setAttribute("title_icon", "edit-find");
-
-        if (iMode == TABLE) {
-            root.setAttribute("operationTable", "v_operation_consolidated");
-            root.setAttribute("currentPage", "-1");
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-        } else {
-            root.setAttribute("period", "0");
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge report plugin"), -1, doc.toString());
-        }
+        root.setAttribute("period", "0");
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge report plugin"), -1, doc.toString());
     }
 }
 
@@ -539,7 +528,7 @@ void SKGSearchPluginWidget::onEditorModified()
     ui.kQueryInfo->setText("");
 
     if (nbSelect == 1) {
-        SKGRuleObject rule = selection.at(0);
+        SKGRuleObject rule(selection.at(0));
 
         //Build where clause and title
         QString wc = rule.getSelectSqlOrder();
