@@ -47,7 +47,7 @@ K_PLUGIN_FACTORY(SKGUnitPluginFactory, registerPlugin<SKGUnitPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGUnitPluginFactory("skrooge_unit", "skrooge_unit"))
 
-SKGUnitPlugin::SKGUnitPlugin(QObject* iParent, const QVariantList& /*iArg*/)
+SKGUnitPlugin::SKGUnitPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/)
     : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL),
       m_splitShareAction(NULL)
 {
@@ -73,11 +73,14 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
 
     //Menu
     m_splitShareAction = new KAction(KIcon("skrooge_split_stock"), i18nc("Verb", "Split share..."), this);
-    connect(m_splitShareAction, SIGNAL(triggered(bool)), this, SLOT(actionSplitShare()));
-    actionCollection()->addAction(QLatin1String("edit_split_stock"), m_splitShareAction);
+    connect(m_splitShareAction, SIGNAL(triggered(bool)), this, SLOT(onSplitShare()));
     m_splitShareAction->setShortcut(Qt::ALT + Qt::Key_Slash);
+    registerGlobalAction("edit_split_stock", m_splitShareAction);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_split_stock", m_splitShareAction);
+    //-----------
+    KAction* act = new KAction(KIcon(icon()), i18nc("Verb", "Delete unused units"), this);
+    connect(act, SIGNAL(triggered(bool)), this, SLOT(deleteUnusedUnits()));
+    registerGlobalAction("tool_delete_unused_units", act);
     return true;
 }
 
@@ -93,7 +96,7 @@ QString SKGUnitPlugin::getDashboardWidgetTitle(int iIndex)
     return "";
 }
 
-SKGWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGUnitBoardWidget(m_currentBankDocument);
     else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
@@ -111,7 +114,7 @@ void SKGUnitPlugin::refresh()
         if (m_splitShareAction) {
             SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
             if (selection.count() == 1 && selection.at(0).getRealTable() == "unit") {
-                SKGUnitObject unit = selection.at(0);
+                SKGUnitObject unit(selection.at(0));
                 m_splitShareAction->setEnabled(unit.getType() == SKGUnitObject::SHARE);
             } else {
                 m_splitShareAction->setEnabled(false);
@@ -154,7 +157,7 @@ void SKGUnitPlugin::refresh()
                             int nb = selection.count();
                             SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Automatic download of units"), err, nb);
                             for (int i = 0; !err && i < nb; ++i) {
-                                SKGUnitObject unit = selection.at(i);
+                                SKGUnitObject unit(selection.at(i));
                                 err = SKGUnitPluginWidget::downloadUnitValue(unit, SKGUnitPluginWidget::getDownloadModeFromSettings());
                                 if (!err) err = m_currentBankDocument->stepForward(i + 1);
                             }
@@ -231,10 +234,10 @@ bool SKGUnitPlugin::isInPagesChooser() const
     return true;
 }
 
-void SKGUnitPlugin::actionSplitShare()
+void SKGUnitPlugin::onSplitShare()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitPlugin::actionSplitShare", err);
+    SKGTRACEINRC(10, "SKGUnitPlugin::onSplitShare", err);
 
     //Get Selection
     if (SKGMainPanel::getMainPanel()) {
@@ -246,7 +249,7 @@ void SKGUnitPlugin::actionSplitShare()
                                                    i18nc("Question", "Ratio (2 means 2-for-1, 0.5 means 1-for-2):"), 2.0,
                                                    0, DBL_MAX, 8, &ok, SKGMainPanel::getMainPanel());
             if (ok) {
-                SKGUnitObject unit = selection.at(0);
+                SKGUnitObject unit(selection.at(0));
                 SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Split stock '%1' by '%2'", unit.getName(), ratio), err);
                 err = unit.split(ratio);
             }
@@ -261,7 +264,7 @@ void SKGUnitPlugin::actionSplitShare()
     }
 }
 
-SKGAdviceList SKGUnitPlugin::advice() const
+SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGUnitPlugin::advice");
     SKGAdviceList output;
@@ -272,104 +275,135 @@ SKGAdviceList SKGUnitPlugin::advice() const
     int nb = result.count();
 
     //Check primary unit
-    if (m_currentBankDocument->getPrimaryUnit().Name.isEmpty() && nb > 1) {
-        //Get unit
-        QString unit = result.at(1).at(1);
+    if (!iIgnoredAdvice.contains("skgunitplugin_primaryunit")) {
+        if (m_currentBankDocument->getPrimaryUnit().Name.isEmpty() && nb > 1) {
+            //Get unit
+            QString unit = result.at(1).at(1);
 
-        SKGAdvice ad;
-        ad.setUUID("skgunitplugin_primaryunit|" % unit);
-        ad.setPriority(8);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a primary currency"));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "To avoid misunderstanding and conflicts between units at conversion time, you should define a primary currency. It is the currency against which all other will be converted"));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as primary currency", unit));
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+            SKGAdvice ad;
+            ad.setUUID("skgunitplugin_primaryunit|" % unit);
+            ad.setPriority(8);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a primary currency"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "To avoid misunderstanding and conflicts between units at conversion time, you should define a primary currency. It is the currency against which all other will be converted"));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as primary currency", unit));
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
 
-        --nb;
+            --nb;
+        }
     }
 
     //Check secondary unit
-    if (m_currentBankDocument->getSecondaryUnit().Name.isEmpty() && nb > 1) {
-        //Get unit
-        QString unit = result.at(1).at(1);
+    if (!iIgnoredAdvice.contains("skgunitplugin_secondaryunit")) {
+        if (m_currentBankDocument->getSecondaryUnit().Name.isEmpty() && nb > 1) {
+            //Get unit
+            QString unit = result.at(1).at(1);
 
-        SKGAdvice ad;
-        ad.setUUID("skgunitplugin_secondaryunit|" % unit);
-        ad.setPriority(2);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a secondary currency"));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "When a secondary unit is defined, Skrooge will display it as an additional amount information."));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as secondary currency", unit));
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+            SKGAdvice ad;
+            ad.setUUID("skgunitplugin_secondaryunit|" % unit);
+            ad.setPriority(2);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a secondary currency"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "When a secondary unit is defined, Skrooge will display it as an additional amount information."));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as secondary currency", unit));
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
 
     //Shares not downloaded
-    m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name, t_internet_code from unit WHERE t_internet_code<>'' AND (julianday('now')-(SELECT MAX(julianday(d_date)) FROM unitvalue WHERE rd_unit_id=unit.id ))>30 OR NOT EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)", result);
-    nb = result.count();
-    for (int i = 1; i < nb; ++i) { //Ignore header
-        //Get parameters
-        QStringList line = result.at(i);
-        QString unit = line.at(0);
-        QString internet_code = line.at(1);
+    if (!iIgnoredAdvice.contains("skgunitplugin_notdownloaded")) {
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name, t_internet_code from unit WHERE t_internet_code<>'' AND (julianday('now')-(SELECT MAX(julianday(d_date)) FROM unitvalue WHERE rd_unit_id=unit.id ))>30 OR NOT EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)", result);
+        nb = result.count();
+        for (int i = 1; i < nb; ++i) { //Ignore header
+            //Get parameters
+            QStringList line = result.at(i);
+            QString unit = line.at(0);
+            QString internet_code = line.at(1);
 
-        SKGAdvice ad;
-        ad.setUUID("skgunitplugin_notdownloaded|" % unit);
-        ad.setPriority(5);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has not been downloaded for more than a month", unit));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget download units to have a better view of your accounts"));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
-        if (!internet_code.isEmpty()) autoCorrections.push_back(i18nc("Advice on making the best (action)", "Download '%1'", unit));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+            SKGAdvice ad;
+            ad.setUUID("skgunitplugin_notdownloaded|" % unit);
+            ad.setPriority(5);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has not been downloaded for more than a month", unit));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget download units to have a better view of your accounts"));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            if (!internet_code.isEmpty()) autoCorrections.push_back(i18nc("Advice on making the best (action)", "Download '%1'", unit));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
 
     //Check unused units
-    bool exist = false;
-    m_currentBankDocument->existObjects("unit", "t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)", exist);
-    if (exist) {
-        SKGAdvice ad;
-        ad.setUUID("skgunitplugin_unused");
-        ad.setPriority(5);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused units"));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing units for which no operation is registered."));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Delete unused units"));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+    if (!iIgnoredAdvice.contains("skgunitplugin_unused")) {
+        bool exist = false;
+        m_currentBankDocument->existObjects("unit", "t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)", exist);
+        if (exist) {
+            SKGAdvice ad;
+            ad.setUUID("skgunitplugin_unused");
+            ad.setPriority(5);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused units"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing units for which no operation is registered."));
+            QStringList autoCorrections;
+            autoCorrections.push_back("skg://tool_delete_unused_units");
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
+    }
+
+    //Check unit too complex
+    if (!iIgnoredAdvice.contains("skgunitplugin_toocomplex")) {
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT A.t_name FROM unit A, unit B, unit C, unit D WHERE A.rd_unit_id=B.id AND B.rd_unit_id=C.id AND C.rd_unit_id=D.id", result);
+        nb = result.count();
+        for (int i = 1; i < nb; ++i) { //Ignore header
+            //Get parameters
+            QStringList line = result.at(i);
+            QString unit = line.at(0);
+
+            SKGAdvice ad;
+            ad.setUUID("skgunitplugin_toocomplex");
+            ad.setPriority(9);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "The definition of the unit '%1' is too complex", unit));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "'%1' is defined relatively to another unit defined relatively to a third one. This is too complex and not supported by Skrooge.", unit));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
 
     //Unit with very old values
-    m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=date('now', '-50 year'))", result);
-    nb = result.count();
-    for (int i = 1; i < nb; ++i) { //Ignore header
-        //Get parameters
-        QStringList line = result.at(i);
-        QString unit = line.at(0);
+    if (!iIgnoredAdvice.contains("skgunitplugin_veryold")) {
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=(SELECT date('now', '-50 year')))", result);
+        nb = result.count();
+        for (int i = 1; i < nb; ++i) { //Ignore header
+            //Get parameters
+            QStringList line = result.at(i);
+            QString unit = line.at(0);
 
-        SKGAdvice ad;
-        ad.setUUID("skgunitplugin_veryold|" % unit);
-        ad.setPriority(3);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has very old values", unit));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "Unit '%1' has very old values. Check if this is normal."));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+            SKGAdvice ad;
+            ad.setUUID("skgunitplugin_veryold|" % unit);
+            ad.setPriority(3);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has very old values", unit));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "Unit '%1' has very old values. Check if this is normal.", unit));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
 
     return output;
 }
 
-SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_primaryunit|"))) {
         if (iSolution == 1) {
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"));
+            SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
         } else {
             //Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 26);
@@ -395,7 +429,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_secondaryunit|"))) {
         if (iSolution == 1) {
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"));
+            SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
         } else {
             //Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
@@ -421,7 +455,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_notdownloaded|"))) {
         if (iSolution == 0) {
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"));
+            SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
         } else {
             //Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
@@ -436,12 +470,12 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
             SKGMainPanel::displayErrorMessage(err);
         }
 
-        return SKGError();
-    } else if (iAdviceIdentifier == "skgunitplugin_unused") {
-        deleteUnusedUnits();
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_veryold|"))) {
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"));
+        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
+        return SKGError();
+    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_toocomplex"))) {
+        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
         return SKGError();
     }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
