@@ -49,6 +49,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     if (!iDocument) return;
 
     ui.setupUi(this);
+    ui.kGraph->setShadowVisible(false);
 
     ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay("t_name")));
     ui.kDecimalLbl->setText(i18n("%1:", iDocument->getDisplay("i_nbdecimal")));
@@ -336,7 +337,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
 
     //Draw plot
     SKGStringListList table;
-    getDocument()->getConsolidatedView("v_unitvalue_display", "d_date", "t_UNIT", "f_quantity", "TOTAL", wc % " AND d_date>date('now', '-50 year')" , table , "");
+    getDocument()->getConsolidatedView("v_unitvalue_display", "d_date", "t_UNIT", "f_quantity", "TOTAL", wc % " AND d_date>(SELECT date('now', '-50 year'))" , table , "");
 
     SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
     SKGServices::SKGUnitInfo secondaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
@@ -482,9 +483,9 @@ void SKGUnitPluginWidget::onModifyUnit()
             getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected units. Units have been merged."));
 
             //Do the merge
-            SKGUnitObject unitObj1 = selection[0];
+            SKGUnitObject unitObj1(selection[0]);
             for (int i = 1; !err && i < nb; ++i) {
-                SKGUnitObject unitObj = selection[i];
+                SKGUnitObject unitObj(selection[i]);
                 err = unitObj1.merge(unitObj);
             }
 
@@ -496,7 +497,7 @@ void SKGUnitPluginWidget::onModifyUnit()
 
         for (int i = 0; !err && i < nb; ++i) {
             //Modification of unit object
-            SKGUnitObject unitObj = selection[i];
+            SKGUnitObject unitObj(selection[i]);
             if (!err) err = unitObj.setName(ui.kNameCreatorUnit->text());
             if (!err) err = unitObj.setSymbol(ui.kSymbolCreatorUnit->text());
             if (!err) err = unitObj.setCountry(ui.kCountryCreatorUnit->text());
@@ -562,7 +563,8 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
     if (nb) {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Download values"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
-            err = downloadUnitValue(selection.at(i), mode);
+            SKGUnitObject unit(selection.at(i));
+            err = downloadUnitValue(unit, mode);
 
             if (!err) err = getDocument()->stepForward(i + 1);
         }
@@ -585,7 +587,7 @@ void SKGUnitPluginWidget::onSimplify()
     if (nb) {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Simplify unit values"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
-            SKGUnitObject unit = selection.at(i);
+            SKGUnitObject unit(selection.at(i));
             err = unit.simplify();
 
             if (!err) err = getDocument()->stepForward(i + 1);
@@ -798,7 +800,7 @@ void SKGUnitPluginWidget::onOpenURL()
     int nb = selection.count();
     if (nb) {
         for (int i = 0; !err && i < nb; ++i) {
-            SKGUnitObject unit = selection.at(i);
+            SKGUnitObject unit(selection.at(i));
             err = unit.openURL();
         }
     }
