@@ -251,7 +251,7 @@ bool SKGDataEngine::getAdviceData()
     while (index >= 0) {
         SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
         if (plugin) {
-            foreach(const SKGAdvice & advice, plugin->advice()) {
+            foreach(const SKGAdvice & advice, plugin->advice(ignoredAdvice)) {
                 if (!ignoredAdvice.contains(advice.getUUID()) && !ignoredAdvice.contains(SKGServices::splitCSVLine(advice.getUUID(), '|').at(0))) {
                     QVariantList values;
                     values.append(SKGServices::intToString(advice.getPriority()));
