@@ -81,7 +81,7 @@ void SKGObjectModel::buidCache()
     m_budgetRuleTable = (getRealTable() == "budgetrule");
 
     if (m_unitvalueTable) {
-        SKGUnitValueObject unitValObject = getObject(index(0, 0));
+        SKGUnitValueObject unitValObject(getObject(index(0, 0)));
         SKGUnitObject unitObject;
         unitValObject.getUnit(unitObject);
         SKGUnitObject parent;
@@ -364,7 +364,7 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
                 QString trackerName;
                 if (obj) trackerName = obj->getAttribute(att);
                 if (!trackerName.isEmpty()) {
-                    SKGTrackerObject tracker = SKGObjectBase(getDocument(), "refund"); //Better performance if v_refund is not used
+                    SKGTrackerObject tracker(SKGObjectBase(getDocument(), "refund")); //Better performance if v_refund is not used
                     tracker.setName(trackerName);
                     tracker.load();
 
@@ -380,7 +380,7 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
             }
         } else if (m_unitTable) {
             if (att == "f_CURRENTAMOUNT") {
-                SKGUnitObject unit = *obj;
+                SKGUnitObject unit(*obj);
                 double annualchange = 365 * unit.getDailyChange();
                 if (annualchange >= 15) return m_iconMuchMore;
                 else if (annualchange <= -15) return m_iconMuchLess;
@@ -533,7 +533,7 @@ else return KIcon();
 
             //Add balance
             if (m_operationTable) {
-                SKGOperationObject op = *obj;
+                SKGOperationObject op(*obj);
                 if (!op.isTemplate()) {
                     if (!toolTipString.isEmpty()) toolTipString += "\n\n";
                     SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
@@ -555,9 +555,9 @@ else return KIcon();
             }
         } else if (m_operationTable || m_recurrentoperationTable) {
             if (att == "t_imported") {
-                SKGOperationObject op = *obj;
+                SKGOperationObject op(*obj);
                 if (m_recurrentoperationTable) {
-                    SKGRecurrentOperationObject rop = *obj;
+                    SKGRecurrentOperationObject rop(*obj);
                     rop.getParentOperation(op);
                 }
                 toolTipString = op.getImportID();
@@ -565,16 +565,16 @@ else return KIcon();
                 QString trackerName;
                 if (obj) trackerName = obj->getAttribute(att);
                 if (!trackerName.isEmpty()) {
-                    SKGTrackerObject tracker = SKGObjectBase(getDocument(), "v_refund");
+                    SKGTrackerObject tracker(SKGObjectBase(getDocument(), "v_refund"));
                     tracker.setName(trackerName);
                     tracker.load();
                     SKGServices::SKGUnitInfo unit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
                     toolTipString = KGlobal::locale()->formatMoney(tracker.getCurrentAmount(), unit.Symbol, unit.NbDecimal);
                 }
             } else if (att == "t_CATEGORY") {
-                SKGOperationObject op = *obj;
+                SKGOperationObject op(*obj);
                 if (m_recurrentoperationTable) {
-                    SKGRecurrentOperationObject rop = *obj;
+                    SKGRecurrentOperationObject rop(*obj);
                     rop.getParentOperation(op);
                 }
                 if (SKGServices::stringToInt(op.getAttribute("i_NBSUBCATEGORY")) > 1) {
@@ -585,9 +585,9 @@ else return KIcon();
                     }
                 }
             } else if (att == "t_mode") {
-                SKGOperationObject op = *obj;
+                SKGOperationObject op(*obj);
                 if (m_recurrentoperationTable) {
-                    SKGRecurrentOperationObject rop = *obj;
+                    SKGRecurrentOperationObject rop(*obj);
                     rop.getParentOperation(op);
                 }
                 if (op.getAttribute("i_group_id") != "0") {
@@ -596,7 +596,8 @@ else return KIcon();
 
                     SKGObjectBase::SKGListSKGObjectBase gOps;
                     op.getGroupedOperations(gOps);
-                    foreach(const SKGOperationObject & gOp, gOps) {
+                    foreach(const SKGObjectBase & item, gOps) {
+                        SKGOperationObject gOp(item);
                         SKGAccountObject account;
                         gOp.getParentAccount(account);
                         toolTipString += account.getDisplayName() % '\n';
@@ -605,7 +606,7 @@ else return KIcon();
             }
 
             if (m_operationTable && toolTipString.isEmpty()) {
-                SKGOperationObject op = *obj;
+                SKGOperationObject op(*obj);
                 if (op.getStatus() == SKGOperationObject::POINTED) {
                     toolTipString = i18nc("A tool tip", "This operation is pointed but not checked yet.");
                     toolTipString += '\n';
@@ -656,20 +657,20 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
         SKGError err;
         {
             if (m_accountTable) {
-                SKGAccountObject obj = getObject(index);
+                SKGAccountObject obj(getObject(index));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
                                          ((Qt::CheckState) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
                 if (abs(obj.getCurrentAmount()) > 0.01) err = getDocument()->sendMessage(i18nc("An information message",  "Warning, you closed an account with money"));
                 if (!err) err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
                 if (!err) err = obj.save();
             } else if (m_trackerTable) {
-                SKGTrackerObject obj = getObject(index);
+                SKGTrackerObject obj(getObject(index));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
                                          ((Qt::CheckState) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open tracker '%1'", obj.getName())), err);
                 err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
                 if (!err) err = obj.save();
             } else if (m_operationTable) {
-                SKGOperationObject obj = getObject(index);
+                SKGOperationObject obj(getObject(index));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Change operation status"), err);
                 SKGOperationObject::OperationStatus statusinitial = obj.getStatus();
                 SKGOperationObject::OperationStatus t_status = statusinitial;
@@ -831,7 +832,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
 
         if (parent.isValid()) {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge payees"), err);
-            SKGPayeeObject parentPayee = getObject(parent);
+            SKGPayeeObject parentPayee(getObject(parent));
             while (!stream.atEnd() && !err) {
                 int o_id;
                 QString o_table;
@@ -850,7 +851,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
 
         if (parent.isValid()) {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge accounts"), err);
-            SKGAccountObject parentAccount = getObject(parent);
+            SKGAccountObject parentAccount(getObject(parent));
             while (!stream.atEnd() && !err) {
                 int o_id;
                 QString o_table;
@@ -869,7 +870,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
 
         if (parent.isValid()) {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge units"), err);
-            SKGUnitObject parentUnit = getObject(parent);
+            SKGUnitObject parentUnit(getObject(parent));
             while (!stream.atEnd() && !err) {
                 int o_id;
                 QString o_table;
@@ -888,7 +889,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
 
         if (parent.isValid()) {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge trackers"), err);
-            SKGTrackerObject trackerUnit = getObject(parent);
+            SKGTrackerObject trackerUnit(getObject(parent));
             while (!stream.atEnd() && !err) {
                 int o_id;
                 QString o_table;
