@@ -116,6 +116,9 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, c
             } else if (attribute == "t_ACCOUNT") {
                 realTable = "account";
                 realAtt = "t_name";
+            } else if (attribute == "t_REALCOMMENT") {
+                realTable = "suboperation";
+                realAtt = "t_comment";
             } else if (attribute == "t_REALREFUND") {
                 realTable = "refund";
                 realAtt = "t_name";
