@@ -75,7 +75,7 @@ private Q_SLOTS:
     void commitAndCloseEditor();
 
 private:
-    Q_DISABLE_COPY(SKGQueryDelegate);
+    Q_DISABLE_COPY(SKGQueryDelegate)
 
     SKGDocument* m_document;
     bool m_updateMode;
