@@ -359,7 +359,7 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
                                     " AND d_date<='" % SKGServices::dateToSqlString(QDateTime(lastDate)) % "' ORDER BY d_date", items);
     int nb = items.count();
     for (int i = 0; !err && i < nb; ++i) {
-        SKGOperationObject ob = items.at(i);
+        SKGOperationObject ob(items.at(i));
 
         SKGInterestItem itemI;
         itemI.object = ob;
@@ -384,7 +384,7 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
         int pos = 0;
         int nb = items.count();
         for (int i = 0; !err && i < nb; ++i) {
-            SKGInterestObject ob = items.at(i);
+            SKGInterestObject ob(items.at(i));
 
             SKGInterestItem itemI;
             itemI.object = ob;
@@ -440,9 +440,9 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
             err = computeInterestItems(oInterestList, oInterests, y);
         } else {
             //Drop temporary table
-            if (!err) {
-                err = getDocument()->executeSqliteOrder("DROP TABLE IF EXISTS interest_result");
-            }
+            if (!err) err = getDocument()->executeSqliteOrder("DROP TABLE IF EXISTS interest_result");
+            //Create fake table
+            if (!err) err = getDocument()->executeSqliteOrder("CREATE TEMP TABLE interest_result(a)");
         }
     }
     return err;
@@ -475,7 +475,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
         SKGObjectBase object = tmp.object;
         if (object.getRealTable() == "operation") {
             //Get operations
-            SKGOperationObject op = object;
+            SKGOperationObject op(object);
 
             //Get current amount
             tmp.amount = op.getCurrentAmount();
@@ -484,7 +484,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
             SKGInterestObject::ValueDateMode valueMode = SKGInterestObject::FIFTEEN;
             SKGInterestObject::InterestMode baseMode = SKGInterestObject::FIFTEEN24;
             if (currentInterest.object.getRealTable() == "interest") {
-                SKGInterestObject interestObj = currentInterest.object;
+                SKGInterestObject interestObj(currentInterest.object);
                 valueMode = (tmp.amount >= 0 ? interestObj.getIncomeValueDateMode() : interestObj.getExpenditueValueDateMode());
                 baseMode = interestObj.getInterestComputationMode();
 
@@ -641,7 +641,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         int limit = -1;
         bool moreThanOneSoluceFound = false;
         for (int i = 0; !moreThanOneSoluceFound && !err && i < nb; ++i) {
-            SKGOperationObject op = operations.at(i);
+            SKGOperationObject op(operations.at(i));
             double amount = op.getCurrentAmount();
             diff += amount;
             sdiff = doc->formatMoney(diff, unit1);
@@ -657,7 +657,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         //Check all
         if (limit != -1) {
             for (int i = 0; !err && i <= limit; ++i) {
-                SKGOperationObject op = operations.at(i);
+                SKGOperationObject op(operations.at(i));
                 err = op.setStatus(SKGOperationObject::POINTED);
                 if (!err) err = op.save(true, false);
             }
@@ -688,7 +688,7 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
     if (!err) err = iAccount.getOperations(ops);
     int nb = ops.count();
     for (int i = 0; !err && i < nb; ++i) {
-        SKGOperationObject op = ops.at(i);
+        SKGOperationObject op(ops.at(i));
         err = op.setParentAccount(*this);
         if (!err) err = op.save(true, false);
     }
