@@ -61,9 +61,18 @@ QString SKGBudgetObject::getWhereclauseId() const
     //Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
     if (output.isEmpty()) {
-        output = "i_year=" % getAttribute("i_year") % " AND "
-                 "i_month=" % getAttribute("i_month") % " AND "
-                 "rc_category_id=" % (getAttribute("rc_category_id").isEmpty() ? "0" : getAttribute("rc_category_id"));
+        QString y = getAttribute("i_year");
+        if (!y.isEmpty()) output = "i_year=" % y;
+
+        QString m = getAttribute("i_month");
+        if (!m.isEmpty()) {
+            if (!output.isEmpty()) output = output % " AND ";
+            output = output % "i_month=" % m;
+        }
+
+        QString r = getAttribute("rc_category_id");
+        if (!output.isEmpty()) output = output % " AND ";
+        output = output % "rc_category_id=" % (r.isEmpty() ? "0" : r);
     }
     return output;
 }
@@ -158,7 +167,7 @@ SKGError SKGBudgetObject::process()
     if (!err && nb) {
         err = getDocument()->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Apply budget rules"), nb);
         for (int i = 0; !err && i < nb; ++i) {
-            SKGBudgetRuleObject rule = budgetsRules.at(0);
+            SKGBudgetRuleObject rule(budgetsRules.at(i));
 
             //Do we have something to do
             SKGBudgetRuleObject::Condition cond = rule.getCondition();
@@ -170,12 +179,12 @@ SKGError SKGBudgetObject::process()
                     double value = (rule.isAbolute() ? (cond == SKGBudgetRuleObject::NEGATIVE ? qMax(delta, quantity) : qMin(delta, quantity)) : quantity * delta / 100.0);
 
                     //Get impacted budget
-                    SKGBudgetObject impactedBudget;
+                    SKGBudgetObject impactedBudget = *this;
+                    impactedBudget.resetID();
+
                     SKGBudgetRuleObject::Mode mode = rule.getTransferMode();
                     if (mode == SKGBudgetRuleObject::NEXT) {
                         //Next
-                        impactedBudget = *this;
-                        err = impactedBudget.resetID();
                         if (m == 0) {
                             //Yearly budget
                             ++y;
@@ -191,6 +200,7 @@ SKGError SKGBudgetObject::process()
                         if (!err) err = impactedBudget.setMonth(m);
                     } else if (mode == SKGBudgetRuleObject::YEAR) {
                         //Year
+                        if (!err) err = impactedBudget.setYear(y);
                         if (!err) err = impactedBudget.setMonth(0);
                     }
 
@@ -201,17 +211,20 @@ SKGError SKGBudgetObject::process()
                         err = impactedBudget.setCategory(transferCategory);
                     }
 
-                    if (!err && impactedBudget.exist()) {
-                        err = impactedBudget.load();
-                        QString newBudget = SKGServices::doubleToString(budgeted - value);
-                        if (!err) err = impactedBudget.setAttribute("f_budgeted_modified", newBudget);
-                        if (!err) err = impactedBudget.save();
+                    if (!err) {
+                        if (impactedBudget.exist()) {
+                            err = impactedBudget.load();
+                            QString newBudget = SKGServices::doubleToString(budgeted - value);
+                            if (!err) err = impactedBudget.setAttribute("f_budgeted_modified", newBudget);
+                            if (!err) err = impactedBudget.save();
 
-                        transferred += value;
-                        if (!err) err = setAttribute("f_transferred", SKGServices::doubleToString(transferred));
-                        if (!err) err = save();
+                            transferred += value;
+                            if (!err) err = setAttribute("f_transferred", SKGServices::doubleToString(transferred));
+                            if (!err) err = save();
+                        } else {
+                            getDocument()->sendMessage(i18nc("", "Impossible to apply the rule '%1' for budget '%2' because the impacted budget does not exist", rule.getDisplayName(), this->getDisplayName()));
+                        }
                     }
-                    //SKGBudgetObject budget(iDocument, id);
                 }
             }
             if (!err) err = getDocument()->stepForward(i + 1);
@@ -224,7 +237,7 @@ SKGError SKGBudgetObject::process()
     return err;
 }
 
-SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int iYear, int iBaseYear, bool iRemovePreviousBudget)
+SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int iYear, int iBaseYear, bool iUseScheduledOperation, bool iRemovePreviousBudget)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGBudgetObject::createAutomaticBudget", err);
@@ -250,13 +263,16 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
                       ") GROUP BY t_REALCATEGORY ORDER BY COUNT(TOT) DESC, (MAX(TOT)-MIN(TOT))/ABS(ROUND(TOTAL(TOT)/COUNT(TOT))) ASC, ROUND(TOTAL(TOT)/COUNT(TOT)) ASC";
         err = iDocument->executeSelectSqliteOrder(sql, listTmp);
 
+
+        //SELECT r.d_date,r.i_period_increment,r.t_period_unit, r.i_nb_times, r. t_times, r.t_CATEGORY, r.f_CURRENTAMOUNT  FROM v_recurrentoperation_display r WHERE r.t_TRANSFER='N'
+
         double sumBudgeted = 0;
         double sumOps = 0;
 
         int nbval = listTmp.count();
         if (!err && iDocument) {
             int step = 0;
-            err = iDocument->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create automatic budget"), nbval - 1 + 1);
+            err = iDocument->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create automatic budget"), nbval - 1 + 1 + (iRemovePreviousBudget ? 1 : 0));
 
             //Remove previous budgets
             if (iRemovePreviousBudget) {
