@@ -262,7 +262,7 @@ SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
     if (!err) err = iCategory.getSubOperations(ops);
     int nb = ops.count();
     for (int i = 0; !err && i < nb; ++i) {
-        SKGSubOperationObject op = ops.at(i);
+        SKGSubOperationObject op(ops.at(i));
         err = op.setCategory(*this);
         if (!err) err = op.save(true, false);
     }
@@ -271,7 +271,7 @@ SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
     if (!err) err = iCategory.getCategories(cats);
     nb = cats.count();
     for (int i = 0; !err && i < nb; ++i) {
-        SKGCategoryObject cat = cats.at(i);
+        SKGCategoryObject cat(cats.at(i));
         err = cat.setParentCategory(*this);
         if (!err) err = cat.save(true, false);
     }
