@@ -80,14 +80,22 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
     SKGTRACEINRC(10, "SKGImportExportManager::getDefaultAccount", err);
     if (m_defaultAccount == NULL && m_document) {
         QFileInfo fInfo(m_fileName);
-        QString name = fInfo.baseName();
+        QStringList items = fInfo.baseName().split('@');
+        QString bankname;
+        QString number;
+        QString name = items.at(0);
+        if (items.count() == 2) bankname = items.at(1);
+        else bankname = name;
         name.replace('_', ' ');
+        name.replace('-', ' ');
+        QRegExp rx("(\\d+)");
+        if (rx.indexIn(name) != -1) number = rx.cap(1);
 
         //Searching if an account exist
         QString whereClause = "t_name='" % name % '\'';
         foreach(const QString & val, name.split(' ')) {
             if (!whereClause.isEmpty()) whereClause += " OR ";
-            whereClause += "t_number='" % val % '\'';
+            whereClause += "t_number='" % val % "'";
         }
         if (!whereClause.isEmpty()) {
             SKGObjectBase::SKGListSKGObjectBase listAccount;
@@ -95,7 +103,7 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
             if (!err) {
                 if (listAccount.count() == 1) {
                     //Yes ! Only one account found
-                    SKGAccountObject account = listAccount.at(0);
+                    SKGAccountObject account(listAccount.at(0));
                     m_defaultAccount = new SKGAccountObject(account);
                     err = m_document->sendMessage(i18nc("An information message",  "Using account '%1' for import", account.getName()));
                 } else if (listAccount.count() > 1) {
@@ -108,10 +116,11 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         if (m_defaultAccount == NULL) {
             SKGAccountObject account;
             SKGBankObject bank(m_document);
-            if (!err) err = bank.setName(name);
+            if (!err) err = bank.setName(bankname);
             if (!err && bank.load().isFailed()) err = bank.save(false);    //Save only
             if (!err) err = bank.addAccount(account);
             if (!err) err = account.setName(name);
+            if (!err) err = account.setNumber(number);
             if (!err && account.load().isFailed()) err = account.save(false);    //Save only
             if (!err) m_defaultAccount = new SKGAccountObject(account);
             if (!err) err = m_document->sendMessage(i18nc("An information message",  "Default account '%1' created for import", name));
@@ -194,11 +203,31 @@ void SKGImportExportManager::setAutomaticValidation(bool iValidation)
     m_automaticValidationOfImportedOperation = iValidation;
 }
 
+bool SKGImportExportManager::automaticValidation() const
+{
+    return m_automaticValidationOfImportedOperation;
+}
+
 void SKGImportExportManager::setAutomaticApplyRules(bool iValidation)
 {
     m_automaticApplyRulesOfImportedOperation = iValidation;
 }
 
+bool SKGImportExportManager::automaticApplyRules() const
+{
+    return m_automaticApplyRulesOfImportedOperation;
+}
+
+void SKGImportExportManager::setSinceLastImportDate(bool iSinceLast)
+{
+    m_since_last_import = iSinceLast;
+}
+
+bool SKGImportExportManager::sinceLastImportDate() const
+{
+    return m_since_last_import;
+}
+
 SKGError SKGImportExportManager::finalizedImportedOperations()
 {
     SKGError err;
@@ -215,8 +244,19 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
             if (!err) err = m_document->executeSqliteOrder("DELETE from operation WHERE id IN (SELECT id from v_operation WHERE " % wc % ')');
         }
 
+        //Delete operations before the last import
+        if (m_since_last_import && !err) {
+            SKGTRACEINRC(2, "SKGImportExportManager::finalizedImportedOperations-deletebeforelastimport", err);
+            err = m_document->executeSqliteOrder("DELETE FROM operation WHERE operation.t_imported='T' AND "
+                                                 "EXISTS(SELECT 1 FROM operation o WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND o.d_date>=operation.d_date)");
+        }
+
+        //For performances
+        if (!err) err = m_document->executeSqliteOrder("ANALYZE");
+
         //Apply rules
         if (!err && m_automaticApplyRulesOfImportedOperation) {
+            SKGTRACEINRC(2, "SKGImportExportManager::finalizedImportedOperations-applyrules", err);
             //Get rules
             SKGObjectBase::SKGListSKGObjectBase rules;
             err = m_document->getObjects("v_rule", "1=1 ORDER BY f_sortorder", rules);
@@ -224,7 +264,7 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
             int nb = rules.count();
             err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Finalize import"), nb);
             for (int i = 0; !err && i < nb; ++i) {
-                SKGRuleObject rule = rules.at(i);
+                SKGRuleObject rule(rules.at(i));
                 err = rule.execute(SKGRuleObject::IMPORTING);
                 if (!err) err = m_document->stepForward(i + 1);
             }
@@ -237,9 +277,12 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
         }
 
         //Change imported status
-        if (!err) err = m_document->executeSqliteOrder(QString("UPDATE operation SET t_imported='") %
-                            (m_automaticValidationOfImportedOperation ? "Y" : "P") %
-                            "' WHERE t_imported='T'");
+        if (!err) {
+            SKGTRACEINRC(2, "SKGImportExportManager::finalizedImportedOperations-setfinalstatus", err);
+            err = m_document->executeSqliteOrder(QString("UPDATE operation SET t_imported='") %
+                                                 (m_automaticValidationOfImportedOperation ? "Y" : "P") %
+                                                 "' WHERE t_imported='T'");
+        }
     }
     return err;
 }
@@ -467,7 +510,7 @@ SKGError SKGImportExportManager::cleanBankImport()
 
             int nb = operations.count();
             for (int i = 0; !err && i < nb ; ++i) {
-                SKGOperationObject op = operations[i];
+                SKGOperationObject op(operations[i]);
 
                 //Comment is like this: <TYPE>  <INFO>
                 //Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
@@ -493,7 +536,7 @@ SKGError SKGImportExportManager::cleanBankImport()
 
             nb = operations.count();
             for (int i = 0; !err && i < nb ; ++i) {
-                SKGOperationObject op = operations[i];
+                SKGOperationObject op(operations[i]);
 
                 //Comment is like this: <TYPE> <INFO>
                 //Example: RETRAIT DAB 14-05-16607-482390
@@ -519,7 +562,7 @@ SKGError SKGImportExportManager::cleanBankImport()
 
             nb = operations.count();
             for (int i = 0; !err && i < nb ; ++i) {
-                SKGOperationObject op = operations[i];
+                SKGOperationObject op(operations[i]);
 
                 //Comment is like this: <TYPE>  <INFO>
                 //Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
