@@ -39,11 +39,11 @@ class SKGImportPlugin;
  */
 class SKGBANKMODELER_EXPORT SKGImportExportManager : public QObject
 {
-    Q_OBJECT;
+    Q_OBJECT
     /**
      * This enumerate defines dump modes
      */
-    Q_ENUMS(ImportExportMode);
+    Q_ENUMS(ImportExportMode)
 
 public:
     /**
@@ -94,18 +94,39 @@ public:
     /**
      * Enable/disable the automatically validation of imported operations.
      * @param iValidation the mode.
-     * @return an object managing the error.
-     *   @see SKGError
      */
     virtual void setAutomaticValidation(bool iValidation);
+
+    /**
+     * get the automatic validation state
+     * @return The automatic validation state.
+     */
+    virtual bool automaticValidation() const;
+
     /**
      * Enable/disable the automatically rules application on imported operations.
      * @param iApply the mode.
-     * @return an object managing the error.
-     *   @see SKGError
      */
     virtual void setAutomaticApplyRules(bool iApply);
 
+    /**
+    * get the automatic apply rules state
+    * @return The automatic apply rules state.
+    */
+    virtual bool automaticApplyRules() const;
+
+    /**
+     * To authorize the import of operations after the last imported operation
+     * @param iSinceLast the mode.
+     */
+    virtual void setSinceLastImportDate(bool iSinceLast);
+
+    /**
+    * get the since last import state
+    * @return The since last import state.
+    */
+    virtual bool sinceLastImportDate() const;
+
     /**
      * Get parameters for Import
      * @return the parameters
@@ -217,7 +238,7 @@ public:
      */
     virtual SKGError finalizedImportedOperations();
 private:
-    Q_DISABLE_COPY(SKGImportExportManager);
+    Q_DISABLE_COPY(SKGImportExportManager)
 
 
     SKGImportPlugin* getImportPlugin();
@@ -231,6 +252,7 @@ private:
     QString m_codec;
     bool m_automaticValidationOfImportedOperation;
     bool m_automaticApplyRulesOfImportedOperation;
+    bool m_since_last_import;
     SKGImportPlugin* m_importPlugin;
     SKGImportPlugin* m_exportPlugin;
 };
