@@ -80,7 +80,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
         err = getSubOperations(subops);
         int nbsupops = subops.count();
         for (int i = 0; !err && i < nbsupops; ++i) {
-            SKGSubOperationObject subop = subops.at(i);
+            SKGSubOperationObject subop(subops.at(i));
             err = subop.resetID();
             if (!err) err = subop.setParentOperation(oOperation);
             if (!err) err = subop.save(false);    //Just an insert
@@ -93,7 +93,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
         err = getGroupedOperations(goupops);
         int nbgoupops = goupops.count();
         for (int i = 0; !err && i < nbgoupops; ++i) {
-            SKGOperationObject groupop = goupops.at(i);
+            SKGOperationObject groupop(goupops.at(i));
             if (groupop != *this) {
                 //Create the duplicated operation
                 SKGOperationObject newgroupop = groupop;
@@ -115,7 +115,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
                     err = groupop.getSubOperations(subops);
                     int nbsupops = subops.count();
                     for (int i = 0; !err && i < nbsupops; ++i) {
-                        SKGSubOperationObject subop = subops.at(i);
+                        SKGSubOperationObject subop(subops.at(i));
                         err = subop.resetID();
                         if (!err) err = subop.setParentOperation(newgroupop);
                         if (!err) err = subop.save(false);    //Just an insert
@@ -466,8 +466,8 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
 
         if (subOps2.count() == 1 && subOps1.count() == 1) {
             //Change the quantity of the sub operation
-            SKGSubOperationObject so1 = subOps1.at(0);
-            SKGSubOperationObject so2 = subOps2.at(0);
+            SKGSubOperationObject so1(subOps1.at(0));
+            SKGSubOperationObject so2(subOps2.at(0));
             if (!err) err = so1.setQuantity(so2.getQuantity());
             if (!err) err = so1.save();
         } else if (subOps2.count() >= 1 && subOps1.count() >= 1) {
@@ -492,7 +492,7 @@ SKGError SKGOperationObject::mergeSuboperations(const SKGOperationObject& iDelet
     err = iDeletedOne.getSubOperations(subops);
     int nb = subops.count();
     for (int i = 0; !err && i < nb; ++i) {
-        SKGSubOperationObject subop = subops.at(i);
+        SKGSubOperationObject subop(subops.at(i));
         err = subop.setParentOperation(*this);
         if (!err) err = subop.save();
     }
