@@ -35,11 +35,11 @@ class SKGPayeeObject;
  */
 class SKGBANKMODELER_EXPORT SKGOperationObject : public SKGObjectBase
 {
-    Q_OBJECT;
+    Q_OBJECT
     /**
      * This enumerate defines status for operations
      */
-    Q_ENUMS(OperationStatus);
+    Q_ENUMS(OperationStatus)
 public:
 
     /**
@@ -61,7 +61,7 @@ public:
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGOperationObject(const SKGObjectBase& iObject);
+    explicit SKGOperationObject(const SKGObjectBase& iObject);
 
     /**
      * Copy constructor
