@@ -125,7 +125,7 @@ SKGError SKGPayeeObject::merge(const SKGPayeeObject& iPayee)
     if (!err) err = iPayee.getOperations(ops);
     int nb = ops.count();
     for (int i = 0; !err && i < nb; ++i) {
-        SKGOperationObject op = ops.at(i);
+        SKGOperationObject op(ops.at(i));
         err = op.setPayee(*this);
         if (!err) err = op.save(true, false);
     }
