@@ -277,7 +277,7 @@ SKGError SKGRecurrentOperationObject::process(SKGDocumentBank* iDocument, int& o
 
     int nb = recuOps.count();
     for (int i = 0; !err && i < nb; ++i) {
-        SKGRecurrentOperationObject recu = recuOps.at(i);
+        SKGRecurrentOperationObject recu(recuOps.at(i));
         int nbi = 0;
         err = recu.process(nbi, iForce, iDate);
         oNbInserted += nbi;
