@@ -118,7 +118,7 @@ QVariantList SKGReportBank::getPortfolio()
                     current.currentAmount = 0.0;
                     current.quantity = 0.0;
                     for (int i = 0; i < nb; ++i) {
-                        SKGOperationObject obj = objs.at(i);
+                        SKGOperationObject obj(objs.at(i));
                         SKGUnitObject unit;
                         obj.getUnit(unit);
                         if (i != 0 && current.unit != unit) {
@@ -136,7 +136,7 @@ QVariantList SKGReportBank::getPortfolio()
                         obj.getGroupedOperations(oGroupedOperations);
                         oGroupedOperations.removeAll(obj);
                         if (oGroupedOperations.count() == 1) {
-                            SKGOperationObject obj2 = oGroupedOperations.at(0);
+                            SKGOperationObject obj2(oGroupedOperations.at(0));
                             current.purchaseAmount += obj2.getAmount(obj.getDate());
                         }
                         current.quantity += SKGServices::stringToDouble(obj.getAttribute("f_QUANTITY"));
@@ -197,7 +197,8 @@ QVariantList SKGReportBank::getUnitTable()
                          << "%"
                          << doc->getDisplay("t_symbol");
                     table << QVariant(line);
-                    foreach(const SKGUnitObject & unit, units) {
+                    foreach(const SKGObjectBase & item, units) {
+                        SKGUnitObject unit(item);
                         double v1 = unit.getAmount(date1);
                         double v2 = unit.getAmount(date2);
                         QVariantList line;
@@ -246,7 +247,7 @@ QVariantList SKGReportBank::getAccountTable()
                     QString currentType;
                     int nb = accounts.count();
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGAccountObject account = accounts.at(i);
+                        SKGAccountObject account(accounts.at(i));
                         double v1 = account.getAmount(date1);
                         double v2 = account.getAmount(date2);
                         double v3 = account.getAmount(date3);
@@ -327,7 +328,7 @@ QVariantList SKGReportBank::getBankTable()
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
                 SKGObjectBase::SKGListSKGObjectBase accounts;
-                SKGError err = doc->getObjects("v_account_display", "1=1 ORDER BY t_BANK", accounts);
+                SKGError err = doc->getObjects("v_account", "1=1 ORDER BY t_BANK", accounts);
                 if (!err) {
                     QVariantList line;
                     line << "sum" << doc->getDisplay("t_BANK") << locale->formatDate(date1, KLocale::ShortDate) << locale->formatDate(date2, KLocale::ShortDate) <<
@@ -344,7 +345,7 @@ QVariantList SKGReportBank::getBankTable()
                     bool currentOpen = false;
                     int nb = accounts.count();
                     for (int i = 0; !err && i < nb; ++i) {
-                        SKGAccountObject account = accounts.at(i);
+                        SKGAccountObject account(accounts.at(i));
                         double v1 = account.getAmount(date1);
                         double v2 = account.getAmount(date2);
                         double v3 = account.getAmount(date3);
@@ -354,9 +355,9 @@ QVariantList SKGReportBank::getBankTable()
                             QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
                             icon = dirLogo.absoluteFilePath(icon);
                         }
-                        currentOpen = currentOpen || !account.isClosed();
-                        if (type != currentType && currentOpen) {
-                            if (!currentType.isEmpty()) {
+                        bool open = !account.isClosed();
+                        if (type != currentType) {
+                            if (!currentType.isEmpty() && currentOpen) {
                                 QVariantList line;
                                 line << false << currentType << sumTypeV1 << sumTypeV2 <<
                                      (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2 << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3)) <<
@@ -365,11 +366,12 @@ QVariantList SKGReportBank::getBankTable()
                                 sumTypeV1 = 0;
                                 sumTypeV2 = 0;
                                 sumTypeV3 = 0;
-                                currentOpen = false;
+                                currentOpen = open;
                             }
                             currentType = type;
                             currentIcon = icon;
                         }
+                        currentOpen = currentOpen || open;
 
                         sumTypeV1 += v1;
                         sumTypeV2 += v2;
@@ -412,7 +414,7 @@ QVariantList SKGReportBank::getScheduledOperations()
             int nb = objs.count();
             if (nb) {
                 for (int i = 0; i < nb; ++i) {
-                    SKGRecurrentOperationObject obj = objs.at(i);
+                    SKGRecurrentOperationObject obj(objs.at(i));
                     bool bold = false;
                     if (obj.isWarnEnabled() &&  QDate::currentDate() >= obj.getDate().addDays(-obj.getWarnDays())) bold = true;
                     table.push_back(QVariantList() << bold << obj.getDisplayName());
