@@ -196,6 +196,7 @@ SKGRuleObject::SKGAlarmInfo SKGRuleObject::getAlarmInfo() const
 SKGError SKGRuleObject::execute(ProcessMode iMode)
 {
     SKGError err;
+    SKGTRACEINRC(10, "SKGRuleObject::execute", err);
     if (getActionType() == SKGRuleObject::UPDATE) {
         //Update mode
         QString addSql;
@@ -278,6 +279,10 @@ QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QSt
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is empty");
     else if (output == "#ATT#!=''")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not empty");
+    else if (output == "REGEXP('#V1S#', #ATT#)")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "regexp '#V1S#'").replace("#V1S#", iParam1);
+    else if (output == "WILDCARD('#V1S#', #ATT#)")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "wildcard '#V1S#'").replace("#V1S#", iParam1);
 
     else if (output == "#ATT#=#V1#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#V1#").replace("#V1#", iParam1);
@@ -324,6 +329,8 @@ QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QSt
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=substring of #ATT2# from #V1# to #V2#").replace("#V1#", iParam1).replace("#V2#", iParam2).replace("#ATT2#", iAtt2);
     else if (output == "#ATT#=#ATT2#")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2#").replace("#ATT2#", iAtt2);
+    else if (output == "#ATT#=WORD(#ATT2#,#V1S#)")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=word(#ATT2#,#V1S#)").replace("#ATT2#", iAtt2).replace("#V1S#", iParam1);
 
     else if (output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current month");
@@ -372,6 +379,7 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
         if (iAttributeType != SKGServices::BOOL && iAttributeType != SKGServices::TRISTATE) {
             output.push_back("#ATT#=substr(#ATT2#,'#V1#','#V2#')");
             output.push_back("#ATT#=#ATT2#");
+            output.push_back("#ATT#=WORD(#ATT2#,#V1S#)");
         }
     } else if (iType == SEARCH) {
         //Mode query
@@ -383,6 +391,8 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT#!=''");
             output.push_back("#ATT#!=lower(#ATT#)");
             output.push_back("#ATT#!=upper(#ATT#)");
+            output.push_back("REGEXP('#V1S#', #ATT#)");
+            output.push_back("WILDCARD('#V1S#', #ATT#)");
         }
 
         if (iAttributeType == SKGServices::INTEGER || iAttributeType == SKGServices::FLOAT) {
@@ -594,9 +604,9 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
 
     if (iFullUpdate) {
         //Remove markers
+        output.push_back("UPDATE parameters set i_tmp=0 WHERE i_tmp=1");
         output.push_back("UPDATE suboperation set i_tmp=0 WHERE i_tmp=1");
         output.push_back("UPDATE operation set i_tmp=0 WHERE i_tmp=1");
-        output.push_back("UPDATE parameters set i_tmp=0 WHERE i_tmp=1");
     }
     return output;
 }
