@@ -124,7 +124,7 @@ SKGError SKGTrackerObject::merge(const SKGTrackerObject& iTracker)
     if (!err) err = iTracker.getSubOperations(ops);
     int nb = ops.count();
     for (int i = 0; !err && i < nb; ++i) {
-        SKGSubOperationObject op = ops.at(i);
+        SKGSubOperationObject op(ops.at(i));
         err = op.setTracker(*this);
         if (!err) err = op.save(true, false);
     }
