@@ -450,7 +450,7 @@ SKGError SKGUnitObject::simplify()
             QDate limit2 = QDate::currentDate().addYears(-1);
             QDate limit3 = QDate::currentDate().addYears(-3);
             for (int i = nb - 1; !err && i >= 0 ; --i) {
-                SKGUnitValueObject v = values.at(i);
+                SKGUnitValueObject v(values.at(i));
                 QDate d = v.getDate();
                 if (d >= limit1) {
                     //No simplification ==> nothing to do
@@ -496,7 +496,7 @@ SKGError SKGUnitObject::simplify()
                 double min = 10e20;
                 double max = 0;
                 for (int j = 0; j < nb2; ++j) {
-                    SKGUnitValueObject v1 = group.at(j);
+                    SKGUnitValueObject v1(group.at(j));
                     double y1 = v1.getQuantity();
                     min = qMin(y1, min);
                     max = qMax(y1, max);
@@ -504,7 +504,7 @@ SKGError SKGUnitObject::simplify()
 
                 //Simplify
                 for (int j = 1; !err && j < nb2 - 1; ++j) {
-                    SKGUnitValueObject v1 = group.at(j);
+                    SKGUnitValueObject v1(group.at(j));
                     double y1 = v1.getQuantity();
                     if (y1 != min && y1 != max) {
                         err = v1.remove();
@@ -785,54 +785,37 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
             //Download history
             if (!last) {
                 QString path = "http://ichart.finance.yahoo.com/table.csv?s=" % code % "&ignore=.csv&" % parameters;
-                KUrl url(path);
-                QString tmpFile;
-                if (KIO::NetAccess::download(url, tmpFile, NULL)) {
+                QString stream;
+                SKGError err = SKGServices::download(KUrl(path), stream);
+                if (!err) {
+                    //The file is something like this
+                    //Date,Open,High,Low,Close,Volume,Adj Close
+                    //2008-08-29,41.64,41.86,41.04,41.32,308800,41.32
+                    //2008-08-28,40.43,41.93,40.25,41.67,362000,41.67
+                    //2008-08-27,41.00,41.00,40.11,40.49,174200,40.49
+                    //2008-08-26,40.44,41.00,40.20,40.95,228200,40.95
+                    //2008-08-25,40.52,41.02,40.52,40.80,100100,40.80
+                    QStringList lines = SKGServices::splitCSVLine(stream, '\n');
+                    int nb = lines.count();
+                    for (int i = 1; i < nb && !err && (i < nbMaxValues - 1 || nbMaxValues == 0); ++i) { //-1 because the value of the day will be loaded after
+                        //Read line
+                        QString line = lines.at(i);
+                        QStringList fields = SKGServices::splitCSVLine(line, ',');
+                        if (fields.count() == 7) {
+                            QDate ds = QDate::fromString(fields[0], "yyyy-MM-dd");
+                            double val = SKGServices::stringToDouble(fields[6]);
 
-                    //Open file
-                    QFile file(tmpFile);
-                    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                        doc->sendMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
-                    } else {
-                        QTextStream stream(&file);
-
-                        //The file is something like this
-                        //Date,Open,High,Low,Close,Volume,Adj Close
-                        //2008-08-29,41.64,41.86,41.04,41.32,308800,41.32
-                        //2008-08-28,40.43,41.93,40.25,41.67,362000,41.67
-                        //2008-08-27,41.00,41.00,40.11,40.49,174200,40.49
-                        //2008-08-26,40.44,41.00,40.20,40.95,228200,40.95
-                        //2008-08-25,40.52,41.02,40.52,40.80,100100,40.80
-                        stream.readLine(); //to forget column names
-
-                        int nbLoaded = 0;
-                        while (!stream.atEnd() && !err && (nbLoaded < nbMaxValues - 1 || nbMaxValues == 0)) { //-1 because the value of the day will be loaded after
-                            //Read line
-                            QString line = stream.readLine().trimmed();
-                            QStringList fields = SKGServices::splitCSVLine(line, ',');
-                            if (fields.count() == 7) {
-                                QDate ds = QDate::fromString(fields[0], "yyyy-MM-dd");
-                                double val = SKGServices::stringToDouble(fields[6]);
-
-                                //Creation or update of the value
-                                SKGUnitValueObject value;
-                                if (!err) err = addUnitValue(value);
-                                if (!err) err = value.setDate(ds);
-                                if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
-                                if (!err) err = value.save();
-                            } else {
-                                err.setReturnCode(ERR_ABORT);
-                                err.setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
-                            }
-                            nbLoaded++;
+                            //Creation or update of the value
+                            SKGUnitValueObject value;
+                            if (!err) err = addUnitValue(value);
+                            if (!err) err = value.setDate(ds);
+                            if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
+                            if (!err) err = value.save();
+                        } else {
+                            err.setReturnCode(ERR_ABORT);
+                            err.setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
                         }
-
-                        //close file
-                        file.close();
                     }
-
-                    //Remove tmp file
-                    KIO::NetAccess::removeTempFile(tmpFile);
                 } else {
                     //283840: doc->sendMessage(KIO::NetAccess::lastErrorString());
                     doc->sendMessage(i18nc("A warning message", "History for %1 not found on Yahoo", code));
@@ -1018,54 +1001,40 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                 }
 
                 QString path = "http://download.finance.yahoo.com/d/quotes.csv?s=" % code % "&f=l1d1" % yahooString;//l1=val d1=date
-                KUrl url(path);
-                QString tmpFile;
-                if (!err && KIO::NetAccess::download(url, tmpFile, NULL)) {
-                    //Open file
-                    QFile file(tmpFile);
-                    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                        doc->sendMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
+                QString stream;
+                SKGError errTmp = SKGServices::download(KUrl(path), stream);
+                if (!errTmp) {
+                    //Read line
+                    QString line = stream.trimmed();
+                    QStringList fields = SKGServices::splitCSVLine(line, ',');
+                    QDate ds;
+                    int nb = fields.count();
+                    if (nb != unitYahooTitle.count() + 2) {
+                        err = getDocument()->sendMessage(i18nc("An error message", "Additional information was not downloaded because of invalid number of fields (found=%1, expected=%2) for %3 in following string:\n%4", SKGServices::intToString(nb), SKGServices::intToString(unitYahooTitle.count() + 2), unitname, line));
+
+                        if (!err) err = downloadUnitValue(iMode, nbMaxValues, false);
                     } else {
-                        QTextStream stream(&file);
+                        if ((ds = QDate::fromString(fields[1], "M/d/yyyy")).isValid()) {
+                            double val = SKGServices::stringToDouble(fields[0]);
 
-                        //Read line
-                        QString line = stream.readLine().trimmed();
-                        QStringList fields = SKGServices::splitCSVLine(line, ',');
-                        QDate ds;
-                        int nb = fields.count();
-                        if (nb != unitYahooTitle.count() + 2) {
-                            err = getDocument()->sendMessage(i18nc("An error message", "Additional information was not downloaded because of invalid number of fields (found=%1, expected=%2) for %3 in following string:\n%4", SKGServices::intToString(nb), SKGServices::intToString(unitYahooTitle.count() + 2), unitname, line));
-
-                            if (!err) err = downloadUnitValue(iMode, nbMaxValues, false);
+                            //Creation or update of the value
+                            SKGUnitValueObject value;
+                            if (!err) err = addUnitValue(value);
+                            if (!err) err = value.setDate(ds);
+                            if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
+                            if (!err) err = value.save();
                         } else {
-                            if ((ds = QDate::fromString(fields[1], "M/d/yyyy")).isValid()) {
-                                double val = SKGServices::stringToDouble(fields[0]);
-
-                                //Creation or update of the value
-                                SKGUnitValueObject value;
-                                if (!err) err = addUnitValue(value);
-                                if (!err) err = value.setDate(ds);
-                                if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
-                                if (!err) err = value.save();
-                            } else {
-                                err.setReturnCode(ERR_ABORT);
-                                err.setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
-                            }
-
-                            for (int j = 2; !err && j < nb; ++j) {
-                                QString val = fields[j];
-                                if (!val.contains("N/A") && val != "-" && val != "- - -" && val != "0" && val != "0.00") err = setProperty(unitYahooTitle[j - 2], val);
-                            }
+                            err.setReturnCode(ERR_ABORT);
+                            err.setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
                         }
 
-                        //close file
-                        file.close();
+                        for (int j = 2; !err && j < nb; ++j) {
+                            QString val = fields[j];
+                            if (!val.contains("N/A") && val != "-" && val != "- - -" && val != "0" && val != "0.00") err = setProperty(unitYahooTitle[j - 2], val);
+                        }
                     }
-
-                    //Remove tmp file
-                    KIO::NetAccess::removeTempFile(tmpFile);
                 } else {
-                    doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, KIO::NetAccess::lastErrorString()));
+                    doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, errTmp.getFullMessageWithHistorical()));
                 }
             }
         } else {
@@ -1086,60 +1055,46 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     QString dateFormat = properties["dateformat"];
 
                     //Download url
-                    KUrl url(path);
-                    QString tmpFile;
-                    if (!err && KIO::NetAccess::download(url, tmpFile, NULL)) {
-                        //Open file
-                        QFile file(tmpFile);
-                        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                            doc->sendMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
-                        } else {
-                            QTextStream stream(&file);
+                    QString stream;
+                    SKGServices::download(KUrl(path), stream);
+                    if (!stream.isEmpty()) {
+                        //Parse data
+                        QRegExp priceRegExp(price, Qt::CaseInsensitive);
+                        QRegExp dateRegExp(date, Qt::CaseInsensitive);
 
-                            //Parse data
-                            QRegExp priceRegExp(price, Qt::CaseInsensitive);
-                            QRegExp dateRegExp(date, Qt::CaseInsensitive);
+                        QStringList lines = (mode == "CSV" ? SKGServices::splitCSVLine(stream, '\n') : QStringList() << "" << stream);
+                        int nb = lines.count();
+                        int nbLoaded = 0;
+                        for (int i = 1; i < nb && !err && (i < nbMaxValues - 1 || nbMaxValues == 0); ++i) { //-1 because the value of the day will be loaded after
+                            QString data = lines.at(i).trimmed();
+                            if (!data.isEmpty()) {
+                                SKGTRACEL(1) << "Downloaded data from [" << path << "]=[" << data << "]" << endl;
 
-                            //Read data
-                            int nbLoaded = 0;
-                            while (!stream.atEnd() && !err && (nbLoaded < nbMaxValues || nbMaxValues == 0)) {
-                                //Read line
-                                QString data = (mode == "CSV" ? stream.readLine() : stream.readAll()).trimmed();
-                                if (!data.isEmpty()) {
-                                    SKGTRACEL(1) << "Downloaded data from [" << path << "]=[" << data << "]" << endl;
+                                double val = 0.0;
+                                if (priceRegExp.indexIn(data) > -1) val = SKGServices::stringToDouble(priceRegExp.cap(1));
+                                QString d;
+                                if (dateRegExp.indexIn(data) > -1) d = dateRegExp.cap(1);
+                                SKGTRACEL(1) << "Price found=[" << val << "]" << endl;
+                                SKGTRACEL(1) << "Date found=[" << d << "]" << endl;
 
-                                    double val = 0.0;
-                                    if (priceRegExp.indexIn(data) > -1) val = SKGServices::stringToDouble(priceRegExp.cap(1));
-                                    QString d;
-                                    if (dateRegExp.indexIn(data) > -1) d = dateRegExp.cap(1);
-                                    SKGTRACEL(1) << "Price found=[" << val << "]" << endl;
-                                    SKGTRACEL(1) << "Date found=[" << d << "]" << endl;
+                                //Set value
+                                if (val) {
+                                    QDate ds = QDate::fromString(d, dateFormat);
+                                    if (!ds.isValid()) ds = QDate::currentDate();
+                                    if (!dateFormat.contains("yyyy") && ds.year() < 2000) ds = ds.addYears(100);
 
-                                    //Set value
-                                    if (val) {
-                                        QDate ds = QDate::fromString(d, dateFormat);
-                                        if (!ds.isValid()) ds = QDate::currentDate();
-                                        if (!dateFormat.contains("yyyy") && ds.year() < 2000) ds = ds.addYears(100);
+                                    //Creation or update of the value
+                                    SKGUnitValueObject value;
+                                    if (!err) err = addUnitValue(value);
+                                    if (!err) err = value.setDate(ds);
+                                    if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
+                                    if (!err) err = value.save();
 
-                                        //Creation or update of the value
-                                        SKGUnitValueObject value;
-                                        if (!err) err = addUnitValue(value);
-                                        if (!err) err = value.setDate(ds);
-                                        if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
-                                        if (!err) err = value.save();
-
-                                        nbLoaded++;
-                                    }
+                                    nbLoaded++;
                                 }
                             }
                             if (nbLoaded == 0) err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2'", getName(), SKGServices::stringToHtml(price))); //TODO does not work with html
-
-                            //close file
-                            file.close();
                         }
-
-                        //Remove tmp file
-                        KIO::NetAccess::removeTempFile(tmpFile);
                     } else {
                         doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, KIO::NetAccess::lastErrorString()));
                     }
@@ -1214,7 +1169,7 @@ SKGError SKGUnitObject::merge(const SKGUnitObject& iUnit)
     if (!err) err = iUnit.getOperations(ops);
     int nb = ops.count();
     for (int i = 0; !err && i < nb; ++i) {
-        SKGOperationObject op = ops.at(i);
+        SKGOperationObject op(ops.at(i));
         err = op.setUnit(*this);
         if (!err) err = op.save(true, false);
     }
