@@ -49,7 +49,7 @@ class SKGBASEGUI_EXPORT SKGCalculatorEdit : public KLineEdit
     /**
      * Mode of the calculator editor
      */
-    Q_ENUMS(Mode);
+    Q_ENUMS(Mode)
 public:
 
     /**
@@ -143,7 +143,7 @@ protected:
     virtual void focusOutEvent(QFocusEvent* event);
 
 private:
-    Q_DISABLE_COPY(SKGCalculatorEdit);
+    Q_DISABLE_COPY(SKGCalculatorEdit)
 
     void keyPressEvent(int key);
     double getEvaluatedValue(bool& iOk);
