@@ -38,7 +38,7 @@ public:
      * @param widget the date picker
      * @param parent the parent
      */
-    SKGDatePickerAction(KDatePicker* widget, QObject* parent)
+    explicit SKGDatePickerAction(KDatePicker* widget, QObject* parent)
         : QWidgetAction(parent),
           mDatePicker(widget), mOriginalParent(widget->parentWidget()) {
     }
