@@ -22,7 +22,7 @@
 #include "skgfilteredtableviewdesignerplugin.h"
 #include "skgfilteredtableview.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
