@@ -22,7 +22,7 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include <QStringList>
-#include <kparts/plugin.h>
+#include <kparts/part.h>
 
 #include "skgdocument.h"
 #include "skgtabpage.h"
@@ -30,15 +30,17 @@
 #include "skgerror.h"
 #include "skgbasegui_export.h"
 class SKGMainPanel;
+class SKGBoardWidget;
+class KAction;
 class KConfigSkeleton;
 class QDockWidget;
 
 /**
  * This file is a plugin interface definition.
  */
-class SKGBASEGUI_EXPORT SKGInterfacePlugin : public KParts::Plugin
+class SKGBASEGUI_EXPORT SKGInterfacePlugin : public KParts::ReadOnlyPart
 {
-    Q_OBJECT ;
+    Q_OBJECT
 public:
     /**
      * Default constructor
@@ -59,6 +61,13 @@ public:
      */
     virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) = 0;
 
+    /**
+     * Register a global action
+     * @param iIdentifier identifier of the action
+     * @param iAction action pointer
+     */
+    virtual void registerGlobalAction(const QString& iIdentifier, QAction* iAction);
+
     /**
      * This function is called when the application is launched again with new arguments
      * @param iArgument the arguments
@@ -99,7 +108,7 @@ public:
      * @param iIndex the index of the widget
      * @return The dashboard widget of the plugin
      */
-    virtual SKGWidget* getDashboardWidget(int iIndex);
+    virtual SKGBoardWidget* getDashboardWidget(int iIndex);
 
     /**
      * The dock widget of the plugin.
@@ -179,7 +188,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -188,15 +197,15 @@ public:
      * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
      *   @see SKGError
      */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution);
 
 private:
-    Q_DISABLE_COPY(SKGInterfacePlugin);
+    Q_DISABLE_COPY(SKGInterfacePlugin)
 
 };
 /**
  * This plugin interface definition.
  */
-Q_DECLARE_INTERFACE(SKGInterfacePlugin, "skrooge.com.SKGInterfacePlugin/1.0");
+Q_DECLARE_INTERFACE(SKGInterfacePlugin, "skrooge.com.SKGInterfacePlugin/1.0")
 
 #endif // SKGINTERFACEPLUGIN_H
