@@ -71,6 +71,7 @@
 #include <QDir>
 #include <QResizeEvent>
 #include <qdesktopservices.h>
+#include <QScrollArea>
 #include <qtextcodec.h>
 
 
@@ -81,16 +82,26 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
       m_tabWidget(new SKGTabWidget(this)),
       m_splashScreen(iSplashScreen),
       m_currentDocument(iDocument),
-      m_tipOfDayAction(NULL), m_closePageAction(NULL), m_closeAllPagesAction(NULL), m_closeAllOtherPagesAction(NULL), m_switchPinState(NULL),
-      m_fullScreenAction(NULL), m_actLock(NULL), m_actUnLock(NULL), m_kSystemTrayIcon(NULL),
+      m_actHideContextItem(NULL), m_actShowAllContextItems(NULL), m_actDelete(NULL), m_addTabAction(NULL), m_tipOfDayAction(NULL),
+      m_closePageAction(NULL), m_closeAllPagesAction(NULL), m_closeAllOtherPagesAction(NULL), m_switchPinState(NULL), m_saveDefaultStateAction(NULL),
+      m_resetDefaultStateAction(NULL), m_overwriteBookmarkStateAction(NULL), m_configureAction(NULL), m_enableEditorAction(NULL), m_fullScreenAction(NULL), m_actLock(NULL),
+      m_actUnLock(NULL),
+      m_kSystemTrayIcon(NULL),
       m_kNormalMessage(NULL), m_zoomSelector(NULL),  m_previousAction(NULL), m_nextAction(NULL), m_buttonMenuAction(NULL),
       m_mainWidget(NULL), m_mainLayout(NULL), m_middleClick(false), m_saveOnClose(false)
+
+
+
 {
     SKGTRACEIN(1, "SKGMainPanel::SKGMainPanel");
 
+    setComponentData(KGlobal::mainComponent());
+
     //Set main panel
     m_mainPanel = this;
-    QWidget* w = new QWidget(this);
+    QScrollArea* w = new QScrollArea(this);
+    w->setFrameShape(QFrame::NoFrame);
+    w->setFocusPolicy(Qt::NoFocus);
     m_mainLayout = new QHBoxLayout(w);
     m_mainLayout->setSpacing(0);
     m_mainLayout->setContentsMargins(0, 0, 0, 0);
@@ -211,9 +222,7 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
                          ki18n("%1").subs(listTasks.at(i).toAscii().data()),
                          listEmails.at(i).toAscii(),
                          ""
-#ifdef SKGKDE46ENABLED
                          , listOscs.at(i).toAscii()
-#endif
                         );
     }
 
@@ -230,11 +239,8 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     m_tabWidget->setAutomaticResizeTabs(true);
     m_tabWidget->setTabBarHidden(false);
     m_tabWidget->setUsesScrollButtons(true);
-#ifdef SKGKDE46ENABLED
     m_tabWidget->tabBar()->setSelectionBehaviorOnRemove(KTabBar::SelectPreviousTab);
-#endif
     m_tabWidget->setDocumentMode(true);
-
     m_tabWidget->show();
 
     //System tray
@@ -261,27 +267,22 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     //Add a status bar
     statusBar()->show();
 
-    //Add action to control hide / display of Pages
-    /*KAction* toggle = actionCollection()->addAction("view_context");
-    toggle->setShortcut(QKeySequence(Qt::SHIFT+Qt::Key_F9));
-    toggle->setText(i18nc ("Noun", "Pages" ) );
-    toggle->setCheckable(true);
-    toggle->setChecked(true);
-    connect(toggle, SIGNAL(toggled(bool)), ui.kDockContext->toggleViewAction(), SLOT(toggle()));
-    connect(ui.kDockContext, SIGNAL(visibilityChanged(bool)), toggle, SLOT(setChecked(bool)));*/
-
     QPalette palette = QApplication::palette();
     palette.setColor(QPalette::Base, Qt::transparent);
     ui.kContextList->setPalette(palette);
 
     QAction* toggle = ui.kDockContext->toggleViewAction();
-    if (toggle) {
-        toggle->setText(i18nc("Noun", "Pages"));
-        toggle->setShortcut(Qt::SHIFT + Qt::Key_F9);
-        actionCollection()->addAction("view_context", toggle);
-    }
+    KAction* panelAction = actionCollection()->addAction("view_context");
+    registerGlobalAction("view_context", panelAction);
+    panelAction->setCheckable(true);
+    panelAction->setChecked(toggle->isChecked());
+    panelAction->setText(toggle->text());
+    panelAction->setShortcut(Qt::SHIFT + Qt::Key_F9);
+    connect(panelAction, SIGNAL(triggered()), toggle, SLOT(trigger()));
+    connect(toggle, SIGNAL(toggled(bool)), panelAction, SLOT(setChecked(bool)));
+
     KSelectAction* contextMenu = new KSelectAction(KIcon("tab-new"), i18nc("Noun", "Pages"), this);
-    actionCollection()->addAction("view_contextmenu" , contextMenu);
+    registerGlobalAction("view_contextmenu" , contextMenu);
 
     //Add plugin in client in right order
     QList<QListWidgetItem*> pageNotVisible;
@@ -330,6 +331,11 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
                         contextActionList.append(action);
 
                         if (!visible) pageNotVisible.push_back(contextItem);
+
+                        //Register action
+                        QString id = "page_" % pluginInterface->objectName();
+                        registerGlobalAction(id, action);
+                        registerGlobalAction(id, action);
                     }
                 }
 
@@ -347,7 +353,7 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     //Lock docs if needed
     KConfigGroup pref = getMainConfigGroup();
     if (pref.readEntry("docks_locked", false)) {
-        actionLockDocks();
+        onLockDocks();
     }
 
     //267773 this->setWindowState(windowState() | Qt::WindowMaximized);
@@ -358,6 +364,8 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     // mainwindow to automatically save settings if changed: window size,
     // toolbar position, icon size, etc.
     setupGUI(Default, "../skg/skgmainpanel.rc");
+    //setupGUI(ToolBar | Keys | StatusBar | Save, "../skg/skgmainpanel.rc");
+    //createGUI(NULL);
     plugActionList("context_actionlist", contextActionList);
 
     for (int j = 0; j < nbplugin; ++j) {
@@ -390,6 +398,7 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     kProgressBar->setFont(f);
     kProgressBar->setVisible(false);
     kProgressBar->setAlignment(Qt::AlignTop | Qt::AlignHCenter);
+    kProgressBar->setRange(0, 100);
 
     m_zoomSelector = new SKGZoomSelector(this);
     m_zoomSelector->setSizePolicy(sizePolicy);
@@ -465,10 +474,10 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
 
     m_contextMenu = new KMenu(ui.kContextList);
     m_actHideContextItem = m_contextMenu->addAction(KIcon("layer-visible-off"), i18nc("Verb", "Hide"));
-    connect(m_actHideContextItem, SIGNAL(triggered(bool)), this, SLOT(actionHideContextItem()));
+    connect(m_actHideContextItem, SIGNAL(triggered(bool)), this, SLOT(onHideContextItem()));
 
     m_actShowAllContextItems = m_contextMenu->addAction(KIcon("layer-visible-on"), i18nc("Verb", "Show all"));
-    connect(m_actShowAllContextItems, SIGNAL(triggered(bool)), this, SLOT(actionShowAllContextItems()));
+    connect(m_actShowAllContextItems, SIGNAL(triggered(bool)), this, SLOT(onShowAllContextItems()));
 
     m_contextMenu->addSeparator();
     m_contextMenu->addAction(getGlobalAction("tab_savedefaultstate"));
@@ -537,12 +546,12 @@ void SKGMainPanel::setContextVisibility(int iPage, bool iVisibility)
     setContextVisibility(ui.kContextList->item(iPage), iVisibility);
 }
 
-void SKGMainPanel::actionHideContextItem()
+void SKGMainPanel::onHideContextItem()
 {
     setContextVisibility(ui.kContextList->currentRow(), false);
 }
 
-void SKGMainPanel::actionShowAllContextItems()
+void SKGMainPanel::onShowAllContextItems()
 {
     int nb = ui.kContextList->count();
     for (int i = 0; i < nb; ++i) {
@@ -562,17 +571,23 @@ void SKGMainPanel::processArguments(const QStringList& iArgument)
     }
 }
 
-void SKGMainPanel::registerGlobalAction(const QString& iIdentifier, KAction* iAction)
+void SKGMainPanel::registerGlobalAction(const QString& iIdentifier, QAction* iAction, bool iAddInCollection)
 {
-    m_registeredGlogalAction[iIdentifier] = iAction;
+    if (iAction == NULL) {
+        SKGTRACE << "WARNING: registerGlobalAction(" << iIdentifier << ",NULL)" << endl;
+    } else {
+        m_registeredGlogalAction[iIdentifier] = iAction;
+        if (iAddInCollection) actionCollection()->addAction(iIdentifier, iAction);
+    }
 }
 
-KAction* SKGMainPanel::getGlobalAction(const QString& iIdentifier)
+QAction* SKGMainPanel::getGlobalAction(const QString& iIdentifier, bool iWarnIfNotExist)
 {
-    if (!m_registeredGlogalAction.contains(iIdentifier)) {
-        SKGTRACE << "WARNING: Actione [" << iIdentifier << "]" << endl;
+    QAction* act = m_registeredGlogalAction[iIdentifier];
+    if (act == NULL && iWarnIfNotExist) {
+        SKGTRACE << "WARNING: getGlobalAction(" << iIdentifier << ")=NULL" << endl;
     }
-    return m_registeredGlogalAction[iIdentifier];
+    return act;
 }
 
 SKGInterfacePlugin* SKGMainPanel::getPluginByIndex(int iIndex)
@@ -617,79 +632,62 @@ void SKGMainPanel::setupActions()
 
     // New Tab
     m_addTabAction = new KAction(KIcon("tab-new-background"), i18nc("Noun, user action", "New Tab"), this);
-    actionCollection()->addAction(QLatin1String("new_tab"), m_addTabAction);
     m_addTabAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_W);
     connect(m_addTabAction, SIGNAL(triggered()), this, SLOT(addTab()));
-
-    registerGlobalAction("tab-new-background", m_addTabAction);
+    registerGlobalAction("new_tab", m_addTabAction);
 
     m_actLock = new KAction(KIcon("document-encrypt"), i18nc("Verb", "Lock panels"), this);
-    actionCollection()->addAction(QLatin1String("view_lock"), m_actLock);
-    connect(m_actLock, SIGNAL(triggered(bool)), this, SLOT(actionLockDocks()));
+    connect(m_actLock, SIGNAL(triggered(bool)), this, SLOT(onLockDocks()));
+    registerGlobalAction("view_lock", m_actLock);
 
     m_actUnLock = new KAction(KIcon("document-decrypt"), i18nc("Verb", "Unlock panels"), this);
-    actionCollection()->addAction(QLatin1String("view_unlock"), m_actUnLock);
-    connect(m_actUnLock, SIGNAL(triggered(bool)), this, SLOT(actionUnlockDocks()));
+    connect(m_actUnLock, SIGNAL(triggered(bool)), this, SLOT(onUnlockDocks()));
+    registerGlobalAction("view_unlock", m_actUnLock);
 
     m_switchPinState = new KAction(KIcon("document-encrypt"), i18nc("Noun, user action", "Pin this page"), this);
-    actionCollection()->addAction(QLatin1String("tab_switchpin"), m_switchPinState);
     //TODO m_switchPinState->setShortcut(Qt::ALT + Qt::Key_W);
     connect(m_switchPinState, SIGNAL(triggered()), this, SLOT(switchPinPage()));
-
     registerGlobalAction("tab_switchpin", m_switchPinState);
 
     //
     m_closePageAction = actionCollection()->addAction(KStandardAction::Close, "tab_close", this, SLOT(closePage()));
-
     registerGlobalAction("tab_close", m_closePageAction);
 
     //
     m_closeAllPagesAction = new KAction(KIcon("window-close"), i18nc("Noun, user action", "Close All"), this);
-    actionCollection()->addAction(QLatin1String("tab_closeall"), m_closeAllPagesAction);
     m_closeAllPagesAction->setShortcut(Qt::ALT + Qt::Key_W);
     connect(m_closeAllPagesAction, SIGNAL(triggered()), this, SLOT(closeAllPages()));
-
     registerGlobalAction("tab_closeall", m_closeAllPagesAction);
 
     //
     m_closeAllOtherPagesAction = new KAction(KIcon("window-close"), i18nc("Noun, user action", "Close All Other"), this);
-    actionCollection()->addAction(QLatin1String("tab_closeallother"), m_closeAllOtherPagesAction);
     m_closeAllOtherPagesAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_W);
     connect(m_closeAllOtherPagesAction, SIGNAL(triggered()), this, SLOT(closeAllOtherPages()));
-
     registerGlobalAction("tab_closeallother", m_closeAllOtherPagesAction);
 
     //
     m_saveDefaultStateAction = new KAction(KIcon("document-save"), i18nc("Noun, user action", "Save page state"), this);
-    actionCollection()->addAction(QLatin1String("tab_savedefaultstate"), m_saveDefaultStateAction);
     m_saveDefaultStateAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_S);
     connect(m_saveDefaultStateAction, SIGNAL(triggered()), this, SLOT(saveDefaultState()));
-
     registerGlobalAction("tab_savedefaultstate", m_saveDefaultStateAction);
 
     //
     m_resetDefaultStateAction = new KAction(KIcon("edit-clear"), i18nc("Noun, user action", "Reset page state"), this);
-    actionCollection()->addAction(QLatin1String("tab_resetdefaultstate"), m_resetDefaultStateAction);
     m_resetDefaultStateAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_R);
     connect(m_resetDefaultStateAction, SIGNAL(triggered()), this, SLOT(resetDefaultState()));
-
     registerGlobalAction("tab_resetdefaultstate", m_resetDefaultStateAction);
 
     //
     QStringList overlay;
     overlay.push_back("bookmarks");
     m_overwriteBookmarkStateAction = new KAction(KIcon("document-save", NULL, overlay), i18nc("Noun, user action", "Overwrite bookmark state"), this);
-    actionCollection()->addAction(QLatin1String("tab_overwritebookmark"), m_overwriteBookmarkStateAction);
     connect(m_overwriteBookmarkStateAction, SIGNAL(triggered()), this, SLOT(overwriteBookmarkState()));
     m_overwriteBookmarkStateAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_S);
-
     registerGlobalAction("tab_overwritebookmark", m_overwriteBookmarkStateAction);
 
     //
     m_configureAction = new KAction(KIcon("configure"), i18nc("Noun, user action", "Configure..."), this);
-    actionCollection()->addAction(QLatin1String("tab_configure"), m_configureAction);
     connect(m_configureAction, SIGNAL(triggered()), this, SLOT(optionsPreferences()));
-
     registerGlobalAction("tab_configure", m_configureAction);
 
     m_tipOfDayAction = KStandardAction::tipOfDay(this, SLOT(onTipOfDay()), actionCollection());
@@ -697,68 +695,52 @@ void SKGMainPanel::setupActions()
     //Menu
     m_buttonMenuAction = new KToolBarPopupAction(KIcon("configure"), "", this);
     m_buttonMenuAction->setToolTip(i18nc("Noun, user action", "Menu"));
-    actionCollection()->addAction(QLatin1String("view_menu"), m_buttonMenuAction);
-
     m_buttonMenu = static_cast<KMenu*>(m_buttonMenuAction->menu());
     connect(m_buttonMenu , SIGNAL(aboutToShow()), this, SLOT(onShowButtonMenu()));
     m_buttonMenuAction->setDelayed(false);
-
     registerGlobalAction("view_menu", m_buttonMenuAction);
 
     m_showMenuBarAction = KStandardAction::showMenubar(this, SLOT(onShowMenuBar()), actionCollection());
-
     KConfigGroup pref = getMainConfigGroup();
     m_showMenuBarAction->setChecked(pref.readEntry("menubar_shown", true));
-
     QTimer::singleShot(200, this, SLOT(onShowMenuBar()));
+    registerGlobalAction("menubar_shown", m_showMenuBarAction);
 
     //
     m_previousAction = new KToolBarPopupAction(KIcon("go-previous"), i18nc("Noun, user action", "Previous"), this);
-    connect(m_previousAction, SIGNAL(triggered(bool)), this, SLOT(actionPrevious()));
-    actionCollection()->addAction(QLatin1String("go_previous"), m_previousAction);
+    connect(m_previousAction, SIGNAL(triggered(bool)), this, SLOT(onPrevious()));
     m_previousAction->setShortcut(Qt::ALT + Qt::Key_Left);
     m_previousAction->setPriority(QAction::LowPriority);
-
-    //m_tabWidget->setCornerWidget(toolBar(), Qt::TopLeftCorner);
-
     m_previousMenu = static_cast<KMenu*>(m_previousAction->menu());
     connect(m_previousMenu , SIGNAL(aboutToShow()), this, SLOT(onShowPreviousMenu()));
-
     m_previousAction->setStickyMenu(false);
     m_previousAction->setData(0);
-
     registerGlobalAction("go_previous", m_previousAction);
 
     //
     m_nextAction = new KToolBarPopupAction(KIcon("go-next"), i18nc("Noun, user action", "Next"), this);
-    connect(m_nextAction, SIGNAL(triggered(bool)), this, SLOT(actionNext()));
-    actionCollection()->addAction(QLatin1String("go_next"), m_nextAction);
+    connect(m_nextAction, SIGNAL(triggered(bool)), this, SLOT(onNext()));
     m_nextAction->setShortcut(Qt::ALT + Qt::Key_Right);
     m_nextAction->setPriority(QAction::LowPriority);
-
     m_nextMenu = static_cast<KMenu*>(m_nextAction->menu());
     connect(m_nextMenu , SIGNAL(aboutToShow()), this, SLOT(onShowNextMenu()));
-
     m_nextAction->setStickyMenu(false);
     m_nextAction->setData(0);
-
     registerGlobalAction("go_next", m_nextAction);
 
     //
-    m_fullScreenAction = actionCollection()->addAction(KStandardAction::FullScreen, "fullscreen", this, SLOT(actionFullScreen()));
-
+    m_fullScreenAction = actionCollection()->addAction(KStandardAction::FullScreen, "fullscreen", this, SLOT(onFullScreen()));
     registerGlobalAction("fullscreen", m_fullScreenAction);
 
-
     //
     m_enableEditorAction = new KAction(KIcon("appointment-new"), i18nc("Noun, user action", "Enable editor"), this);
-    actionCollection()->addAction(QLatin1String("enable_editor"), m_enableEditorAction);
     m_enableEditorAction->setShortcut(Qt::CTRL + Qt::Key_Insert);
     connect(m_enableEditorAction, SIGNAL(triggered()), this, SLOT(enableEditor()));
+    registerGlobalAction("enable_editor", m_enableEditorAction);
 
     //Contextual menu
     m_tabWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
-    m_tabWidget->insertAction(0, getGlobalAction("tab-new-background"));
+    m_tabWidget->insertAction(0, getGlobalAction("new_tab"));
     m_tabWidget->insertAction(0, getGlobalAction("tab_close"));
     m_tabWidget->insertAction(0, getGlobalAction("tab_closeall"));
     m_tabWidget->insertAction(0, getGlobalAction("tab_closeallother"));
@@ -786,10 +768,10 @@ void SKGMainPanel::enableEditor()
     if (cPage) cPage->activateEditor();
 }
 
-void SKGMainPanel::actionPrevious()
+void SKGMainPanel::onPrevious()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGMainPanel::actionPrevious", err);
+    SKGTRACEINRC(10, "SKGMainPanel::onPrevious", err);
 
     SKGTabPage* cPage = currentPage();
     if (cPage) {
@@ -840,7 +822,7 @@ void SKGMainPanel::onShowPreviousMenu()
                 QAction* act = m_previousMenu->addAction(KIcon(list.at(i).icon), list.at(i).name);
                 if (act) {
                     act->setData(i);
-                    connect(act, SIGNAL(triggered()), this, SLOT(actionPrevious()));
+                    connect(act, SIGNAL(triggered()), this, SLOT(onPrevious()));
                 }
             }
         }
@@ -857,7 +839,7 @@ void SKGMainPanel::onShowMenuBar()
     pref.writeEntry("menubar_shown", test);
 }
 
-void SKGMainPanel::actionFullScreen()
+void SKGMainPanel::onFullScreen()
 {
     if (!m_fullScreenAction->isChecked()) {
         //No Full screen
@@ -897,10 +879,10 @@ void SKGMainPanel::actionFullScreen()
     }
 }
 
-void SKGMainPanel::actionNext()
+void SKGMainPanel::onNext()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGMainPanel::actionNext", err);
+    SKGTRACEINRC(10, "SKGMainPanel::onNext", err);
 
     SKGTabPage* cPage = currentPage();
     if (cPage) {
@@ -938,7 +920,7 @@ void SKGMainPanel::actionNext()
     }
 }
 
-void SKGMainPanel::actionLockDocks()
+void SKGMainPanel::onLockDocks()
 {
     QObjectList cs = children();
     foreach(QObject * c, cs) {
@@ -954,7 +936,7 @@ void SKGMainPanel::actionLockDocks()
     refresh();
 }
 
-void SKGMainPanel::actionUnlockDocks()
+void SKGMainPanel::onUnlockDocks()
 {
     QObjectList cs = children();
     foreach(QObject * c, cs) {
@@ -981,7 +963,7 @@ void SKGMainPanel::onShowNextMenu()
                 QAction* act = m_nextMenu->addAction(KIcon(list.at(i).icon), list.at(i).name);
                 if (act) {
                     act->setData(i);
-                    connect(act, SIGNAL(triggered()), this, SLOT(actionNext()));
+                    connect(act, SIGNAL(triggered()), this, SLOT(onNext()));
                 }
             }
         }
@@ -1039,7 +1021,7 @@ bool SKGMainPanel::queryFileClose()
         QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
         int code = KMessageBox::Yes;
         QString fileName = getDocument()->getCurrentFileName();
-        KAction* save = getGlobalAction(fileName.isEmpty() ? "file_save_as" : "file_save");
+        QAction* save = getGlobalAction(fileName.isEmpty() ? "file_save_as" : "file_save");
         if (save) {
             if (!m_saveOnClose) code = KMessageBox::questionYesNoCancel(this, i18nc("Question", "The document has been modified.\nDo you want to save it before closing?"),
                                            QString(),
@@ -1094,7 +1076,7 @@ SKGAdviceList SKGMainPanel::getAdvice() const
     while (index >= 0) {
         SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
         if (plugin) {
-            foreach(const SKGAdvice & ad, plugin->advice()) {
+            foreach(const SKGAdvice & ad, plugin->advice(ignoredAdvice)) {
                 if (!ignoredAdvice.contains(ad.getUUID()) && !ignoredAdvice.contains(SKGServices::splitCSVLine(ad.getUUID(), '|').at(0))) globalAdviceList.push_back(ad);
             }
         } else index = -2;
@@ -1290,10 +1272,11 @@ void SKGMainPanel::refresh()
     } else {
         m_switchPinState->setText(i18nc("Noun, user action", "Pin this page"));
     }
-    m_addTabAction->setEnabled(atLeastOnePageOpened);
-    m_closePageAction->setEnabled(atLeastOnePageOpened && !toSave->isPin());
-    m_closeAllPagesAction->setEnabled(atLeastOnePageOpened);
-    m_closeAllOtherPagesAction->setEnabled(m_tabWidget->count() > 1);
+    if (m_addTabAction) m_addTabAction->setEnabled(atLeastOnePageOpened);
+    if (m_closePageAction) m_closePageAction->setEnabled(atLeastOnePageOpened && toSave && !toSave->isPin());
+    if (m_switchPinState) m_switchPinState->setEnabled(atLeastOnePageOpened);
+    if (m_closeAllPagesAction) m_closeAllPagesAction->setEnabled(atLeastOnePageOpened);
+    if (m_closeAllOtherPagesAction) m_closeAllOtherPagesAction->setEnabled(m_tabWidget->count() > 1);
 
     if (m_saveDefaultStateAction) m_saveDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
     if (m_resetDefaultStateAction) m_resetDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
@@ -1490,10 +1473,9 @@ void SKGMainPanel::onBeforeOpenContext()
     m_middleClick = QApplication::mouseButtons() & Qt::MidButton;
 }
 
-SKGTabPage* SKGMainPanel::openPage(const QUrl& iUrl, bool iNewPage)
+bool SKGMainPanel::openPage(const QUrl& iUrl, bool iNewPage)
 {
     KUrl url(iUrl);
-
     if (url.protocol() == "skg") {
         //Get plugin
         SKGInterfacePlugin* plugin = getPluginByName(url.host());
@@ -1501,9 +1483,10 @@ SKGTabPage* SKGMainPanel::openPage(const QUrl& iUrl, bool iNewPage)
             //Open special page
             SKGTabPage* w = plugin->getWidget();
             if (w) {
-                //Create stata
+                //Create xml
+                QString path = url.path().remove('/');
                 QDomDocument doc("SKGML");
-                doc.setContent(getDocument()->getParameter(w->getDefaultStateAttribute()));
+                doc.setContent(getDocument()->getParameter(path.isEmpty() ? w->getDefaultStateAttribute() : path));
                 QDomElement root = doc.documentElement();
                 if (root.isNull()) {
                     root = doc.createElement("parameters");
@@ -1513,33 +1496,41 @@ SKGTabPage* SKGMainPanel::openPage(const QUrl& iUrl, bool iNewPage)
 
                 QStringList listKeys = params.keys();
                 foreach(const QString & k, listKeys) {
-                    QString value = KUrl::decode_string(params[k]);
+                    QString value = KUrl::fromPercentEncoding(params[k].toLatin1());
                     root.setAttribute(k, value);
                 }
 
                 //Open page
-                return openPage(plugin, iNewPage ? -1 : currentPageIndex(), doc.toString());
+                openPage(plugin, iNewPage ? -1 : currentPageIndex(), doc.toString());
+                return true;
             }
         } else {
             //Trigger action
             QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction(url.host());
             if (action) {
                 action->trigger();
-                return NULL;
+                return true;
             }
         }
     } else {
         QDesktopServices::openUrl(iUrl);
-        return NULL;
+        return true;
     }
     displayErrorMessage(SKGError(ERR_ABORT, i18nc("Error message", "Unknown plugin or action [%1] in url [%2]", url.host(), iUrl.toString())));
 
-    return NULL;
+    return false;
 }
 
-SKGTabPage* SKGMainPanel::openPage(const QString& iUrl, bool iNewPage)
+bool SKGMainPanel::openPage(const QString& iUrl, bool iNewPage)
 {
-    return openPage(QUrl(iUrl), iNewPage);
+    //Get the url
+    QString urlString(iUrl);
+    if (urlString.isEmpty()) {
+        QAction* act = qobject_cast< QAction* >(sender());
+        if (act) urlString = act->data().toString();
+    }
+
+    return openPage(QUrl(urlString), iNewPage);
 }
 
 SKGTabPage* SKGMainPanel::openPage(int iPage, bool iNewPage)
@@ -1743,7 +1734,7 @@ void SKGMainPanel::notify(int iTransaction)
 
             if (nbMessages < 20) {
                 //Display a simple notification
-                KNotification* notify = new KNotification(KCmdLineArgs::appName() % "_info_event" , this);
+                KNotification* notify = new KNotification(KGlobal::mainComponent().aboutData()->appName() % "_info_event" , this);
                 notify->setText(message);
                 notify->sendEvent();
             } else {
