@@ -270,9 +270,9 @@ public Q_SLOTS:
      * or "skg://action" to trigger an action
      * or "http://..." to open a web page
      * @param iNewPage to open a new page or not
-     * @return the opened tab*
+     * @return true if the url has been opened
      */
-    virtual SKGTabPage* openPage(const QUrl& iUrl, bool iNewPage = true);
+    virtual bool openPage(const QUrl& iUrl, bool iNewPage = true);
 
     /**
      * Open a plugin in a page
@@ -280,15 +280,15 @@ public Q_SLOTS:
      * or "skg://action" to trigger an action
      * or "http://..." to open a web page
      * @param iNewPage to open a new page or not
-     * @return the opened tab*
+     * @return true if the url has been opened
      */
-    virtual SKGTabPage* openPage(const QString& iUrl, bool iNewPage = true);
+    virtual bool openPage(const QString& iUrl = "", bool iNewPage = true);
 
     /**
      * Open a plugin in a page
      * @param iPage index of the page in the pages chooser
      * @param iNewPage to open a new page or not
-     * @return the opened tab*
+     * @return the opened tab
      */
     virtual SKGTabPage* openPage(int iPage, bool iNewPage = true);
 
@@ -333,15 +333,17 @@ public Q_SLOTS:
      * Register a global action
      * @param iIdentifier identifier of the action
      * @param iAction action pointer
+     * @param iAddInCollection to add or not the action in the main panel collection
      */
-    virtual void registerGlobalAction(const QString& iIdentifier, KAction* iAction);
+    virtual void registerGlobalAction(const QString& iIdentifier, QAction* iAction, bool iAddInCollection = true);
 
     /**
      * Get a registered global action
      * @param iIdentifier identifier of the action
+     * @param iWarnIfNotExist warn if the action does not exist
      * @return action pointer
      */
-    virtual KAction* getGlobalAction(const QString& iIdentifier);
+    virtual QAction* getGlobalAction(const QString& iIdentifier, bool iWarnIfNotExist = true);
 
     /**
      * Get the temporary filename containing the tips of days
@@ -419,9 +421,9 @@ private Q_SLOTS:
     void overwriteBookmarkState();
     void enableEditor();
 
-    void actionPrevious();
-    void actionNext();
-    void actionFullScreen();
+    void onPrevious();
+    void onNext();
+    void onFullScreen();
 
     void onShowPreviousMenu();
     void onShowNextMenu();
@@ -430,13 +432,13 @@ private Q_SLOTS:
     void onShowMenuBar();
     void onShowButtonMenu();
 
-    void actionHideContextItem();
-    void actionShowAllContextItems();
+    void onHideContextItem();
+    void onShowAllContextItems();
 
-    void actionLockDocks();
-    void actionUnlockDocks();
+    void onLockDocks();
+    void onUnlockDocks();
 private:
-    Q_DISABLE_COPY(SKGMainPanel);
+    Q_DISABLE_COPY(SKGMainPanel)
     void setupActions();
     bool iconInSystemtray();
     void refreshTabPosition();
@@ -455,7 +457,7 @@ private:
     SKGDocument* m_currentDocument;
 
     QList<SKGInterfacePlugin*> m_pluginsList;
-    QMap<QString, KAction*> m_registeredGlogalAction;
+    QMap<QString, QAction*> m_registeredGlogalAction;
     QList<QWidget*> m_hiddenWidgets;
 
     KMenu* m_contextMenu;
