@@ -614,7 +614,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
             return "";
         } else {
             if (index.column() == 0 && m_nodeTable) {
-                SKGNodeObject node = *obj;
+                SKGNodeObject node(*obj);
                 return qVariantFromValue(node.getIcon());
             } else if (index.column() == 0 && m_doctransactionTable) {
                 return qVariantFromValue((QIcon) KIcon(obj->getAttribute("t_mode") == "U" ? "edit-undo" : "edit-redo"));
@@ -734,13 +734,13 @@ bool SKGObjectModelBase::setData(const QModelIndex& index, const QVariant& value
     if (role == Qt::EditRole) {
         SKGError err;
         if (m_nodeTable) {
-            SKGNodeObject obj = getObject(index);
+            SKGNodeObject obj(getObject(index));
             QString name = value.toString();
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update '%1'", name), err);
             err = obj.setName(name);
             if (!err) err = obj.save();
         } else {
-            SKGObjectBase obj = getObject(index);
+            SKGObjectBase obj(getObject(index));
 
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Update object"), err);
             SKGObjectBase obj2(obj.getDocument(), obj.getRealTable(), obj.getID()); //To be sure this is not a complex object
@@ -811,7 +811,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
         QList<QUrl> urls = data->urls();
         int nb = urls.count();
         {
-            SKGObjectBase obj = getObject(parent);
+            SKGObjectBase obj(getObject(parent));
 
             SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Property creation"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
@@ -847,14 +847,14 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
             double max = 0;
             if (row >= 1) {
                 QModelIndex previousIndex = SKGObjectModelBase::index(row - 1, 0, parent);
-                SKGNodeObject previousObject = getObject(previousIndex);
+                SKGNodeObject previousObject(getObject(previousIndex));
                 min = previousObject.getOrder();
             }
 
             if (row >= rowCount(parent)) max = min + 1;
             else {
                 QModelIndex nextIndex = SKGObjectModelBase::index(row, 0, parent);
-                SKGNodeObject nextObject = getObject(nextIndex);
+                SKGNodeObject nextObject(getObject(nextIndex));
                 max = nextObject.getOrder();
             }
             if (max <= min) max = min + 1;
