@@ -22,7 +22,7 @@
 #include "skgtableviewdesignerplugin.h"
 #include "skgtableview.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
