@@ -22,7 +22,7 @@
 #include "skgtablewidgetdesignerplugin.h"
 #include "skgtablewidget.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
