@@ -334,7 +334,7 @@ void SKGTreeView::insertGlobalAction(const QString& iRegisteredAction)
         sep->setSeparator(true);
         this->insertAction(0, sep);
     } else if (SKGMainPanel::getMainPanel()) {
-        KAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(iRegisteredAction);
+        QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(iRegisteredAction);
         this->insertAction(0, act);
     }
 }
@@ -1093,4 +1093,9 @@ void SKGTreeView::setModel(QAbstractItemModel* iModel)
     }
 }
 
+KMenu* SKGTreeView::getHeaderMenu() const
+{
+    return m_headerMenu;
+}
+
 #include "skgtreeview.moc"
