@@ -139,6 +139,12 @@ public:
      **/
     virtual void setModel(QAbstractItemModel* iModel);
 
+    /**
+     * @brief Get the header menu
+     * @return the header menu
+     **/
+    virtual KMenu* getHeaderMenu() const;
+
 Q_SIGNALS:
     /**
      * Emitted when the empty area
@@ -281,7 +287,7 @@ private Q_SLOTS:
     SKGStringListList getTableContent(const QModelIndex& iIndex = QModelIndex()) const;
 
 private:
-    Q_DISABLE_COPY(SKGTreeView);
+    Q_DISABLE_COPY(SKGTreeView)
     QStringList getCurrentSchema() const;
 
     KMenu* m_headerMenu;
