@@ -75,13 +75,6 @@ public:
      */
     virtual QString getDefaultStateAttribute();
 
-    /**
-     * Get the widget for drag and drop
-     * MUST BE OVERWRITTEN
-     * @return the widget.
-     */
-    virtual QWidget* getDragWidget();
-
     /**
      * Get the current selection
      * MUST BE OVERWRITTEN
@@ -109,7 +102,7 @@ public:
     virtual QWidget* mainWidget() const;
 
 private:
-    Q_DISABLE_COPY(SKGWidget);
+    Q_DISABLE_COPY(SKGWidget)
 
     SKGDocument*  m_document;
 };
