@@ -31,7 +31,7 @@
 class SKGBASEGUI_EXPORT SKGWidgetCollectionDesignerPlugin: public QObject, public QDesignerCustomWidgetCollectionInterface
 {
     Q_OBJECT
-    Q_INTERFACES(QDesignerCustomWidgetCollectionInterface);
+    Q_INTERFACES(QDesignerCustomWidgetCollectionInterface)
 
 public:
     /**
