@@ -42,23 +42,23 @@ class SKGReport;
 */
 class SKGBASEMODELER_EXPORT SKGDocument : public QObject
 {
-    Q_OBJECT;
-    Q_CLASSINFO("D-Bus Interface", "org.skg.SKGDocument");
+    Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.skg.SKGDocument")
 
     /**
      * This enumerate defines a type of modification
      */
-    Q_ENUMS(ModificationType);
+    Q_ENUMS(ModificationType)
 
     /**
      * This enumerate defines the direction of the UNDO / REDO mechanism
      */
-    Q_ENUMS(UndoRedoMode);
+    Q_ENUMS(UndoRedoMode)
 
     /**
      * This enumerate defines the mode of file
      */
-    Q_ENUMS(DatabaseMode);
+    Q_ENUMS(DatabaseMode)
 
     /**
      * The unique identifier
@@ -856,7 +856,7 @@ protected:
     virtual SKGError computeMaterializedViews(const QString& iTable = "");
 
 private:
-    Q_DISABLE_COPY(SKGDocument);
+    Q_DISABLE_COPY(SKGDocument)
 
     QString getBackupFile(const QString iFileName);
 
