@@ -246,6 +246,8 @@ QString SKGObjectBase::getAttribute(const QString& iName) const
     QString output;
     if (d->attributes.contains(iName)) {
         output = d->attributes[iName];
+    } else if (iName == "id") {
+        output = SKGServices::intToString(getID());
     } else {
         //Is the iName a number ?
         bool ok;
