@@ -42,19 +42,19 @@ class SKGObjectBasePrivate;
  */
 class SKGBASEMODELER_EXPORT SKGObjectBase : public QObject
 {
-    Q_OBJECT;
+    Q_OBJECT
     /**
      * Unique ide  of the object
      */
-    Q_PROPERTY(QString uniqueID READ getUniqueID);
+    Q_PROPERTY(QString uniqueID READ getUniqueID)
     /**
      * Id of the object
      */
-    Q_PROPERTY(int ID READ getID);
+    Q_PROPERTY(int ID READ getID)
     /**
      * Table of the object
      */
-    Q_PROPERTY(QString table READ getTable);
+    Q_PROPERTY(QString table READ getTable)
 
 public:
     /**
@@ -307,7 +307,7 @@ private:
 /**
  * Declare the meta type
  */
-Q_DECLARE_METATYPE(SKGObjectBase);
+Q_DECLARE_METATYPE(SKGObjectBase)
 
 /**
  * Declare the class
@@ -317,5 +317,5 @@ Q_DECLARE_TYPEINFO(SKGObjectBase, Q_MOVABLE_TYPE);
 /**
  * Declare the meta type
  */
-Q_DECLARE_METATYPE(QList<SKGObjectBase>);
+Q_DECLARE_METATYPE(QList<SKGObjectBase>)
 #endif
