@@ -114,10 +114,10 @@ void SKGReport::addItemsInMapping(QVariantHash& iMapping)
 
 }
 
-SKGError SKGReport::getReportFormTemplate(SKGReport* iReport, const QString& iFile, QString& oHtml)
+SKGError SKGReport::getReportFromTemplate(SKGReport* iReport, const QString& iFile, QString& oHtml)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGReport::getReportFormTemplate", err);
+    SKGTRACEINRC(10, "SKGReport::getReportFromTemplate", err);
     SKGDocument* doc = (iReport ? static_cast<SKGDocument*>(iReport->m_document) : NULL);
 
     //Prepare grantlee engine
@@ -169,7 +169,7 @@ SKGError SKGReport::getReportFormTemplate(SKGReport* iReport, const QString& iFi
 
     //Generation
     {
-        SKGTRACEINRC(10, "SKGReport::getReportFormTemplate-grantlee render", err);
+        SKGTRACEINRC(10, "SKGReport::getReportFromTemplate-grantlee render", err);
         oHtml = gTemplate->render(&gContext);
         if (gTemplate->error()) err = SKGError(gTemplate->error(), gTemplate->errorString());
     }
