@@ -27,6 +27,7 @@
 #include <kglobal.h>
 #include <ksavefile.h>
 #include <kio/netaccess.h>
+#include <kio/job.h>
 
 #include <sys/time.h>
 
@@ -38,6 +39,7 @@
 #include <QVariant>
 #include <QRegExp>
 #include <QFile>
+#include <QTemporaryFile>
 #include <QtCrypto>
 #include <QDomDocument>
 
@@ -171,9 +173,17 @@ QString SKGServices::stringToCsv(const QString& iNumber)
 
 double SKGServices::stringToDouble(const QString& iNumber)
 {
-    if (iNumber.isEmpty()) return 0;
+    if (iNumber.isEmpty() || iNumber == "nan") return 0;
+    else if (iNumber == "inf") return 1e300;
+    else if (iNumber == "-inf") return -1e300;
     QString number = iNumber;
-    number.remove(QRegExp("[^0-9-+eE,.]"));
+    number.remove(QRegExp("[^0-9-+/eE,.]"));
+    if (number.contains("/")) {
+        //Use script engine
+        QScriptEngine myEngine;
+        QScriptValue result = myEngine.evaluate(number);
+        if (result.isNumber()) return result.toNumber();
+    }
 
     bool ok;
     double output = number.toDouble(&ok);
@@ -310,12 +320,14 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
     for (int i = 0; i < nb; ++i) {
 
         QString val = iDates.at(i);
-        val = val.replace('/', '-');
+        val = val.replace(' ', '0');
         val = val.replace('\\', '-');
+        val = val.replace('/', '-');
+        val = val.replace('.', '-');
         val = val.replace("'20", "-20");
         val = val.replace("' ", "-200");
         val = val.replace('\'', "-20");
-        val = val.replace('.', '-');
+        val = val.replace("-9", "-199");
         if (rx.indexIn(val) == -1) {
             f_YYYY_MM_DD = false;
             f_MM_DD_YY = false;
@@ -391,7 +403,7 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
 
             if (v3.length() == 4) {
                 f_YYYY_MM_DD = false;
-//                 f_MM_DD_YY=false;
+                f_MM_DD_YY = false;
                 f_DD_MM_YY = false;
             } else {
                 f_MM_DD_YYYY = false;
@@ -452,12 +464,14 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
 
     } else {
         QString val = iDate;
+        val = val.replace(' ', '0');
         val = val.replace('\\', '-');
         val = val.replace('/', '-');
+        val = val.replace('.', '-');
         val = val.replace("'20", "-20");
         val = val.replace("' ", "-200");
         val = val.replace('\'', "-20");
-        val = val.replace('.', '-');
+        val = val.replace("-9", "-199");
         QRegExp rx("(.+)-(.+)-(.+)");
         if (rx.indexIn(val) != -1) {
             QString v1 = rx.cap(1);
@@ -570,6 +584,35 @@ QString SKGServices::getRealTable(const QString& iTable)
     return output;
 }
 
+SKGError SKGServices::download(const KUrl& iSourceUrl, QString& oStream)
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGServices::download", err);
+    QTemporaryFile tmpFile;
+    if (tmpFile.open()) {
+        KIO::Job* getJob = KIO::file_copy(iSourceUrl, KUrl(KUrl::fromLocalFile(tmpFile.fileName())), -1, KIO::Overwrite | KIO::HideProgressInfo);
+        //getJob->ui()->setWindow(window);
+        if (!KIO::NetAccess::synchronousRun(getJob, 0)) {
+            err.setReturnCode(ERR_ABORT);
+            err.setMessage(getJob->errorString());
+        } else {
+            //Open file
+            QFile file(tmpFile.fileName());
+            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                err.setReturnCode(ERR_FAIL);
+                err.setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile.fileName()));
+            } else {
+                oStream = file.readAll();
+
+                //close file
+                file.close();
+            }
+        }
+        tmpFile.remove();
+    }
+    return err;
+}
+
 SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFileTarget, const QString& iPassword, bool iEncrypt, const QString& iHeaderFile)
 {
     SKGError err;
@@ -680,30 +723,29 @@ SKGError SKGServices::copySqliteDatabaseToXml(QSqlDatabase* iDb, QDomDocument& o
 
         // Copy the tables
         QStringList listTables = iDb->tables();
-        listTables.removeAll("sqlite_sequence");
-        listTables.removeAll("sqlite_stat1");
         int nb = listTables.count();
         for (int i = 0; !err && i < nb; ++i) {
             QString tableName = listTables.at(i);
+            if (!tableName.startsWith(QLatin1String("sqlite_"))) {
+                QDomElement table = oDocument.createElement("table");
+                document.appendChild(table);
+                table.setAttribute("name", tableName);
 
-            QDomElement table = oDocument.createElement("table");
-            document.appendChild(table);
-            table.setAttribute("name", tableName);
+                SKGStringListList listRows;
+                err = SKGServices::executeSelectSqliteOrder(iDb, "SELECT * FROM " % tableName, listRows);
+                int nbRows = listRows.count();
+                if (nbRows) {
+                    QStringList titles = listRows.at(0);
+                    for (int j = 1; !err && j < nbRows; ++j) { //Forget title
+                        QStringList values = listRows.at(j);
 
-            SKGStringListList listRows;
-            err = SKGServices::executeSelectSqliteOrder(iDb, "SELECT * FROM " % tableName, listRows);
-            int nbRows = listRows.count();
-            if (nbRows) {
-                QStringList titles = listRows.at(0);
-                for (int j = 1; !err && j < nbRows; ++j) { //Forget title
-                    QStringList values = listRows.at(j);
+                        QDomElement row = oDocument.createElement("row");
+                        table.appendChild(row);
 
-                    QDomElement row = oDocument.createElement("row");
-                    table.appendChild(row);
-
-                    int nbVals = values.count();
-                    for (int k = 0; k < nbVals; ++k) {
-                        row.setAttribute(titles.at(k), values.at(k));
+                        int nbVals = values.count();
+                        for (int k = 0; k < nbVals; ++k) {
+                            row.setAttribute(titles.at(k), values.at(k));
+                        }
                     }
                 }
             }
@@ -721,43 +763,42 @@ SKGError SKGServices::copySqliteDatabaseToJson(QSqlDatabase* iDb, QString& oDocu
 
         // Copy the tables
         QStringList listTables = iDb->tables();
-        listTables.removeAll("sqlite_sequence");
-        listTables.removeAll("sqlite_stat1");
         int nb = listTables.count();
         for (int i = 0; !err && i < nb; ++i) {
             QString tableName = listTables.at(i);
+            if (!tableName.startsWith(QLatin1String("sqlite_"))) {
+                oDocument += "\"" % tableName % "\":\n[\n";
 
-            oDocument += "\"" % tableName % "\":\n[\n";
+                SKGStringListList listRows;
+                err = SKGServices::executeSelectSqliteOrder(iDb, "SELECT * FROM " % tableName, listRows);
+                int nbRows = listRows.count();
+                if (nbRows) {
+                    QStringList titles = listRows.at(0);
+                    for (int j = 1; !err && j < nbRows; ++j) { //Forget title
+                        QStringList values = listRows.at(j);
 
-            SKGStringListList listRows;
-            err = SKGServices::executeSelectSqliteOrder(iDb, "SELECT * FROM " % tableName, listRows);
-            int nbRows = listRows.count();
-            if (nbRows) {
-                QStringList titles = listRows.at(0);
-                for (int j = 1; !err && j < nbRows; ++j) { //Forget title
-                    QStringList values = listRows.at(j);
-
-                    oDocument += '{';
-                    int nbVals = values.count();
-                    for (int k = 0; k < nbVals; ++k) {
-                        QString v = values.at(k);
-                        v = v.replace("\\", "\\\\");
-                        v = v.replace('\t', "\\\t");
-                        v = v.replace('\r', "\\\r");
-                        v = v.replace('\n', "\\\n");
-                        v = v.replace('\f', "\\\f");
-                        v = v.replace('\b', "\\\b");
-                        v = v.replace('/', "\\/");
-                        v = v.replace('"', "\\\"");
-                        oDocument += '"' % titles.at(k) % "\":\"" % v % '"';
-                        if (k < nbVals - 1) oDocument += ',';
+                        oDocument += '{';
+                        int nbVals = values.count();
+                        for (int k = 0; k < nbVals; ++k) {
+                            QString v = values.at(k);
+                            v = v.replace("\\", "\\\\");
+                            v = v.replace('\t', "\\\t");
+                            v = v.replace('\r', "\\\r");
+                            v = v.replace('\n', "\\\n");
+                            v = v.replace('\f', "\\\f");
+                            v = v.replace('\b', "\\\b");
+                            v = v.replace('/', "\\/");
+                            v = v.replace('"', "\\\"");
+                            oDocument += '"' % titles.at(k) % "\":\"" % v % '"';
+                            if (k < nbVals - 1) oDocument += ',';
+                        }
+                        oDocument += '}';
+                        if (j < nbRows - 1) oDocument += ',';
+                        oDocument += '\n';
                     }
-                    oDocument += '}';
-                    if (j < nbRows - 1) oDocument += ',';
-                    oDocument += '\n';
                 }
+                oDocument += "]\n";
             }
-            oDocument += "]\n";
         }
     }
     return err;
@@ -779,7 +820,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
         if (!err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYTABLES", err);
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
-                    "SELECT sql, tbl_name FROM sqlite_master WHERE type='table' AND sql NOT NULL and name NOT IN ('sqlite_stat1', 'sqlite_sequence')",
+                    "SELECT sql, tbl_name FROM sqlite_master WHERE type='table' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
                     listTables);
 
             nb = listTables.count();
@@ -835,7 +876,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYTRIGGER", err);
             SKGStringListList listSqlOrder;
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
-                    "SELECT sql FROM sqlite_master WHERE type='trigger' AND sql NOT NULL and name NOT IN ('sqlite_stat1', 'sqlite_sequence')",
+                    "SELECT sql FROM sqlite_master WHERE type='trigger' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
                     listSqlOrder);
 
             int nb = listSqlOrder.count();
@@ -850,7 +891,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYINDEX", err);
             SKGStringListList listSqlOrder;
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
-                    "SELECT sql FROM sqlite_master WHERE type='index' AND sql NOT NULL and name NOT IN ('sqlite_stat1', 'sqlite_sequence')",
+                    "SELECT sql FROM sqlite_master WHERE type='index' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
                     listSqlOrder);
 
             int nb = listSqlOrder.count();
@@ -865,7 +906,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYVIEW", err);
             SKGStringListList listSqlOrder;
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
-                    "SELECT sql FROM sqlite_master WHERE type='view' AND sql NOT NULL and name NOT IN ('sqlite_stat1', 'sqlite_sequence')",
+                    "SELECT sql FROM sqlite_master WHERE type='view' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
                     listSqlOrder);
 
             int nb = listSqlOrder.count();
@@ -931,6 +972,8 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
 
             err = SKGError(SQLLITEERROR + sqlError.number(), iSqlOrder);
             err.addError(SQLLITEERROR + sqlError.number(), sqlError.text());
+
+            if (sqlError.number() == 19) err.addError(ERR_FAIL, i18nc("Error message", "Creation failed. The object already exists."));
         } else {
             if (iLastId) *iLastId = query.lastInsertId().toInt();
         }
@@ -1246,4 +1289,10 @@ SKGStringListList SKGServices::getHistorizedTable(const SKGStringListList& iTabl
     return output;
 }
 
+QString SKGServices::encodeForUrl(const QString& iString)
+{
+    return KUrl::toPercentEncoding(iString);
+}
+
+
 #include "skgservices.moc"
