@@ -26,6 +26,8 @@
 #include "skgdefine.h"
 #include "skgbasemodeler_export.h"
 
+#include <kurl.h>
+
 #include <QStringList>
 #include <QHash>
 #include <QDateTime>
@@ -83,15 +85,15 @@ typedef QList<int>::Iterator SKGIntListIterator;
 */
 class SKGBASEMODELER_EXPORT SKGServices : public QObject
 {
-    Q_OBJECT;
+    Q_OBJECT
     /**
      * This enumerate defines dump modes
      */
-    Q_ENUMS(DumpMode);
+    Q_ENUMS(DumpMode)
     /**
      * This enumerate defines attributes types
      */
-    Q_ENUMS(AttributeType);
+    Q_ENUMS(AttributeType)
 public:
     /**
      * Unit value
@@ -455,6 +457,15 @@ public:
     static SKGError cryptFile(const QString& iFileSource, const QString& iFileTarget,
                               const QString& iPassword, bool iEncrypt = true, const QString& iHeaderFile = "");
 
+    /**
+     * Download a non local URL to a string
+     * @param iSourceUrl the non local URL
+     * @param oStream the downloaded string
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    static SKGError download(const KUrl& iSourceUrl, QString& oStream);
+
     /**
      * To enable, disable sql traces
      */
@@ -480,11 +491,19 @@ public:
      * Create an historized table.
      * Each column is the sum of previous ones
      * @param iTable table
+     * @return the table
      */
     static SKGStringListList getHistorizedTable(const SKGStringListList& iTable);
 
+    /**
+     * Encode a string for an url
+     * @param iString the decoded string
+     * @return the encoded string
+     */
+    static QString encodeForUrl(const QString& iString);
+
 private:
-    Q_DISABLE_COPY(SKGServices);
+    Q_DISABLE_COPY(SKGServices)
     static SKGError m_lastCallbackError;
 };
 #endif
